@@ -361,11 +361,6 @@ QMenu* DkActionManager::createFileMenu(QWidget* parent /* = 0 */) {
 
 	mFileMenu = new QMenu(QObject::tr("&File"), parent);
 
-	mFileMenu->addAction(mFileActions[menu_file_new_tab]);
-	mFileMenu->addAction(mFileActions[menu_file_close_tab]);
-	mFileMenu->addAction(mFileActions[menu_file_close_all_tabs]);
-	mFileMenu->addSeparator();
-
 	mFileMenu->addAction(mFileActions[menu_file_open]);
 	mFileMenu->addAction(mFileActions[menu_file_open_dir]);
 	if (DkSettingsManager::param().global().extendedTabs)
@@ -406,32 +401,22 @@ QMenu* DkActionManager::createFileMenu(QWidget* parent /* = 0 */) {
 
 QMenu * DkActionManager::createOpenWithMenu(QWidget* parent) {
 
-	// TODO: propagate update!
 	mOpenWithMenu = new QMenu(QObject::tr("&Open With"), parent);
 	return updateOpenWithMenu();
 }
 
 QMenu* DkActionManager::updateOpenWithMenu() {
-	//QList<QAction* > oldActions = mOpenWithMenu->findChildren<QAction* >();
-
-	//// remove old actions
-	//for (int idx = 0; idx < oldActions.size(); idx++)
-	//	viewport()->removeAction(oldActions.at(idx));
 	
 	mOpenWithMenu->clear();
 
 	QVector<QAction* > appActions = mAppManager->getActions();
 
-	//for (int idx = 0; idx < appActions.size(); idx++)
-	//	qDebug() << "adding action: " << appActions[idx]->text() << " " << appActions[idx]->toolTip();
-
 	assignCustomShortcuts(appActions);
 	mOpenWithMenu->addActions(appActions.toList());
 
 	if (!appActions.empty())
 		mOpenWithMenu->addSeparator();
 	mOpenWithMenu->addAction(mFileActions[menu_file_app_manager]);
-	//centralWidget()->addActions(appActions.toList());	// TODO: notify
 
 	return mOpenWithMenu;
 }
@@ -454,10 +439,14 @@ QMenu* DkActionManager::createViewMenu(QWidget* parent /* = 0 */) {
 
 	mViewMenu = new QMenu(QObject::tr("&View"), parent);
 
-	mViewMenu->addAction(mViewActions[menu_view_frameless]);	
+	mViewMenu->addAction(mViewActions[menu_view_frameless]);
 	mViewMenu->addAction(mViewActions[menu_view_fullscreen]);
 	mViewMenu->addSeparator();
 
+	mViewMenu->addAction(mViewActions[menu_view_new_tab]);
+	mViewMenu->addAction(mViewActions[menu_view_close_tab]);
+	mViewMenu->addAction(mViewActions[menu_view_close_all_tabs]);
+
 	if (DkSettingsManager::param().global().extendedTabs)
 		mViewMenu->addAction(mViewActions[menu_view_first_tab]);
 	mViewMenu->addAction(mViewActions[menu_view_previous_tab]);
@@ -492,8 +481,13 @@ QMenu* DkActionManager::createViewMenu(QWidget* parent /* = 0 */) {
 	mViewMenu->addAction(mViewActions[menu_view_movie_pause]);
 	mViewMenu->addAction(mViewActions[menu_view_movie_prev]);
 	mViewMenu->addAction(mViewActions[menu_view_movie_next]);
-
 	mViewMenu->addSeparator();
+
+	if (DkSettingsManager::param().app().currentAppMode == DkSettingsManager::param().mode_frameless) {
+		mViewMenu->addAction(mViewActions[menu_view_monitors]);
+		mViewMenu->addSeparator();
+	}
+	
 	mViewMenu->addAction(mViewActions[menu_view_gps_map]);
 
 	return mViewMenu;
@@ -593,21 +587,14 @@ QMenu* DkActionManager::createToolsMenu(QWidget* parent /* = 0 */) {
 	return mToolsMenu;
 }
 
-void DkActionManager::addSyncMenu(QMenu* syncMenu, DkTcpMenu* localMenu, DkTcpMenu* lanMenu) {
+void DkActionManager::addSyncMenu(QMenu* syncMenu, DkTcpMenu* localMenu) {
 
 	mSyncMenu = syncMenu;
 	mLocalMenu = localMenu;
-	mLanMenu = lanMenu;
 
 	mSyncMenu->addMenu(localMenu);
-	mSyncMenu->addMenu(lanMenu);
 
-	mSyncMenu->addAction(mSyncActions[menu_sync_remote_control]);
-	mSyncMenu->addAction(mSyncActions[menu_sync_remote_display]);
-	mSyncMenu->addAction(mLanActions[menu_lan_image]);
-	mSyncMenu->addSeparator();
-	
-	mSyncMenu->addAction(mSyncActions[menu_sync]);
+	mSyncMenu->addAction(mSyncActions[menu_sync_view]);
 	mSyncMenu->addAction(mSyncActions[menu_sync_pos]);
 	mSyncMenu->addAction(mSyncActions[menu_sync_arrange]);
 	mSyncMenu->addAction(mSyncActions[menu_sync_all_actions]);
@@ -642,6 +629,7 @@ QMenu* DkActionManager::createContextMenu(QWidget* parent) {
 
 	mContextMenu->addAction(mViewActions[menu_view_frameless]);
 	mContextMenu->addAction(mViewActions[menu_view_fullscreen]);
+	mContextMenu->addAction(mPanelActions[menu_panel_menu]);
 	mContextMenu->addSeparator();
 
 	if (DkSettingsManager::param().global().extendedTabs) {
@@ -732,10 +720,6 @@ QAction* DkActionManager::action(SyncMenuActions action) const {
 	return mSyncActions[action];
 }
 
-QAction* DkActionManager::action(LanMenuActions action) const {
-	return mLanActions[action];
-}
-
 QAction* DkActionManager::action(HelpMenuActions action) const {
 	return mHelpActions[action];
 }
@@ -773,7 +757,19 @@ QVector<QAction*> DkActionManager::sortActions() const {
 }
 
 QVector<QAction*> DkActionManager::openWithActions() const {
-	return mOpenWithActions;
+	
+	if (!openWithMenu())
+		return QVector<QAction*>();
+
+	QList<QAction* > openWithActionList = openWithMenu()->actions();
+	QVector<QAction* > owas;
+
+	// the separator creates a NULL action?! - remove it here...
+	for (auto a : openWithActionList)
+		if (!a->text().isNull())
+			owas << a;
+	
+	return owas;
 }
 
 QVector<QAction*> DkActionManager::viewActions() const {
@@ -796,10 +792,6 @@ QVector<QAction*> DkActionManager::syncActions() const {
 	return mSyncActions;
 }
 
-QVector<QAction*> DkActionManager::lanActions() const {
-	return mLanActions;
-}
-
 QVector<QAction*> DkActionManager::helpActions() const {
 	return mHelpActions;
 }
@@ -876,10 +868,6 @@ DkTcpMenu* DkActionManager::localMenu() const {
 	return mLocalMenu;
 }
 
-DkTcpMenu* DkActionManager::lanMenu() const {
-	return mLanMenu;
-}
-
 DkManipulatorManager DkActionManager::manipulatorManager() const {
 	return mManipulators;
 }
@@ -894,7 +882,6 @@ void DkActionManager::createMenus(QWidget* parent) {
 	createManipulatorMenu(parent);
 	createToolsMenu(parent);
 	createPanelMenu(parent);
-	//createPluginMenu(parent);
 	createHelpMenu(parent);
 	createContextMenu(parent);
 }
@@ -923,10 +910,11 @@ void DkActionManager::createIcons() {
 	mFileIcons[icon_file_next] = DkImage::loadIcon(":/nomacs/img/next.svg");
 	mFileIcons[icon_file_filter] = DkImage::loadIcon();
 	mFileIcons[icon_file_filter].addPixmap(DkImage::loadIcon(":/nomacs/img/filter.svg"), QIcon::Normal, QIcon::On);
-	mFileIcons[icon_file_filter].addPixmap(DkImage::loadIcon(":/nomacs/img/nofilter.svg"), QIcon::Normal, QIcon::Off);
+	mFileIcons[icon_file_filter].addPixmap(DkImage::loadIcon(":/nomacs/img/filter-disabled.svg"), QIcon::Normal, QIcon::Off);
+	mFileIcons[icon_file_find] = DkImage::loadIcon(":/nomacs/img/find.svg");
 
 	mEditIcons.resize(icon_edit_end);
-	mEditIcons[icon_edit_image] = DkImage::loadIcon(":/nomacs/img/manipulation.svg");
+	mEditIcons[icon_edit_image] = DkImage::loadIcon(":/nomacs/img/sliders.svg");
 	mEditIcons[icon_edit_rotate_cw] = DkImage::loadIcon(":/nomacs/img/rotate-cw.svg");
 	mEditIcons[icon_edit_rotate_ccw] = DkImage::loadIcon(":/nomacs/img/rotate-cc.svg");
 	mEditIcons[icon_edit_crop] = DkImage::loadIcon(":/nomacs/img/crop.svg");
@@ -937,17 +925,17 @@ void DkActionManager::createIcons() {
 
 	mViewIcons.resize(icon_view_end);
 	mViewIcons[icon_view_fullscreen] = DkImage::loadIcon(":/nomacs/img/fullscreen.svg");
-	mViewIcons[icon_view_reset] = DkImage::loadIcon(":/nomacs/img/zoomReset.svg");
-	mViewIcons[icon_view_100] = DkImage::loadIcon(":/nomacs/img/zoom100.svg");
-	mViewIcons[icon_view_gps] = DkImage::loadIcon(":/nomacs/img/gps-globe.svg");
+	mViewIcons[icon_view_reset] = DkImage::loadIcon(":/nomacs/img/zoom-reset.svg");
+	mViewIcons[icon_view_100] = DkImage::loadIcon(":/nomacs/img/zoom-100.svg");
+	mViewIcons[icon_view_gps] = DkImage::loadIcon(":/nomacs/img/location.svg");
 	mViewIcons[icon_view_zoom_in] = DkImage::loadIcon(":/nomacs/img/zoom-in.svg");
 	mViewIcons[icon_view_zoom_out] = DkImage::loadIcon(":/nomacs/img/zoom-out.svg");
 
-	mViewIcons[icon_view_movie_play] = DkImage::loadIcon();
-	mViewIcons[icon_view_movie_play].addPixmap(QPixmap(":/nomacs/img/movie-play.svg"), QIcon::Normal, QIcon::On);
-	mViewIcons[icon_view_movie_play].addPixmap(QPixmap(":/nomacs/img/movie-pause.svg"), QIcon::Normal, QIcon::Off);
-	mViewIcons[icon_view_movie_prev] = DkImage::loadIcon(":/nomacs/img/movie-prev.svg");
-	mViewIcons[icon_view_movie_next] = DkImage::loadIcon(":/nomacs/img/movie-next.svg");
+	mViewIcons[icon_view_movie_play] = DkImage::loadIcon(":/nomacs/img/play.svg");
+	mViewIcons[icon_view_movie_play].addPixmap(DkImage::loadIcon(":/nomacs/img/play.svg"), QIcon::Normal, QIcon::On);
+	mViewIcons[icon_view_movie_play].addPixmap(DkImage::loadIcon(":/nomacs/img/pause.svg"), QIcon::Normal, QIcon::Off);
+	mViewIcons[icon_view_movie_prev] = DkImage::loadIcon(":/nomacs/img/previous.svg");
+	mViewIcons[icon_view_movie_next] = DkImage::loadIcon(":/nomacs/img/next.svg");
 }
 
 void DkActionManager::createActions(QWidget* parent) {
@@ -955,17 +943,6 @@ void DkActionManager::createActions(QWidget* parent) {
 	// file actions
 	mFileActions.resize(menu_file_end);
 
-	mFileActions[menu_file_new_tab] = new QAction(QObject::tr("New &Tab"), parent);
-	mFileActions[menu_file_new_tab]->setShortcut(QKeySequence(shortcut_new_tab));
-	mFileActions[menu_file_new_tab]->setStatusTip(QObject::tr("Open a new tab"));
-
-	mFileActions[menu_file_close_tab] = new QAction(QObject::tr("&Close Tab"), parent);
-	mFileActions[menu_file_close_tab]->setShortcut(QKeySequence(shortcut_close_tab));
-	mFileActions[menu_file_close_tab]->setStatusTip(QObject::tr("Close current tab"));
-
-	mFileActions[menu_file_close_all_tabs] = new QAction(QObject::tr("&Close All Tabs"), parent);
-	mFileActions[menu_file_close_all_tabs]->setStatusTip(QObject::tr("Close all open tabs"));
-
 	mFileActions[menu_file_open] = new QAction(mFileIcons[icon_file_open], QObject::tr("&Open"), parent);
 	mFileActions[menu_file_open]->setShortcuts(QKeySequence::Open);
 	mFileActions[menu_file_open]->setStatusTip(QObject::tr("Open an image"));
@@ -1023,7 +1000,7 @@ void DkActionManager::createActions(QWidget* parent) {
 
 	mFileActions[menu_file_reload] = new QAction(QObject::tr("&Reload File"), parent);
 	mFileActions[menu_file_reload]->setShortcutContext(Qt::WidgetWithChildrenShortcut);
-	mFileActions[menu_file_reload]->setShortcuts(QKeySequence::Refresh);
+	mFileActions[menu_file_reload]->setShortcut(QKeySequence(shortcut_reload));
 	mFileActions[menu_file_reload]->setStatusTip(QObject::tr("Reload File"));
 
 	mFileActions[menu_file_next] = new QAction(mFileIcons[icon_file_next], QObject::tr("Ne&xt File"), parent);
@@ -1044,7 +1021,7 @@ void DkActionManager::createActions(QWidget* parent) {
 	mFileActions[menu_file_private_instance]->setShortcut(QKeySequence(shortcut_private_instance));
 	mFileActions[menu_file_private_instance]->setStatusTip(QObject::tr("Open private instance"));
 
-	mFileActions[menu_file_find] = new QAction(QObject::tr("&Find && Filter"), parent);
+	mFileActions[menu_file_find] = new QAction(mFileIcons[icon_file_find], QObject::tr("&Find && Filter"), parent);
 	mFileActions[menu_file_find]->setShortcut(QKeySequence::Find);
 	mFileActions[menu_file_find]->setStatusTip(QObject::tr("Find an image"));
 
@@ -1178,7 +1155,7 @@ void DkActionManager::createActions(QWidget* parent) {
 
 	// panel actions
 	mPanelActions.resize(menu_panel_end);
-	mPanelActions[menu_panel_menu] = new QAction(QObject::tr("&Menu"), parent);
+	mPanelActions[menu_panel_menu] = new QAction(QObject::tr("Show &Menu"), parent);
 	mPanelActions[menu_panel_menu]->setStatusTip(QObject::tr("Hides the Menu and Shows it Again on ALT"));
 	mPanelActions[menu_panel_menu]->setCheckable(true);
 
@@ -1213,6 +1190,7 @@ void DkActionManager::createActions(QWidget* parent) {
 	mPanelActions[menu_panel_toggle]->setShortcut(QKeySequence(shortcut_toggle_panels));
 	mPanelActions[menu_panel_toggle]->setStatusTip(QObject::tr("Hide all panels"));
 	mPanelActions[menu_panel_toggle]->setCheckable(true);
+	mPanelActions[menu_panel_toggle]->setChecked(DkSettingsManager::param().app().hideAllPanels);
 
 	mPanelActions[menu_panel_explorer] = new QAction(QObject::tr("File &Explorer"), parent);
 	mPanelActions[menu_panel_explorer]->setShortcut(QKeySequence(shortcut_show_explorer));
@@ -1265,10 +1243,39 @@ void DkActionManager::createActions(QWidget* parent) {
 
 	// view actions
 	mViewActions.resize(menu_view_end);
+
+	mViewActions[menu_view_new_tab] = new QAction(QObject::tr("New &Tab"), parent);
+	mViewActions[menu_view_new_tab]->setShortcut(QKeySequence(shortcut_new_tab));
+	mViewActions[menu_view_new_tab]->setStatusTip(QObject::tr("Open a new tab"));
+
+	mViewActions[menu_view_close_tab] = new QAction(QObject::tr("&Close Tab"), parent);
+	mViewActions[menu_view_close_tab]->setShortcut(QKeySequence(shortcut_close_tab));
+	mViewActions[menu_view_close_tab]->setStatusTip(QObject::tr("Close current tab"));
+
+	mViewActions[menu_view_close_all_tabs] = new QAction(QObject::tr("&Close All Tabs"), parent);
+	mViewActions[menu_view_close_all_tabs]->setStatusTip(QObject::tr("Close all open tabs"));
+
 	mViewActions[menu_view_fit_frame] = new QAction(QObject::tr("&Fit Window"), parent);
 	mViewActions[menu_view_fit_frame]->setShortcut(QKeySequence(shortcut_fit_frame));
 	mViewActions[menu_view_fit_frame]->setStatusTip(QObject::tr("Fit window to the image"));
 
+	mViewActions[menu_view_first_tab] = new QAction(QObject::tr("F&irst Tab"), parent);
+	mViewActions[menu_view_first_tab]->setStatusTip(QObject::tr("Switch to first tab"));
+
+	mViewActions[menu_view_previous_tab] = new QAction(QObject::tr("&Previous Tab"), parent);
+	mViewActions[menu_view_previous_tab]->setShortcut(QKeySequence(shortcut_previous_tab));
+	mViewActions[menu_view_previous_tab]->setStatusTip(QObject::tr("Switch to previous tab"));
+
+	mViewActions[menu_view_goto_tab] = new QAction(QObject::tr("&Go to Tab"), parent);
+	mViewActions[menu_view_goto_tab]->setStatusTip(QObject::tr("Go to tab by index"));
+
+	mViewActions[menu_view_next_tab] = new QAction(QObject::tr("&Next Tab"), parent);
+	mViewActions[menu_view_next_tab]->setShortcut(QKeySequence(shortcut_next_tab));
+	mViewActions[menu_view_next_tab]->setStatusTip(QObject::tr("Switch to next tab"));
+
+	mViewActions[menu_view_last_tab] = new QAction(QObject::tr("La&st Tab"), parent);
+	mViewActions[menu_view_last_tab]->setStatusTip(QObject::tr("Switch to last tab"));
+
 	QList<QKeySequence> scs;
 	scs.append(shortcut_full_screen_ff);
 	scs.append(shortcut_full_screen_ad);
@@ -1310,23 +1317,6 @@ void DkActionManager::createActions(QWidget* parent) {
 	mViewActions[menu_view_frameless]->setCheckable(true);
 	mViewActions[menu_view_frameless]->setChecked(false);
 
-	mViewActions[menu_view_first_tab] = new QAction(QObject::tr("F&irst Tab"), parent);
-	mViewActions[menu_view_first_tab]->setStatusTip(QObject::tr("Switch to first tab"));
-
-	mViewActions[menu_view_previous_tab] = new QAction(QObject::tr("&Previous Tab"), parent);
-	mViewActions[menu_view_previous_tab]->setShortcut(QKeySequence(shortcut_previous_tab));
-	mViewActions[menu_view_previous_tab]->setStatusTip(QObject::tr("Switch to previous tab"));
-
-	mViewActions[menu_view_goto_tab] = new QAction(QObject::tr("&Go to Tab"), parent);
-	mViewActions[menu_view_goto_tab]->setStatusTip(QObject::tr("Go to tab by index"));
-
-	mViewActions[menu_view_next_tab] = new QAction(QObject::tr("&Next Tab"), parent);
-	mViewActions[menu_view_next_tab]->setShortcut(QKeySequence(shortcut_next_tab));
-	mViewActions[menu_view_next_tab]->setStatusTip(QObject::tr("Switch to next tab"));
-
-	mViewActions[menu_view_last_tab] = new QAction(QObject::tr("La&st Tab"), parent);
-	mViewActions[menu_view_last_tab]->setStatusTip(QObject::tr("Switch to last tab"));
-
 	mViewActions[menu_view_opacity_change] = new QAction(QObject::tr("&Change Opacity"), parent);
 	mViewActions[menu_view_opacity_change]->setShortcut(QKeySequence(shortcut_opacity_change));
 	mViewActions[menu_view_opacity_change]->setStatusTip(QObject::tr("change the window opacity"));
@@ -1364,8 +1354,11 @@ void DkActionManager::createActions(QWidget* parent) {
 	mViewActions[menu_view_movie_next] = new QAction(mViewIcons[icon_view_movie_next], QObject::tr("&Next Frame"), parent);
 	mViewActions[menu_view_movie_next]->setStatusTip(QObject::tr("show next frame"));
 
-	mViewActions[menu_view_gps_map] = new QAction(mViewIcons[icon_view_gps], QObject::tr("Show G&PS Coordinates"), parent);
-	mViewActions[menu_view_gps_map]->setStatusTip(QObject::tr("shows the GPS coordinates"));
+	mViewActions[menu_view_monitors] = new QAction(QObject::tr("Choose &Monitor"), parent);
+	mViewActions[menu_view_monitors]->setStatusTip(QObject::tr("Choose the Monitor to run nomacs"));
+
+	mViewActions[menu_view_gps_map] = new QAction(mViewIcons[icon_view_gps], QObject::tr("Show Image Location"), parent);
+	mViewActions[menu_view_gps_map]->setStatusTip(QObject::tr("shows where the image was taken in Google maps"));
 	mViewActions[menu_view_gps_map]->setEnabled(false);
 
 	// tools actions
@@ -1414,16 +1407,18 @@ void DkActionManager::createActions(QWidget* parent) {
 
 	mHelpActions[menu_help_update] = new QAction(QObject::tr("&Check for Updates"), parent);
 	mHelpActions[menu_help_update]->setStatusTip(QObject::tr("check for updates"));
+	mHelpActions[menu_help_update]->setDisabled(DkSettingsManager::param().sync().disableUpdateInteraction);
 
 	mHelpActions[menu_help_update_translation] = new QAction(QObject::tr("&Update Translation"), parent);
 	mHelpActions[menu_help_update_translation]->setStatusTip(QObject::tr("Checks for a new version of the translations of the current language"));
+	mHelpActions[menu_help_update_translation]->setDisabled(DkSettingsManager::param().sync().disableUpdateInteraction);
 
 	// sync actions
 	mSyncActions.resize(menu_sync_end);
-	mSyncActions[menu_sync] = new QAction(QObject::tr("Synchronize &View"), parent);
-	mSyncActions[menu_sync]->setShortcut(QKeySequence(shortcut_sync));
-	mSyncActions[menu_sync]->setStatusTip(QObject::tr("synchronize the current view"));
-	mSyncActions[menu_sync]->setEnabled(false);
+	mSyncActions[menu_sync_view] = new QAction(QObject::tr("Synchronize &View"), parent);
+	mSyncActions[menu_sync_view]->setShortcut(QKeySequence(shortcut_sync));
+	mSyncActions[menu_sync_view]->setStatusTip(QObject::tr("synchronize the current view"));
+	mSyncActions[menu_sync_view]->setEnabled(false);
 
 	mSyncActions[menu_sync_pos] = new QAction(QObject::tr("&Window Overlay"), parent);
 	mSyncActions[menu_sync_pos]->setShortcut(QKeySequence(shortcut_tab));
@@ -1445,28 +1440,6 @@ void DkActionManager::createActions(QWidget* parent) {
 	mSyncActions[menu_sync_all_actions]->setCheckable(true);
 	mSyncActions[menu_sync_all_actions]->setChecked(DkSettingsManager::param().sync().syncActions);
 
-	mSyncActions[menu_sync_remote_control] = new QAction(QObject::tr("&Remote Control"), parent);
-	//syncActions[menu_sync_remote_control]->setShortcut(QKeySequence(shortcut_connect_all));
-	mSyncActions[menu_sync_remote_control]->setStatusTip(QObject::tr("Automatically Receive Images From Your Remote Instance."));
-	mSyncActions[menu_sync_remote_control]->setCheckable(true);
-
-	mSyncActions[menu_sync_remote_display] = new QAction(QObject::tr("Remote &Display"), parent);
-	mSyncActions[menu_sync_remote_display]->setStatusTip(QObject::tr("Automatically Send Images to a Remote Instance."));
-	mSyncActions[menu_sync_remote_display]->setCheckable(true);
-
-	mLanActions.resize(menu_lan_end);
-
-	// start server action
-	mLanActions[menu_lan_server] = new QAction(QObject::tr("Start &Server"), parent);
-	mLanActions[menu_lan_server]->setObjectName("serverAction");
-	mLanActions[menu_lan_server]->setCheckable(true);
-	mLanActions[menu_lan_server]->setChecked(false);
-
-	mLanActions[menu_lan_image] = new QAction(QObject::tr("Send &Image"), parent);
-	mLanActions[menu_lan_image]->setObjectName("sendImageAction");
-	mLanActions[menu_lan_image]->setShortcut(QKeySequence(shortcut_send_img));
-	mLanActions[menu_lan_image]->setToolTip(QObject::tr("Sends the current image to all clients."));
-
 	// plugin actions
 	mPluginActions.resize(menu_plugins_end);
 	mPluginActions[menu_plugin_manager] = new QAction(QObject::tr("&Plugin Manager"), parent);
@@ -1485,7 +1458,7 @@ void DkActionManager::createActions(QWidget* parent) {
 	mPreviewActions[preview_zoom_out] = new QAction(DkImage::loadIcon(":/nomacs/img/zoom-out.svg"), QObject::tr("Zoom &Out"), parent);
 	mPreviewActions[preview_zoom_out]->setShortcut(QKeySequence::ZoomOut);
 
-	mPreviewActions[preview_display_squares] = new QAction(DkImage::loadIcon(":/nomacs/img/thumbs-view.svg"), QObject::tr("Display &Squares"), parent);
+	mPreviewActions[preview_display_squares] = new QAction(DkImage::loadIcon(":/nomacs/img/rects.svg"), QObject::tr("Display &Squares"), parent);
 	mPreviewActions[preview_display_squares]->setCheckable(true);
 	mPreviewActions[preview_display_squares]->setChecked(DkSettingsManager::param().display().displaySquaredThumbs);
 
@@ -1512,6 +1485,10 @@ void DkActionManager::createActions(QWidget* parent) {
 	mPreviewActions[preview_batch]->setToolTip(QObject::tr("Adds selected files to batch processing."));
 	mPreviewActions[preview_batch]->setShortcut(QKeySequence(Qt::Key_B));
 
+	mPreviewActions[preview_print] = new QAction(DkImage::loadIcon(":/nomacs/img/printer.svg"), QObject::tr("&Batch Print"), parent);
+	mPreviewActions[preview_print]->setToolTip(QObject::tr("Prints selected files."));
+	mPreviewActions[preview_print]->setShortcut(QKeySequence::Print);
+
 	// hidden actions
 	mHiddenActions.resize(sc_end);
 
@@ -1563,6 +1540,46 @@ void DkActionManager::createActions(QWidget* parent) {
 	mHiddenActions[sc_delete_silent]->setStatusTip(QObject::tr("Deletes a file without warning"));
 	mHiddenActions[sc_delete_silent]->setShortcut(QKeySequence(shortcut_delete_silent));
 
+	mHiddenActions[sc_star_rating_0] = new QAction(QObject::tr("Star Rating 0"), parent);
+	mHiddenActions[sc_star_rating_0]->setStatusTip(QObject::tr("Star rating which is saved to an image's metadata"));
+	mHiddenActions[sc_star_rating_0]->setShortcut(QKeySequence(shortcut_star_rating_0));
+
+	mHiddenActions[sc_star_rating_1] = new QAction(QObject::tr("Star Rating 1"), parent);
+	mHiddenActions[sc_star_rating_1]->setStatusTip(QObject::tr("Star rating which is saved to an image's metadata"));
+	mHiddenActions[sc_star_rating_1]->setShortcut(QKeySequence(shortcut_star_rating_1));
+
+	mHiddenActions[sc_star_rating_2] = new QAction(QObject::tr("Star Rating 2"), parent);
+	mHiddenActions[sc_star_rating_2]->setStatusTip(QObject::tr("Star rating which is saved to an image's metadata"));
+	mHiddenActions[sc_star_rating_2]->setShortcut(QKeySequence(shortcut_star_rating_2));
+
+	mHiddenActions[sc_star_rating_3] = new QAction(QObject::tr("Star Rating 3"), parent);
+	mHiddenActions[sc_star_rating_3]->setStatusTip(QObject::tr("Star rating which is saved to an image's metadata"));
+	mHiddenActions[sc_star_rating_3]->setShortcut(QKeySequence(shortcut_star_rating_3));
+
+	mHiddenActions[sc_star_rating_4] = new QAction(QObject::tr("Star Rating 4"), parent);
+	mHiddenActions[sc_star_rating_4]->setStatusTip(QObject::tr("Star rating which is saved to an image's metadata"));
+	mHiddenActions[sc_star_rating_4]->setShortcut(QKeySequence(shortcut_star_rating_4));
+
+	mHiddenActions[sc_star_rating_5] = new QAction(QObject::tr("Star Rating 5"), parent);
+	mHiddenActions[sc_star_rating_5]->setStatusTip(QObject::tr("Star rating which is saved to an image's metadata"));
+	mHiddenActions[sc_star_rating_5]->setShortcut(QKeySequence(shortcut_star_rating_5));
+
+	mHiddenActions[sc_pan_up] = new QAction(QObject::tr("Pan Image Up"), parent);
+	mHiddenActions[sc_pan_up]->setStatusTip(QObject::tr("Pans the image up if zoomed."));
+	mHiddenActions[sc_pan_up]->setShortcut(QKeySequence(shortcut_pan_up));
+
+	mHiddenActions[sc_pan_down] = new QAction(QObject::tr("Pan Image Down"), parent);
+	mHiddenActions[sc_pan_down]->setStatusTip(QObject::tr("Pans the image down if zoomed."));
+	mHiddenActions[sc_pan_down]->setShortcut(QKeySequence(shortcut_pan_down));
+
+	mHiddenActions[sc_pan_left] = new QAction(QObject::tr("Pan Image Left"), parent);
+	mHiddenActions[sc_pan_left]->setStatusTip(QObject::tr("Pans the image left if zoomed."));
+	mHiddenActions[sc_pan_left]->setShortcut(QKeySequence(shortcut_pan_left));
+
+	mHiddenActions[sc_pan_right] = new QAction(QObject::tr("Pan Image Right"), parent);
+	mHiddenActions[sc_pan_right]->setStatusTip(QObject::tr("Pans the image right if zoomed."));
+	mHiddenActions[sc_pan_right]->setShortcut(QKeySequence(shortcut_pan_right));
+
 	mManipulators.createManipulators(parent);
 
 	assignCustomShortcuts(allActions());
@@ -1572,6 +1589,11 @@ void DkActionManager::createActions(QWidget* parent) {
 		a->setToolTip(a->statusTip());
 		a->setShortcutContext(Qt::WidgetWithChildrenShortcut);
 	}
+	
+	// trivial connects
+	auto a = action(menu_panel_toggle);
+	QObject::connect(a, &QAction::triggered,
+		[a]() { DkSettingsManager::param().app().hideAllPanels = a->isChecked(); });
 }
 
 QVector<QAction*> DkActionManager::allActions() const {
@@ -1587,7 +1609,6 @@ QVector<QAction*> DkActionManager::allActions() const {
 	all += panelActions();
 	all += syncActions();
 	all += pluginActions();
-	all += lanActions();
 	all += helpActions();
 	all += previewActions();
 
@@ -1602,7 +1623,14 @@ void DkActionManager::assignCustomShortcuts(QVector<QAction*> actions) const {
 	settings.beginGroup("CustomShortcuts");
 
 	for (QAction* a : actions) {
-		QString val = settings.value(a->text(), "no-shortcut").toString();
+
+		if (!a) {
+			qWarning() << "NULL action detected!";
+			continue;
+		}
+
+		QString at = a->text().remove("&");
+		QString val = settings.value(at, "no-shortcut").toString();
 
 		if (val != "no-shortcut")
 			a->setShortcut(val);
@@ -1614,6 +1642,75 @@ void DkActionManager::assignCustomShortcuts(QVector<QAction*> actions) const {
 	settings.endGroup();
 }
 
+void DkActionManager::enableImageActions(bool enable) const {
+	
+	action(DkActionManager::menu_file_save)->setEnabled(enable);
+	action(DkActionManager::menu_file_save_as)->setEnabled(enable);
+	action(DkActionManager::menu_file_save_list)->setEnabled(enable);
+	action(DkActionManager::menu_file_save_web)->setEnabled(enable);
+	action(DkActionManager::menu_file_rename)->setEnabled(enable);
+	action(DkActionManager::menu_file_print)->setEnabled(enable);
+	action(DkActionManager::menu_file_reload)->setEnabled(enable);
+	action(DkActionManager::menu_file_prev)->setEnabled(enable);
+	action(DkActionManager::menu_file_next)->setEnabled(enable);
+	action(DkActionManager::menu_file_goto)->setEnabled(enable);
+	action(DkActionManager::menu_file_find)->setEnabled(enable);
+
+	action(DkActionManager::menu_edit_rotate_cw)->setEnabled(enable);
+	action(DkActionManager::menu_edit_rotate_ccw)->setEnabled(enable);
+	action(DkActionManager::menu_edit_rotate_180)->setEnabled(enable);
+	action(DkActionManager::menu_edit_delete)->setEnabled(enable);
+	action(DkActionManager::menu_edit_transform)->setEnabled(enable);
+	action(DkActionManager::menu_edit_crop)->setEnabled(enable);
+	action(DkActionManager::menu_edit_copy)->setEnabled(enable);
+	action(DkActionManager::menu_edit_copy_buffer)->setEnabled(enable);
+	action(DkActionManager::menu_edit_copy_color)->setEnabled(enable);
+	action(DkActionManager::menu_edit_undo)->setEnabled(enable);
+	action(DkActionManager::menu_edit_redo)->setEnabled(enable);
+
+
+	action(DkActionManager::menu_panel_info)->setEnabled(enable);
+#ifdef WITH_OPENCV
+	action(DkActionManager::menu_panel_histogram)->setEnabled(enable);
+#else
+	action(DkActionManager::menu_panel_histogram)->setEnabled(false);
+#endif
+	action(DkActionManager::menu_panel_scroller)->setEnabled(enable);
+	action(DkActionManager::menu_panel_comment)->setEnabled(enable);
+	action(DkActionManager::menu_panel_preview)->setEnabled(enable);
+	action(DkActionManager::menu_panel_exif)->setEnabled(enable);
+	action(DkActionManager::menu_panel_overview)->setEnabled(enable);
+	action(DkActionManager::menu_panel_player)->setEnabled(enable);
+	action(DkActionManager::menu_panel_thumbview)->setEnabled(enable);
+
+	action(DkActionManager::menu_view_slideshow)->setEnabled(enable);
+	action(DkActionManager::menu_view_fullscreen)->setEnabled(enable);
+	action(DkActionManager::menu_view_reset)->setEnabled(enable);
+	action(DkActionManager::menu_view_100)->setEnabled(enable);
+	action(DkActionManager::menu_view_fit_frame)->setEnabled(enable);
+	action(DkActionManager::menu_view_zoom_in)->setEnabled(enable);
+	action(DkActionManager::menu_view_zoom_out)->setEnabled(enable);
+	action(DkActionManager::menu_view_tp_pattern)->setEnabled(enable);
+	action(DkActionManager::menu_view_anti_aliasing)->setEnabled(enable);
+
+	action(DkActionManager::menu_tools_wallpaper)->setEnabled(enable);
+	action(DkActionManager::menu_tools_thumbs)->setEnabled(enable);
+
+	// hidden actions
+	action(DkActionManager::sc_skip_prev)->setEnabled(enable);
+	action(DkActionManager::sc_skip_prev_sync)->setEnabled(enable);
+	action(DkActionManager::sc_skip_next)->setEnabled(enable);
+	action(DkActionManager::sc_skip_next_sync)->setEnabled(enable);
+	action(DkActionManager::sc_first_file)->setEnabled(enable);
+	action(DkActionManager::sc_first_file_sync)->setEnabled(enable);
+	action(DkActionManager::sc_last_file)->setEnabled(enable);
+	action(DkActionManager::sc_last_file_sync)->setEnabled(enable);
+
+	// disable open with actions
+	for (QAction* a : DkActionManager::instance().appManager()->getActions())
+		a->setEnabled(enable);
+}
+
 // DkGlobalProgress --------------------------------------------------------------------
 DkGlobalProgress::DkGlobalProgress() : showProgress(true) {
 #ifdef Q_OS_WIN
