@@ -41,7 +41,7 @@
 
 // quazip
 #ifdef WITH_QUAZIP
-#include <quazip/JlCompress.h>
+#include <quazip5/JlCompress.h>
 #endif
 #pragma warning(pop)		// no warnings from includes - end
 
@@ -372,6 +372,18 @@ bool DkImageContainer::hasImage() const {
 	return mLoader->hasImage();
 }
 
+bool DkImageContainer::hasMovie() const {
+
+	QString newSuffix = QFileInfo(filePath()).suffix();
+	return newSuffix.contains(QRegExp("(gif|mng|webp)", Qt::CaseInsensitive)) != 0;
+}
+
+bool DkImageContainer::hasSvg() const {
+
+	QString newSuffix = QFileInfo(filePath()).suffix();
+	return newSuffix.contains(QRegExp("(svg)", Qt::CaseInsensitive)) != 0;
+}
+
 int DkImageContainer::getLoadState() const {
 
 	return mLoadState;
@@ -869,7 +881,7 @@ void DkImageContainerT::receiveUpdates(QObject* obj, bool connectSignals /* = tr
 		connect(this, SIGNAL(errorDialogSignal(const QString&)), obj, SLOT(errorDialog(const QString&)), Qt::UniqueConnection);
 		connect(this, SIGNAL(fileLoadedSignal(bool)), obj, SLOT(imageLoaded(bool)), Qt::UniqueConnection);
 		connect(this, SIGNAL(showInfoSignal(const QString&, int, int)), obj, SIGNAL(showInfoSignal(const QString&, int, int)), Qt::UniqueConnection);
-		connect(this, SIGNAL(fileSavedSignal(const QString&, bool)), obj, SLOT(imageSaved(const QString&, bool)), Qt::UniqueConnection);
+		connect(this, SIGNAL(fileSavedSignal(const QString&, bool, bool)), obj, SLOT(imageSaved(const QString&, bool, bool)), Qt::UniqueConnection);
 		connect(this, SIGNAL(imageUpdatedSignal()), obj, SLOT(currentImageUpdated()), Qt::UniqueConnection);
 		mFileUpdateTimer.start();
 	}
@@ -877,7 +889,7 @@ void DkImageContainerT::receiveUpdates(QObject* obj, bool connectSignals /* = tr
 		disconnect(this, SIGNAL(errorDialogSignal(const QString&)), obj, SLOT(errorDialog(const QString&)));
 		disconnect(this, SIGNAL(fileLoadedSignal(bool)), obj, SLOT(imageLoaded(bool)));
 		disconnect(this, SIGNAL(showInfoSignal(const QString&, int, int)), obj, SIGNAL(showInfoSignal(const QString&, int, int)));
-		disconnect(this, SIGNAL(fileSavedSignal(const QString&, bool)), obj, SLOT(imageSaved(const QString&, bool)));
+		disconnect(this, SIGNAL(fileSavedSignal(const QString&, bool, bool)), obj, SLOT(imageSaved(const QString&, bool, bool)));
 		disconnect(this, SIGNAL(imageUpdatedSignal()), obj, SLOT(currentImageUpdated()));
 		mFileUpdateTimer.stop();
 	}
@@ -952,14 +964,23 @@ void DkImageContainerT::savingFinished() {
 
 		if (mFileBuffer)
 			mFileBuffer->clear();	// do a complete clear?
-		setFilePath(savePath);
+		
+		if (DkSettingsManager::param().resources().loadSavedImage == DkSettings::ls_load || 
+			filePath().isEmpty() || dirPath() == sInfo.absolutePath()) {
+			setFilePath(savePath);
+
+			emit fileSavedSignal(savePath, true, false);
+		}
+		else {
+			emit fileSavedSignal(savePath);
+		}
+
 		mEdited = false;
 		mDownloaded = false;
 		if (mSelected) {
 			loadImageThreaded(true);	// force a reload
 			mFileUpdateTimer.start();
 		}
-		emit fileSavedSignal(savePath);
 	}
 }
 
