@@ -73,10 +73,11 @@
 #include <QPainter>
 #include <qmath.h>
 #include <QtConcurrentRun>
+#include <QStandardPaths>
 
 // quazip
 #ifdef WITH_QUAZIP
-#include <quazip/JlCompress.h>
+#include <quazip5/JlCompress.h>
 #endif
 
 // opencv
@@ -153,9 +154,10 @@ void DkImageLoader::clearPath() {
 		mCurrentImage->receiveUpdates(this, false);
 		mLastImageLoaded = mCurrentImage;
 		mImages.clear();
-	}
 
-	mCurrentImage.clear();
+		// only clear the current image if it exists
+		mCurrentImage.clear();
+	}
 }
 
 #ifdef WITH_QUAZIP
@@ -733,7 +735,7 @@ bool DkImageLoader::unloadFile() {
 		return true;
 
 	// if we are either in rc or remote display mode & the directory does not exist - we received an image, so don't ask the user
-	if (mCurrentImage->isEdited() && (DkSettingsManager::param().sync().syncMode == DkSettings::sync_mode_default)) {
+	if (mCurrentImage->isEdited()) {
 		DkMessageBox* msgBox = new DkMessageBox(
 			QMessageBox::Question, 
 			tr("Save Image"), 
@@ -746,7 +748,6 @@ bool DkImageLoader::unloadFile() {
 
 		int answer = msgBox->exec();
 
-		// TODO: Save As dialog for unsupported files
 		if (answer == QMessageBox::Accepted || answer == QMessageBox::Yes) {
 			
 			if (DkUtils::isSavable(mCurrentImage->fileInfo().fileName()))
@@ -790,6 +791,8 @@ void DkImageLoader::activate(bool isActive /* = true */) {
 		blockSignals(false);
 		setCurrentImage(mLastImageLoaded);
 	}
+	else
+		emit updateDirSignal(mImages);
 }
 
 void DkImageLoader::setCurrentImage(QSharedPointer<DkImageContainerT> newImg) {
@@ -971,10 +974,6 @@ void DkImageLoader::downloadFile(const QUrl& url) {
  **/ 
 QString DkImageLoader::saveTempFile(const QImage& img, const QString& name, const QString& fileExt, bool force, bool threaded) {
 
-	// do not save temp images if we are remote control or remote display
-	if (DkSettingsManager::param().sync().syncMode != DkSettings::sync_mode_default)
-		return QString();
-
 	QFileInfo tmpPath = QFileInfo(DkSettingsManager::param().global().tmpPath + "\\");
 	
 	if (!force && (!DkSettingsManager::param().global().useTmpPath || !tmpPath.exists())) {
@@ -983,15 +982,7 @@ QString DkImageLoader::saveTempFile(const QImage& img, const QString& name, cons
 	}
 	else if ((!DkSettingsManager::param().global().useTmpPath || !tmpPath.exists())) {
 
-#ifdef Q_OS_WIN
-		
-		// TODO: this path seems to be perfectly ok (you can copy it to windows explorer) - however Qt thinks it does not exist??
-		QString defaultPath = getenv("HOMEPATH");
-		defaultPath = "C:" + defaultPath + "\\My Pictures\\";
-		tmpPath = defaultPath;
-
-		qDebug() << "default path: " << tmpPath.absoluteFilePath();
-#endif
+		tmpPath = QStandardPaths::writableLocation(QStandardPaths::PicturesLocation);
 
 		if (!tmpPath.isDir()) {
 			// load system default open dialog
@@ -1118,7 +1109,6 @@ void DkImageLoader::saveUserFileAs(const QImage& saveImg, bool silent) {
 			(QMessageBox::Yes | QMessageBox::No), dialogParent);
 		msg->setObjectName("overwriteDialog");
 
-		//msg->show();
 		answer = msg->exec();
 
 	}
@@ -1166,6 +1156,7 @@ void DkImageLoader::saveUserFileAs(const QImage& saveImg, bool silent) {
 
 		jpgDialog->imageHasAlpha(saveImg.hasAlphaChannel());
 		jpgDialog->setImage(saveImg);
+		jpgDialog->setMinimumSize(450, 150);
 
 		if (!jpgDialog->exec()) {
 			jpgDialog->deleteLater();
@@ -1184,8 +1175,6 @@ void DkImageLoader::saveUserFileAs(const QImage& saveImg, bool silent) {
 
 			lSaveImg = tmpImg;
 		}
-
-		//	qDebug() << "returned: " << ret;
 	}
 
 	if (selectedFilter.contains("webp")) {
@@ -1271,7 +1260,6 @@ void DkImageLoader::saveFile(const QString& filePath, const QImage& saveImg, con
 	bool saveStarted = (threaded) ? imgC->saveImageThreaded(lFilePath, sImg, compression) : imgC->saveImage(lFilePath, sImg, compression);
 
 	if (!saveStarted) {
-		mDirWatcher->blockSignals(false);
 		imageSaved(QString(), false);
 	}
 	else if (saveStarted && !threaded) {
@@ -1279,7 +1267,7 @@ void DkImageLoader::saveFile(const QString& filePath, const QImage& saveImg, con
 	}
 }
 
-void DkImageLoader::imageSaved(const QString& filePath, bool saved) {
+void DkImageLoader::imageSaved(const QString& filePath, bool saved, bool loadToTab) {
 
 	emit updateSpinnerSignalDelayed(false);
 	mDirWatcher->blockSignals(false);
@@ -1288,12 +1276,17 @@ void DkImageLoader::imageSaved(const QString& filePath, bool saved) {
 	if (!fInfo.exists() || !fInfo.isFile() || !saved)
 		return;
 
-	mFolderUpdated = true;
-	loadDir(mCurrentImage->dirPath());
+	if (DkSettingsManager::instance().param().resources().loadSavedImage == DkSettings::ls_load_to_tab && loadToTab) {
+		emit loadImageToTab(filePath);
+	}
+	else if (DkSettingsManager::instance().param().resources().loadSavedImage == DkSettings::ls_load) {
+		//mFolderUpdated = true;
+		//loadDir(mCurrentImage->dirPath());
 
-	emit imageLoadedSignal(mCurrentImage, true);
-	emit imageUpdatedSignal(mCurrentImage);
-	qDebug() << "image updated: " << mCurrentImage->fileName();
+		emit imageLoadedSignal(mCurrentImage, true);
+		emit imageUpdatedSignal(mCurrentImage);
+		qDebug() << "image updated: " << mCurrentImage->fileName();
+	}
 }
 
 /**
@@ -1313,13 +1306,12 @@ void DkImageLoader::updateHistory() {
 	// sync with other instances
 	DefaultSettings settings;
 	settings.beginGroup("GlobalSettings");
-	DkSettingsManager::param().global().recentFolders = settings.value("recentFolders", DkSettingsManager::param().global().recentFolders).toStringList();
-	DkSettingsManager::param().global().recentFiles = settings.value("recentFiles", DkSettingsManager::param().global().recentFiles).toStringList();
+	QStringList rFolders = settings.value("recentFolders", DkSettingsManager::param().global().recentFolders).toStringList();
+	QStringList rFiles = settings.value("recentFiles", DkSettingsManager::param().global().recentFiles).toStringList();
+	settings.endGroup();
 
-	DkSettingsManager::param().global().lastDir = file.absolutePath();
-
-	DkSettingsManager::param().global().recentFiles.removeAll(file.absoluteFilePath());
-	DkSettingsManager::param().global().recentFolders.removeAll(file.absolutePath());
+	rFiles.removeAll(file.absoluteFilePath());
+	rFolders.removeAll(file.absolutePath());
 
 	QStringList tmpRecentFiles;
 
@@ -1334,26 +1326,33 @@ void DkImageLoader::updateHistory() {
 
 	// maximum 5 most recent images from the same folder
 	for (int idx = tmpRecentFiles.size()-1; idx > 3; idx--) {
-		DkSettingsManager::param().global().recentFiles.removeAll(tmpRecentFiles.at(idx));
+		rFiles.removeAll(tmpRecentFiles.at(idx));
 	}
 
-	DkSettingsManager::param().global().recentFiles.push_front(file.absoluteFilePath());
-	DkSettingsManager::param().global().recentFolders.push_front(file.absolutePath());
+	rFiles.push_front(file.absoluteFilePath());
+	rFolders.push_front(file.absolutePath());
 
-	DkSettingsManager::param().global().recentFiles.removeDuplicates();
-	DkSettingsManager::param().global().recentFolders.removeDuplicates();
+	rFiles.removeDuplicates();
+	rFolders.removeDuplicates();
 
-	for (int idx = 0; idx < DkSettingsManager::param().global().recentFiles.size()-DkSettingsManager::param().global().numFiles-10; idx++)
-		DkSettingsManager::param().global().recentFiles.pop_back();
+	for (int idx = 0; idx < rFiles.size()-DkSettingsManager::param().global().numFiles-10; idx++)
+		rFiles.pop_back();
 
-	for (int idx = 0; idx < DkSettingsManager::param().global().recentFolders.size()-DkSettingsManager::param().global().numFiles-10; idx++)
-		DkSettingsManager::param().global().recentFolders.pop_back();
+	for (int idx = 0; idx < rFolders.size()-DkSettingsManager::param().global().numFiles-10; idx++)
+		rFolders.pop_back();
 
 	// sync with other instances
-	settings.setValue("recentFolders", DkSettingsManager::param().global().recentFolders);
-	settings.setValue("recentFiles", DkSettingsManager::param().global().recentFiles);
+	settings.beginGroup("GlobalSettings");
+	settings.setValue("recentFolders", rFolders);
+	settings.setValue("recentFiles", rFiles);
 	settings.endGroup();
 
+	// update
+	DkSettingsManager::param().global().lastDir = file.absolutePath();
+	DkSettingsManager::param().global().recentFiles = rFiles;
+	DkSettingsManager::param().global().recentFolders = rFolders;
+
+
 	//DkSettings s = DkSettings();
 	//s.save();
 }
@@ -1532,9 +1531,7 @@ bool DkImageLoader::hasMovie() const {
 	if (!mCurrentImage || !mCurrentImage->exists())
 		return false;
 
-	QString newSuffix = QFileInfo(mCurrentImage->filePath()).suffix();
-	return newSuffix.contains(QRegExp("(gif|mng)", Qt::CaseInsensitive)) != 0;
-
+	return mCurrentImage->hasMovie();
 }
 
 bool DkImageLoader::hasSvg() const {
@@ -1542,9 +1539,7 @@ bool DkImageLoader::hasSvg() const {
 	if (!mCurrentImage || !mCurrentImage->exists())
 		return false;
 
-	QString newSuffix = QFileInfo(mCurrentImage->filePath()).suffix();
-	return newSuffix.contains(QRegExp("(svg)", Qt::CaseInsensitive)) != 0;
-
+	return mCurrentImage->hasSvg();
 }
 
 /**
