@@ -66,7 +66,7 @@ QImage DkImage::fromWinHBITMAP(HDC hdc, HBITMAP bitmap, int w, int h) {
 	bmi.bmiHeader.biCompression = BI_RGB;
 	bmi.bmiHeader.biSizeImage   = w * h * 4;
 
-	QImage image(w, h, QImage::Format_ARGB32_Premultiplied);
+	QImage image(w, h, QImage::Format_ARGB32);
 	if (image.isNull())
 		return image;
 
@@ -403,7 +403,7 @@ QImage DkImage::resizeImage(const QImage& img, const QSize& newSize, double fact
 	
 bool DkImage::alphaChannelUsed(const QImage& img) {
 
-	if (img.format() != QImage::Format_ARGB32 && img.format() != QImage::Format_ARGB32_Premultiplied)
+	if (img.format() != QImage::Format_ARGB32 && img.format() != QImage::Format_ARGB32)
 		return false;
 
 	// number of used bytes per line
@@ -692,7 +692,7 @@ bool DkImage::autoAdjustImage(QImage& img) {
 		qDebug() << "[Auto Adjust] Grayscale - switching to Normalize: " << img.format();
 		return normImage(img);
 	}
-	else if (img.format() != QImage::Format_ARGB32 && img.format() != QImage::Format_ARGB32_Premultiplied && 
+	else if (img.format() != QImage::Format_ARGB32 && img.format() != QImage::Format_ARGB32 && 
 		img.format() != QImage::Format_RGB32 && img.format() != QImage::Format_RGB888) {
 		qDebug() << "[Auto Adjust] Format not supported: " << img.format();
 		return false;
@@ -1005,6 +1005,121 @@ QImage DkImage::exposure(const QImage & src, double exposure, double offset, dou
 	return imgR;
 }
 
+QImage DkImage::bgColor(const QImage & src, const QColor & col) {
+
+	QImage dst(src.size(), QImage::Format_RGB32);
+	dst.fill(col);
+
+	QPainter p(&dst);
+	p.drawImage(QPoint(0, 0), src);
+
+	return dst;
+}
+
+QByteArray DkImage::extractImageFromDataStream(const QByteArray & ba, const QByteArray & beginSignature, const QByteArray & endSignature, bool debugOutput) {
+	
+	
+	int bIdx = ba.indexOf(beginSignature);
+
+	if (bIdx == -1) {
+		qDebug() << "[ExtractImage] could not locate" << beginSignature;
+		return QByteArray();
+	}
+
+	int eIdx = ba.indexOf(endSignature, bIdx);
+
+	if (eIdx == -1) {
+		qDebug() << "[ExtractImage] could not locate" << endSignature;
+		return QByteArray();
+	}
+
+	QByteArray bac = ba.mid(bIdx, eIdx + endSignature.size() - bIdx);
+
+	if (debugOutput) {
+		qDebug() << "extracting image from stream...";
+		qDebug() << "cropping: [" << bIdx << eIdx << "]";
+		qDebug() << "original size: " << ba.size()/1024.0 << "KB" << "new size: " << bac.size()/1024.0 << "KB" << "difference:" << (ba.size()-bac.size())/1024 << "KB";
+	}
+
+	return bac;
+}
+
+QByteArray DkImage::fixSamsungPanorama(QByteArray & ba) {
+
+	// this code is based on python code from bcyrill
+	// see: https://gist.github.com/bcyrill/e59fda6c7ffe23c7c4b08a990804b269
+	// it fixes SAMSUNG panorama images that are not standard conformant by adding an EOI marker to the QByteArray
+	// see also: https://github.com/nomacs/nomacs/issues/254
+
+	if (ba.size() < 8)
+		return QByteArray();
+
+	QByteArray trailer = ba.right(4);
+
+	// is it a samsung panorama jpg?
+	if (trailer != QByteArray("SEFT"))
+		return QByteArray();
+
+	// TODO saveify:
+	int sefhPos = intFromByteArray(ba, ba.size() - 8) + 8;
+	trailer = ba.right(sefhPos);
+
+	// trailer starts with "SEFH"?
+	if (trailer.left(4) != QByteArray("SEFH"))
+		return QByteArray();
+
+	int endPos = ba.size();
+	int dirPos = endPos - sefhPos;
+
+	int count = intFromByteArray(trailer, 8);
+
+	int firstBlock = 0;
+	bool isPano = false;
+
+	for (int idx = 0; idx < count; idx++) {
+
+		int e = 12 + 12 * idx;
+
+		int noff = intFromByteArray(trailer, e + 4);
+		int size = intFromByteArray(trailer, e + 8);
+
+		if (firstBlock < noff)
+			firstBlock = noff;
+
+		QByteArray cdata = ba.mid(dirPos - noff, size);
+
+		int eoff = intFromByteArray(cdata, 4);
+		QString pi = cdata.mid(8, eoff);
+
+		if (pi == "Panorama_Shot_Info")
+			isPano = true;
+	}
+
+	if (!isPano)
+		return QByteArray();
+
+	int dataPos = dirPos - firstBlock;
+
+	// ok, append the missing marker
+	QByteArray nb;
+	nb.append(ba.left(dataPos));
+	nb.append(QByteArray("\xff\xd9"));
+	nb.append(ba.right(dataPos));
+	qDebug() << "SAMSUNG panorma fix: EOI marker injected";
+
+	return nb;
+
+}
+
+int DkImage::intFromByteArray(const QByteArray & ba, int pos) {
+
+	// TODO saveify:
+	QByteArray tmp = ba.mid(pos, 4);
+	const int* val = (const int*)(tmp.constData());
+
+	return *val;
+}
+
 #ifdef WITH_OPENCV
 cv::Mat DkImage::exposureMat(const cv::Mat& src, double exposure) {
 
@@ -1115,7 +1230,7 @@ QPixmap DkImage::colorizePixmap(const QPixmap& icon, const QColor& col, float op
 	return glow;
 }
 
-QPixmap DkImage::loadIcon(const QString & filePath, const QSize& size) {
+QPixmap DkImage::loadIcon(const QString & filePath, const QSize& size, const QColor& col) {
 	
 	if (filePath.isEmpty())
 		return QPixmap();
@@ -1128,7 +1243,8 @@ QPixmap DkImage::loadIcon(const QString & filePath, const QSize& size) {
 
 	QPixmap icon = loadFromSvg(filePath, s);
 	
-	icon = colorizePixmap(icon, DkSettingsManager::param().display().iconColor);
+	QColor c = (col.isValid()) ? col : DkSettingsManager::param().display().iconColor;
+	icon = colorizePixmap(icon, c);
 
 	return icon;
 }
@@ -1176,8 +1292,8 @@ cv::Mat DkImage::qImage2Mat(const QImage& img) {
 	QImage cImg;	// must be initialized here!	(otherwise the data is lost before clone())
 
 	try {
-		if (img.format() == QImage::Format_RGB32)
-			qDebug() << "we have an RGB32 in memory...";
+		//if (img.format() == QImage::Format_RGB32)
+		//	qDebug() << "we have an RGB32 in memory...";
 
 		if (img.format() == QImage::Format_ARGB32 || img.format() == QImage::Format_RGB32) {
 			mat2 = cv::Mat(img.height(), img.width(), CV_8UC4, (uchar*)img.bits(), img.bytesPerLine());
@@ -1413,18 +1529,21 @@ bool DkImage::unsharpMask(QImage& img, float sigma, float weight) {
 
 	qDebug() << "unsharp mask takes: " << dt;
 	//DkImage::linearToGamma(img);
+#else
+	Q_UNUSED(img);
+	Q_UNUSED(sigma);
+	Q_UNUSED(weight);
 #endif
 
-
 	return true;
 }
 
-QImage DkImage::createThumb(const QImage& image) {
+QImage DkImage::createThumb(const QImage& image, int maxSize) {
 
 	if (image.isNull())
 		return image;
 
-	int maxThumbSize = (int)(max_thumb_size * DkSettingsManager::param().dpiScaleFactor());
+	int maxThumbSize = maxSize == -1 ? (int)(max_thumb_size * DkSettingsManager::param().dpiScaleFactor()) : maxSize;
 	int imgW = image.width();
 	int imgH = image.height();
 
@@ -1452,6 +1571,7 @@ QImage DkImage::createThumb(const QImage& image) {
 	return thumb;
 }
 
+// NOTE: this is just for fun (all images in the world : )
 bool DkImage::addToImage(QImage& img, unsigned char val) {
 
 	// number of bytes per line used
@@ -1541,6 +1661,7 @@ QColor DkImage::getMeanColor(const QImage& img) {
 
 // DkImageStorage --------------------------------------------------------------------
 DkImageStorage::DkImageStorage(const QImage& img) {
+
 	mImg = img;
 
 	mWaitTimer = new QTimer(this);
@@ -1566,6 +1687,8 @@ void DkImageStorage::setImage(const QImage& img) {
 
 	init();
 	mImg = img;
+
+	mComputeState = l_cancelled;
 }
 
 void DkImageStorage::antiAliasingChanged(bool antiAliasing) {
@@ -1580,12 +1703,11 @@ void DkImageStorage::antiAliasingChanged(bool antiAliasing) {
 
 }
 
-QImage DkImageStorage::getImageConst() const {
-	
+QImage DkImageStorage::imageConst() const {
 	return mImg;
 }
 
-QImage DkImageStorage::getImage(double scale) {
+QImage DkImageStorage::image(double scale) {
 
 	if (scale >= 1.0 || mImg.isNull() || !DkSettingsManager::param().display().antiAliasing)
 		return mImg;
@@ -1606,6 +1728,10 @@ QImage DkImageStorage::getImage(double scale) {
 	return mImg;
 }
 
+void DkImageStorage::cancel() {
+	mComputeState = l_cancelled;
+}
+
 void DkImageStorage::compute() {
 
 	if (mComputeState == l_computed) {
@@ -1660,6 +1786,11 @@ QImage DkImageStorage::computeIntern(const QImage & src, double scale) {
 
 void DkImageStorage::imageComputed() {
 
+	if (mComputeState == l_cancelled) {
+		mComputeState = l_not_computed;
+		return;
+	}
+
 	mScaledImg = mFutureWatcher.result();
 
 	mComputeState = (mScaledImg.isNull()) ? l_empty : l_computed;
