@@ -121,10 +121,10 @@ public:
 	static QImage rotateImage(const QImage& img, double angle);
 	static QImage grayscaleImage(const QImage& img);
 	static QPixmap colorizePixmap(const QPixmap& icon, const QColor& col, float opacity = 1.0f);
-	static QPixmap loadIcon(const QString& filePath = QString(), const QSize& size = QSize());
+	static QPixmap loadIcon(const QString& filePath = QString(), const QSize& size = QSize(), const QColor& col = QColor());
 	static QPixmap loadIcon(const QString& filePath, const QColor& col, const QSize& size = QSize());
 	static QPixmap loadFromSvg(const QString& filePath, const QSize& size);
-	static QImage createThumb(const QImage& img);
+	static QImage createThumb(const QImage& img, const int maxSize = -1);
 	static bool addToImage(QImage& img, unsigned char val = 1);
 	static QColor getMeanColor(const QImage& img);
 	static uchar findHistPeak(const int* hist, float quantile = 0.005f);
@@ -133,6 +133,10 @@ public:
 	static QImage cropToImage(const QImage& src, const DkRotatingRect& rect, const QColor& fillColor = QColor());
 	static QImage hueSaturation(const QImage& src, int hue, int sat, int brightness);
 	static QImage exposure(const QImage& src, double exposure, double offset, double gamma);
+	static QImage bgColor(const QImage& src, const QColor& col);
+	static QByteArray extractImageFromDataStream(const QByteArray& ba, const QByteArray& beginSignature = "PNG", const QByteArray& endSignature = "ENDB`", bool debugOutput = false);
+	static QByteArray fixSamsungPanorama(QByteArray& ba);
+	static int intFromByteArray(const QByteArray& ba, int pos);
 	
 #ifdef WITH_OPENCV
 	static cv::Mat exposureMat(const cv::Mat& src, double exposure);
@@ -153,18 +157,24 @@ public:
 		l_computing,
 		l_computed,
 		l_empty,
+		l_cancelled,
 
 		l_end
 	};
 
-	bool hasImage() const {
-		return !mImg.isNull();
-	}
+	bool isEmpty() const {
+		return mImg.isNull();
+	};
+
+	QSize size() const {
+		return mImg.size();
+	};
 
 	void setImage(const QImage& img);
-	QImage getImageConst() const;
-	QImage getImage(double scale = 1.0);
-	
+	QImage imageConst() const;
+	QImage image(double scale = 1.0);
+	void cancel();
+
 public slots:
 	void antiAliasingChanged(bool antiAliasing);
 	void imageComputed();
