@@ -860,6 +860,9 @@ public:
 	void setPoly(QPolygonF &poly);
 	QPolygonF getClosedPoly();
 	QPointF getCenter() const;
+	QPointF getTopLeft() const;
+	void setSize(const QSizeF& s);
+	QSize size() const;
 	void setCenter(const QPointF& center);
 	double getAngle() const;
 	float getAngleDeg() const;
