@@ -30,6 +30,7 @@
 #include "DkMath.h"
 #include "DkImageStorage.h"
 #include "DkSettings.h"
+#include "DkTimer.h"
 
 #pragma warning(push, 0)	// no warnings from includes - begin
 #include <QTranslator>
@@ -75,8 +76,9 @@ void DkMetaDataT::readMetaData(const QString& filePath, QSharedPointer<QByteArra
 		}
 	} 
 	catch (...) {
+		// TODO: check crashes here
 		mExifState = no_data;
-		qDebug() << "[Exiv2] could not open file for exif data";
+		//qDebug() << "[Exiv2] could not open file for exif data";
 		return;
 	}
 	
@@ -96,7 +98,7 @@ void DkMetaDataT::readMetaData(const QString& filePath, QSharedPointer<QByteArra
 			return;
 		}
 
-	}catch (...) {
+	} catch (...) {
 		mExifState = no_data;
 		qDebug() << "[Exiv2] could not read metadata (exception)";
 		return;
@@ -178,10 +180,10 @@ bool DkMetaDataT::saveMetaData(QSharedPointer<QByteArray>& ba, bool force) {
 	exifImgN->setXmpData(xmpData);
 	exifImgN->setIptcData(iptcData);
 
-	// now get the data again
 	exifImgN->writeMetadata();		// TODO: CIMG6206.jpg crashes here...
 
-	Exiv2::DataBuf exifBuf = exifImgN->io().read(exifImgN->io().size());
+	// now get the data again
+	Exiv2::DataBuf exifBuf = exifImgN->io().read((long)exifImgN->io().size());
 	if (exifBuf.pData_) {
 		QSharedPointer<QByteArray> tmp = QSharedPointer<QByteArray>(new QByteArray((const char*)exifBuf.pData_, exifBuf.size_));
 
@@ -649,14 +651,9 @@ QImage DkMetaDataT::getThumbnail() const {
 	try {
 		Exiv2::ExifThumb thumb(exifData);
 		Exiv2::DataBuf buffer = thumb.copy();
-		
-		// ok, get the buffer...
-		std::pair<Exiv2::byte*, long> stdBuf = buffer.release();
-		QByteArray ba = QByteArray((char*)stdBuf.first, (int)stdBuf.second);
-		
-		qThumb.loadFromData(ba);
 
-		delete[] stdBuf.first;
+		QByteArray ba = QByteArray((char*)buffer.pData_, buffer.size_);
+		qThumb.loadFromData(ba);
 	}
 	catch (...) {
 		qDebug() << "Sorry, I could not load the thumb from the exif data...";
@@ -925,14 +922,14 @@ void DkMetaDataT::setThumbnail(QImage thumb) {
 		// ok, let's try to save the thumbnail...
 		Exiv2::ExifThumb eThumb(exifData);
 
-		QByteArray data;
-		QBuffer buffer(&data);
+		QByteArray ba;
+		QBuffer buffer(&ba);
 		buffer.open(QIODevice::WriteOnly);
 		thumb.save(&buffer, "JPEG");	// here we destroy the alpha channel of thumbnails
 
 		try {
 			// whipe all exif data of the thumbnail
-			Exiv2::MemIo::AutoPtr exifBufferThumb(new Exiv2::MemIo((const byte*)data.constData(), data.size()));
+			Exiv2::MemIo::AutoPtr exifBufferThumb(new Exiv2::MemIo((const byte*)ba.constData(), ba.size()));
 			Exiv2::Image::AutoPtr exifImgThumb = Exiv2::ImageFactory::open(exifBufferThumb);
 
 			if (exifImgThumb.get() != 0 && exifImgThumb->good())
@@ -943,7 +940,7 @@ void DkMetaDataT::setThumbnail(QImage thumb) {
 		}
 
 		eThumb.erase();	// erase all thumbnails
-		eThumb.setJpegThumbnail((Exiv2::byte *)data.data(), data.size());
+		eThumb.setJpegThumbnail((Exiv2::byte *)ba.data(), ba.size());
 
 		mExifImg->setExifData(exifData);
 		mExifState = dirty;
@@ -1147,53 +1144,63 @@ bool DkMetaDataT::updateImageMetaData(const QImage& img) {
 
 	success &= setExifValue("Exif.Image.ImageWidth", QString::number(img.width()));
 	success &= setExifValue("Exif.Image.ImageLength", QString::number(img.height()));
-	success &= setExifValue("Exif.Image.Software", qApp->organizationName() + " - " + qApp->applicationName());
+	success &= setExifValue("Exif.Image.ProcessingSoftware", qApp->organizationName() + " - " + qApp->applicationName() + " " + qApp->applicationVersion());
 
 	// TODO: convert Date Time to Date Time Original and set new Date Time
 
 	clearOrientation();
-	setThumbnail(DkImage::createThumb(img));
+	
+	// NOTE: exiv crashes for some images (i.e. \exif-crash\0125-results.png)
+	// if the thumbnail's max size is > 200px
+	setThumbnail(DkImage::createThumb(img, 200));
 
 	return success;
 }
 
 bool DkMetaDataT::setExifValue(QString key, QString taginfo) {
 
-	if (mExifState == not_loaded || mExifState == no_data)
-		return false;
-
-	if (mExifImg->checkMode(Exiv2::mdExif) != Exiv2::amReadWrite &&
-		mExifImg->checkMode(Exiv2::mdExif) != Exiv2::amWrite)
-		return false;
-
-	Exiv2::ExifData &exifData = mExifImg->exifData();
-
 	bool setExifSuccessfull = false;
 
-	if (!exifData.empty() && getExifKeys().contains(key)) {
+	if (mExifState == not_loaded || mExifState == no_data)
+		return false;
+	
+	try {
 
-		Exiv2::Exifdatum& tag = exifData[key.toStdString()];
+		if (mExifImg->checkMode(Exiv2::mdExif) != Exiv2::amReadWrite &&
+			mExifImg->checkMode(Exiv2::mdExif) != Exiv2::amWrite)
+			return false;
 
-		// TODO: save utf8 strings
-		//QByteArray ba = taginfo.toUtf8();
-		//Exiv2::DataValue val((const byte*)ba.data(), taginfo.size(), Exiv2::ByteOrder::bigEndian, Exiv2::TypeId::unsignedByte);
+		Exiv2::ExifData &exifData = mExifImg->exifData();
 
-		//tag.setValue(&val);
-		if (!tag.setValue(taginfo.toStdString())) {
-			mExifState = dirty;
-			setExifSuccessfull = true;
+
+		if (!exifData.empty() && getExifKeys().contains(key)) {
+
+			Exiv2::Exifdatum& tag = exifData[key.toStdString()];
+
+			// TODO: save utf8 strings
+			//QByteArray ba = taginfo.toUtf8();
+			//Exiv2::DataValue val((const byte*)ba.data(), taginfo.size(), Exiv2::ByteOrder::bigEndian, Exiv2::TypeId::unsignedByte);
+
+			//tag.setValue(&val);
+			if (!tag.setValue(taginfo.toStdString())) {
+				mExifState = dirty;
+				setExifSuccessfull = true;
+			}
+		}
+		else {
+
+			Exiv2::ExifKey exivKey(key.toStdString());
+			Exiv2::Exifdatum tag(exivKey);
+			if (!tag.setValue(taginfo.toStdString())) {
+				mExifState = dirty;
+				setExifSuccessfull = true;
+			}
+
+			exifData.add(tag);
 		}
 	}
-	else {
-
-		Exiv2::ExifKey exivKey(key.toStdString());
-		Exiv2::Exifdatum tag(exivKey);
-		if (!tag.setValue(taginfo.toStdString())) {
-			mExifState = dirty;
-			setExifSuccessfull = true;
-		}
-
-		exifData.add(tag);
+	catch (...) {
+		setExifSuccessfull = false;
 	}
 
 	return setExifSuccessfull;
@@ -1255,7 +1262,7 @@ void DkMetaDataT::printMetaData() const {
 
 	std::string xmpPacket;
 	if (0 != Exiv2::XmpParser::encode(xmpPacket, xmpData)) {
-		throw Exiv2::Error(1, "Failed to serialize XMP data");
+		qCritical() << "Failed to serialize XMP data";
 	}
 	std::cout << xmpPacket << "\n";
 }
@@ -1802,4 +1809,35 @@ QMap<int, QString> DkMetaDataHelper::getAllFlashModes() const {
 	return mFlashModes;
 }
 
+// make XmpParser thread-save
+// see http://exiv2.org/doc/classExiv2_1_1XmpParser.html#aea661a7039adb5a748eb7639c8ce9294
+void DkMetaDataHelper::initialize() {
+
+	DkTimer dt;
+
+	//struct XmpLock {
+	//	CRITICAL_SECTION cs;
+	//	XmpLock() { InitializeCriticalSection(&cs); }
+	//	~XmpLock() { DeleteCriticalSection(&cs); }
+	//	static void LockUnlock(void* pData, bool fLock) {
+	//		XmpLock* pThis = reinterpret_cast<XmpLock*>(pData);
+	//		if (pThis) {
+
+	//			if (fLock) {
+	//				EnterCriticalSection(&pThis->cs);
+	//				qDebug() << "locking -------------------------";
+	//			}
+	//			else {
+	//				LeaveCriticalSection(&pThis->cs);
+	//				qDebug() << "unlocking ------------------------";
+	//			}
+	//		}
+	//	}
+	//} xmpLock;
+
+	//Exiv2::XmpParser::initialize(XmpLock::LockUnlock, &xmpLock);
+	Exiv2::XmpParser::initialize();
+	qDebug() << "initializing the xmp parser takes" << dt;
+}
+
 }
