@@ -30,6 +30,7 @@
 
 #pragma warning(push, 0)	// no warnings from includes - begin
 #include <iostream>
+#include <cassert>
 
 #include <QImageReader>
 #include <QScreen>
@@ -212,6 +213,9 @@ void DkSettings::initFileFilters() {
 	app_p.openFilters.append("OpenCV Haar Training (*.vec)");
 	app_p.openFilters.append("Rohkost (*.roh)");
 
+    // drif images
+    app_p.openFilters.append("Developers Raw Image Format (*.drif)");
+
 	// load user filters
 	DefaultSettings settings;
 	app_p.openFilters += settings.value("ResourceSettings/userFilters", QStringList()).toStringList();
@@ -261,12 +265,15 @@ QStringList DkSettings::getTranslationDirs() {
 	QStringList trDirs;
 	trDirs << DkUtils::getTranslationPath();
 	trDirs << qApp->applicationDirPath();
-	trDirs << qApp->applicationDirPath() + QDir::separator() + "translations";
+	
+	QStringList rDirs;
+	rDirs << qApp->applicationDirPath();
+	rDirs << QStandardPaths::standardLocations(QStandardPaths::DataLocation);
 
-	// still needed?
-	QDir d = QDir(qApp->applicationDirPath());
-	if (d.cd("../share/nomacs/translations/"))
-		trDirs << d.absolutePath();
+	for (const QString& d : rDirs)
+		trDirs << d + QDir::separator() + "translations";
+
+	trDirs.removeDuplicates();
 
 	return trDirs;
 }
@@ -319,13 +326,14 @@ void DkSettings::load(QSettings& settings, bool defaults) {
 	tmpShow = settings.value("showMetaDataDock", app_p.showMetaDataDock).toBitArray();
 	if (tmpShow.size() == app_p.showMetaDataDock.size())	
 		app_p.showMetaDataDock = tmpShow;
-	tmpShow = settings.value("showEditDock", app_p.showMetaDataDock).toBitArray();
+	tmpShow = settings.value("showEditDock", app_p.showEditDock).toBitArray();
 	if (tmpShow.size() == app_p.showEditDock.size())	
 		app_p.showEditDock = tmpShow;
 	tmpShow = settings.value("showHistoryDock", app_p.showHistoryDock).toBitArray();
 	if (tmpShow.size() == app_p.showHistoryDock.size())	
 		app_p.showHistoryDock = tmpShow;
 
+	app_p.hideAllPanels = settings.value("hideAllPanels", app_p.hideAllPanels).toBool();
 	app_p.closeOnEsc = settings.value("closeOnEsc", app_p.closeOnEsc).toBool();
 	app_p.showRecentFiles = settings.value("showRecentFiles", app_p.showRecentFiles).toBool();
 	app_p.useLogFile = settings.value("useLogFile", app_p.useLogFile).toBool();
@@ -358,6 +366,7 @@ void DkSettings::load(QSettings& settings, bool defaults) {
 	global_p.lastDir = settings.value("lastDir", global_p.lastDir).toString();
 	global_p.searchHistory = settings.value("searchHistory", global_p.searchHistory).toStringList();
 	global_p.recentFolders = settings.value("recentFolders", global_p.recentFolders).toStringList();
+	global_p.pinnedFiles = settings.value("pinnedFiles", global_p.pinnedFiles).toStringList();
 	global_p.recentFiles = settings.value("recentFiles", global_p.recentFiles).toStringList();
 	global_p.logRecentFiles = settings.value("logRecentFiles", global_p.logRecentFiles).toBool();
 	global_p.useTmpPath = settings.value("useTmpPath", global_p.useTmpPath).toBool();
@@ -397,11 +406,11 @@ void DkSettings::load(QSettings& settings, bool defaults) {
 	display_p.showCrop = settings.value("showCrop", display_p.showCrop).toBool();
 	display_p.histogramStyle = settings.value("histogramStyle", display_p.histogramStyle).toInt();
 	display_p.tpPattern = settings.value("tpPattern", display_p.tpPattern).toBool();
-	display_p.themeName = settings.value("themeName", display_p.themeName).toString();
-	display_p.toolbarGradient = settings.value("toolbarGradient", display_p.toolbarGradient).toBool();
+	display_p.themeName = settings.value("themeName312", display_p.themeName).toString();
 	display_p.showBorder = settings.value("showBorder", display_p.showBorder).toBool();
 	display_p.displaySquaredThumbs = settings.value("displaySquaredThumbs", display_p.displaySquaredThumbs).toBool();
 	display_p.showThumbLabel = settings.value("showThumbLabel", display_p.showThumbLabel).toBool();
+	display_p.showScrollBars = settings.value("showScrollBars", display_p.showScrollBars).toBool();
 	display_p.animationDuration = settings.value("fadeSec", display_p.animationDuration).toFloat();
 	display_p.alwaysAnimate = settings.value("alwaysAnimate", display_p.alwaysAnimate).toBool();
 	display_p.transition = (TransitionMode)settings.value("transition", display_p.transition).toInt();
@@ -434,18 +443,12 @@ void DkSettings::load(QSettings& settings, bool defaults) {
 	// Synchronize Settings --------------------------------------------------------------------
 	settings.beginGroup("SynchronizeSettings");
 
-	sync_p.enableNetworkSync= settings.value("enableNetworkSync", sync_p.enableNetworkSync).toBool();
-	sync_p.allowTransformation = settings.value("allowTransformation", sync_p.allowTransformation).toBool();
-	sync_p.allowPosition = settings.value("allowPosition", sync_p.allowPosition).toBool();
-	sync_p.allowFile = settings.value("allowFile", sync_p.allowFile).toBool();
-	sync_p.allowImage = settings.value("allowImage", sync_p.allowImage).toBool();;
 	sync_p.checkForUpdates = settings.value("checkForUpdates", sync_p.checkForUpdates).toBool();
 	sync_p.disableUpdateInteraction = settings.value("disableUpdateInteraction", sync_p.disableUpdateInteraction).toBool();
 	sync_p.updateDialogShown = settings.value("updateDialogShown", sync_p.updateDialogShown).toBool();
 	sync_p.lastUpdateCheck = settings.value("lastUpdateCheck", sync_p.lastUpdateCheck).toDate();
 	sync_p.syncAbsoluteTransform = settings.value("syncAbsoluteTransform", sync_p.syncAbsoluteTransform).toBool();
 	sync_p.switchModifier = settings.value("switchModifier", sync_p.switchModifier).toBool();
-	//sync_p.syncMode = settings.value("syncMode", sync_p.syncMode).toInt();
 	sync_p.syncActions = settings.value("syncActions", sync_p.syncActions).toBool();
 
 	settings.endGroup();
@@ -461,6 +464,7 @@ void DkSettings::load(QSettings& settings, bool defaults) {
 	resources_p.filterDuplicats = settings.value("filterDuplicates", resources_p.filterDuplicats).toBool();
 	resources_p.preferredExtension = settings.value("preferredExtension", resources_p.preferredExtension).toString();	
 	resources_p.gammaCorrection = settings.value("gammaCorrection", resources_p.gammaCorrection).toBool();
+	resources_p.loadSavedImage = settings.value("loadSavedImage", resources_p.loadSavedImage).toInt();
 
 	if (sync_p.switchModifier) {
 		global_p.altMod = Qt::ControlModifier;
@@ -490,9 +494,9 @@ void DkSettings::load(QSettings& settings, bool defaults) {
 	}
 }
 
-void DkSettings::save() {
+void DkSettings::save(bool force) {
 	DefaultSettings s;
-	save(s);
+	save(s, force);
 }
 
 void DkSettings::save(QSettings& settings, bool force) {
@@ -537,6 +541,8 @@ void DkSettings::save(QSettings& settings, bool force) {
 		settings.setValue("showEditDock", app_p.showEditDock);
 	if (force ||app_p.showHistoryDock != app_d.showHistoryDock)
 		settings.setValue("showHistoryDock", app_p.showHistoryDock);
+	if (force || app_p.hideAllPanels != app_d.hideAllPanels)
+		settings.setValue("hideAllPanels", app_p.hideAllPanels);
 	if (force ||app_p.advancedSettings != app_d.advancedSettings)
 		settings.setValue("advancedSettings", app_p.advancedSettings);
 	if (force ||app_p.closeOnEsc != app_d.closeOnEsc)
@@ -577,6 +583,8 @@ void DkSettings::save(QSettings& settings, bool force) {
 		settings.setValue("recentFolders", global_p.recentFolders);
 	if (force ||global_p.recentFiles != global_d.recentFiles)
 		settings.setValue("recentFiles", global_p.recentFiles);
+	if (force || global_p.pinnedFiles != global_d.pinnedFiles)
+		settings.setValue("pinnedFiles", global_p.pinnedFiles);
 	if (force ||global_p.logRecentFiles != global_d.logRecentFiles)
 		settings.setValue("logRecentFiles", global_p.logRecentFiles);
 	if (force ||global_p.useTmpPath != global_d.useTmpPath)
@@ -647,15 +655,15 @@ void DkSettings::save(QSettings& settings, bool force) {
 	if (force ||display_p.tpPattern != display_d.tpPattern)
 		settings.setValue("tpPattern", display_p.tpPattern);
 	if (force || display_p.themeName != display_d.themeName)
-		settings.setValue("themeName", display_p.themeName);
-	if (force ||display_p.toolbarGradient != display_d.toolbarGradient)
-		settings.setValue("toolbarGradient", display_p.toolbarGradient);
+		settings.setValue("themeName312", display_p.themeName);
 	if (force ||display_p.showBorder != display_d.showBorder)
 		settings.setValue("showBorder", display_p.showBorder);
 	if (force ||display_p.displaySquaredThumbs != display_d.displaySquaredThumbs)
 		settings.setValue("displaySquaredThumbs", display_p.displaySquaredThumbs);
 	if (force ||display_p.showThumbLabel != display_d.showThumbLabel)
 		settings.setValue("showThumbLabel", display_p.showThumbLabel);
+	if (force || display_p.showScrollBars != display_d.showScrollBars)
+		settings.setValue("showScrollBars", display_p.showScrollBars);
 	if (force ||display_p.alwaysAnimate != display_d.alwaysAnimate)
 		settings.setValue("alwaysAnimate", display_p.alwaysAnimate);
 	if (force ||display_p.animationDuration != display_d.animationDuration)
@@ -699,16 +707,6 @@ void DkSettings::save(QSettings& settings, bool force) {
 	// Sync Settings --------------------------------------------------------------------
 	settings.beginGroup("SynchronizeSettings");
 
-	if (force ||sync_p.enableNetworkSync != sync_d.enableNetworkSync)
-		settings.setValue("enableNetworkSync", sync_p.enableNetworkSync);
-	if (force ||sync_p.allowTransformation != sync_d.allowTransformation)
-		settings.setValue("allowTransformation", sync_p.allowTransformation);
-	if (force ||sync_p.allowPosition != sync_d.allowPosition)
-		settings.setValue("allowPosition", sync_p.allowPosition);
-	if (force ||sync_p.allowFile != sync_d.allowFile)
-		settings.setValue("allowFile", sync_p.allowFile);
-	if (force ||sync_p.allowImage != sync_d.allowImage)
-		settings.setValue("allowImage", sync_p.allowImage);
 	//if (force ||sync_p.checkForUpdates != sync_d.checkForUpdates)
 		settings.setValue("checkForUpdates", sync_p.checkForUpdates);
 	//if (force || sync_p.disableUpdateInteraction != sync_d.disableUpdateInteraction)
@@ -721,8 +719,6 @@ void DkSettings::save(QSettings& settings, bool force) {
 		settings.setValue("syncAbsoluteTransform", sync_p.syncAbsoluteTransform);
 	if (force ||sync_p.switchModifier != sync_d.switchModifier)
 		settings.setValue("switchModifier", sync_p.switchModifier);
-	//if (force ||sync_p.syncMode != sync_d.syncMode)
-	//	settings.setValue("syncMode", sync_p.syncMode);
 	if (force ||sync_p.syncActions != sync_d.syncActions)
 		settings.setValue("syncActions", sync_p.syncActions);
 
@@ -748,6 +744,9 @@ void DkSettings::save(QSettings& settings, bool force) {
 		settings.setValue("preferredExtension", resources_p.preferredExtension);
 	if (force ||resources_p.gammaCorrection != resources_d.gammaCorrection)
 		settings.setValue("gammaCorrection", resources_p.gammaCorrection);
+	if (force || resources_p.loadSavedImage != resources_d.loadSavedImage)
+		settings.setValue("loadSavedImage", resources_p.loadSavedImage);
+
 	settings.endGroup();
 
 	// keep loaded settings in mind
@@ -781,6 +780,7 @@ void DkSettings::setToDefaultSettings() {
 	app_p.showHistoryDock = QBitArray(mode_end, false);
 	app_p.advancedSettings = false;
 	app_p.closeOnEsc = false;
+	app_p.hideAllPanels = false;
 	app_p.showRecentFiles = true;
 	app_p.browseFilters = QStringList();
 	app_p.showMenuBar = true;
@@ -803,6 +803,7 @@ void DkSettings::setToDefaultSettings() {
 	global_p.lastDir = QString();
 	global_p.lastSaveDir = QString();
 	global_p.recentFiles = QStringList();
+	global_p.pinnedFiles = QStringList();
 	global_p.searchHistory = QStringList();
 	global_p.recentFolders = QStringList();
 	global_p.logRecentFiles = true;
@@ -847,11 +848,11 @@ void DkSettings::setToDefaultSettings() {
 	display_p.showCrop = false;
 	display_p.histogramStyle = 0; // DkHistogram::DisplayMode::histogram_mode_simple
 	display_p.tpPattern = false;
-	display_p.themeName = "Light Theme.css";
-	display_p.toolbarGradient = false;
+	display_p.themeName = "Light-Theme.css";
 	display_p.showBorder = false;
 	display_p.displaySquaredThumbs = true;
-	display_p.showThumbLabel = true;
+	display_p.showThumbLabel = false;
+	display_p.showScrollBars = false;
 	display_p.animationDuration = 0.5f;
 	display_p.alwaysAnimate = false;
 	display_p.transition = trans_swipe;
@@ -863,23 +864,17 @@ void DkSettings::setToDefaultSettings() {
 	slideShow_p.time = 3.0;
 	slideShow_p.moveSpeed = 0;		// TODO: set to 1 for finishing slideshow
 	slideShow_p.display = QBitArray(display_end, true);
-	slideShow_p.backgroundColor = QColor(86, 86, 90, 255);
+	slideShow_p.backgroundColor = QColor(51, 51, 51, 255);
 	slideShow_p.silentFullscreen = true;
 
 	meta_p.saveExifOrientation = true;
 	meta_p.ignoreExifOrientation = false;
 
-	sync_p.enableNetworkSync = false;
-	sync_p.allowTransformation = true;
-	sync_p.allowPosition = true;
-	sync_p.allowFile = true;
-	sync_p.allowImage = true;
 	sync_p.checkForUpdates = !isPortable();	// installed version should only check for updates by default
 	sync_p.disableUpdateInteraction = isPortable();	// installed version should only check for updates by default
 	sync_p.updateDialogShown = false;
-	sync_p.lastUpdateCheck = QDate(1970 , 1, 1);
+	sync_p.lastUpdateCheck = QDate(2018, 7, 14);	// ; )
 	sync_p.syncAbsoluteTransform = true;
-	sync_p.syncMode = DkSettings::sync_mode_default;
 	sync_p.syncActions = false;
 
 	resources_p.cacheMemory = 0;
@@ -889,9 +884,8 @@ void DkSettings::setToDefaultSettings() {
 	resources_p.loadRawThumb = raw_thumb_always;
 	resources_p.filterDuplicats = false;
 	resources_p.preferredExtension = "*.jpg";
-	resources_p.numThumbsLoading = 0;
-	resources_p.maxThumbsLoading = 5;
 	resources_p.gammaCorrection = true;
+	resources_p.loadSavedImage = ls_load_to_tab;
 	resources_p.waitForLastImg = true;
 
 	qDebug() << "ok... default settings are set";
@@ -1037,15 +1031,14 @@ void DkSettingsManager::init() {
 
 	qInfo() << "Hi there";
 	qInfoClean() << "my name is " << QApplication::organizationName() << " | " << QApplication::applicationName() 
-		<< " v " << QApplication::applicationVersion() << (nmc::DkSettingsManager::param().isPortable() ? " portable" : " installed");
-
+		<< " v" << QApplication::applicationVersion() << (nmc::DkSettingsManager::param().isPortable() ? " (portable)" : " (installed)");
 }
 
 void DkSettingsManager::importSettings(const QString & settingsPath) {
 
 	QSettings settings(settingsPath, QSettings::IniFormat);
 	param().load(settings);
-	param().save();
+	param().save(true);
 
 	qInfo() << "settings imported...";
 }
@@ -1349,7 +1342,19 @@ QString DkThemeManager::getCurrentThemeName() const {
 
 QString DkThemeManager::themeDir() const {
 
-	QDir themeDir(QCoreApplication::applicationDirPath() + "/themes");
+	QStringList paths;
+	paths << QCoreApplication::applicationDirPath();
+	paths << QStandardPaths::standardLocations(QStandardPaths::DataLocation);
+
+	QDir themeDir;
+
+	for (const QString& p : paths) {
+		themeDir = QDir(p + QDir::separator() + "themes");
+
+		if (themeDir.exists())
+			break;
+	}
+
 	return themeDir.absolutePath();
 }
 
@@ -1398,10 +1403,12 @@ QString DkThemeManager::loadStylesheet() const {
 }
 
 void DkThemeManager::applyTheme() const {
-
+	
 	// add theme
 	QString cssString = loadTheme(getCurrentThemeName());
 
+	DkSettings::Display& dp = DkSettingsManager::param().display();
+
 	// NOTE: it is important, that default.css does not contain
 	// any line of code except for the color definitions
 	// otherwise, we change the default palette here...
@@ -1410,12 +1417,17 @@ void DkThemeManager::applyTheme() const {
 		cssString = replaceColors(cssString);
 
 		QPalette p = qApp->palette();
-		p.setColor(QPalette::Window, DkSettingsManager::param().display().themeBgdColor);
-		p.setColor(QPalette::WindowText, DkSettingsManager::param().display().themeFgdColor);
-		p.setColor(QPalette::Button, QColor(0, 0, 0));
-		p.setColor(QPalette::ButtonText, DkSettingsManager::param().display().themeFgdColor);
 
-		p.setColor(QPalette::Base, DkSettingsManager::param().display().themeBgdColor);
+		if (dp.themeBgdColor != QPalette().color(QPalette::Window)) {
+			p.setColor(QPalette::Window, dp.themeBgdColor);
+			p.setColor(QPalette::Base, dp.themeBgdColor);
+		}
+
+		p.setColor(QPalette::WindowText, dp.themeFgdColor);
+		p.setColor(QPalette::ButtonText, dp.themeFgdColor);
+
+		//p.setColor(QPalette::Button, QColor(0, 0, 0));
+
 		qApp->setPalette(p);
 	}
 
@@ -1428,7 +1440,8 @@ void DkThemeManager::applyTheme() const {
 QString DkThemeManager::cleanThemeName(const QString & theme) const {
 	
 	QString t = theme;
-	t.replace(".css", "");
+	t = t.replace(".css", "");
+	t = t.replace("-", " ");
 	
 	return t;
 }
@@ -1475,24 +1488,31 @@ QString DkThemeManager::parseColors(const QString & styleSheet) const {
 
 			QString cc = kv[1].simplified();
 
-			if (kv[0] == "HIGHLIGHT_COLOR")
+			if (kv[0] == "HIGHLIGHT_COLOR" && cc != "default")
 				DkSettingsManager::param().display().highlightColor.setNamedColor(cc);
-			else if (kv[0] == "HUD_BACKGROUND_COLOR")
+			else if (kv[0] == "HUD_BACKGROUND_COLOR" && cc != "default")
 				DkSettingsManager::param().display().hudBgColor.setNamedColor(cc);
-			else if (kv[0] == "HUD_FOREGROUND_COLOR")
+			else if (kv[0] == "HUD_FOREGROUND_COLOR" && cc != "default")
 				DkSettingsManager::param().display().hudFgdColor.setNamedColor(cc);
 			else if (kv[0] == "BACKGROUND_COLOR") {
+
+				QColor c;
+				c.setNamedColor(cc);
+
+				if (cc == "default")
+					c = QPalette().color(QPalette::Window);
+					
 				if (DkSettingsManager::param().display().defaultBackgroundColor)
-					DkSettingsManager::param().display().bgColor.setNamedColor(cc);
-				DkSettingsManager::param().display().themeBgdColor.setNamedColor(cc);
+						DkSettingsManager::param().display().bgColor = c;
+				DkSettingsManager::param().display().themeBgdColor = c;
 			}
-			else if (kv[0] == "FOREGROUND_COLOR")
+			else if (kv[0] == "FOREGROUND_COLOR" && cc != "default")
 				DkSettingsManager::param().display().themeFgdColor.setNamedColor(cc);
-			else if (kv[0] == "ICON_COLOR") {
+			else if (kv[0] == "ICON_COLOR" && cc != "default") {
 				if (DkSettingsManager::param().display().defaultIconColor)
 					DkSettingsManager::param().display().iconColor.setNamedColor(cc);
 			}
-			else
+			else if (cc != "default")
 				qWarning() << "could not parse color:" << str;
 		}
 
@@ -1521,5 +1541,167 @@ QString DkThemeManager::replaceColors(const QString & cssString) const {
 	return cs;
 }
 
+// -------------------------------------------------------------------- DkZoomConfig 
+DkZoomConfig::DkZoomConfig() {
+
+	mLevels = defaultLevels();
+
+	DefaultSettings ds;
+	loadSettings(ds);
+}
+
+DkZoomConfig& DkZoomConfig::instance() {
+	static DkZoomConfig inst;
+	return inst;
+}
+
+DkZoomConfig::~DkZoomConfig() {
+
+	DefaultSettings ds;
+	saveSettings(ds);
+}
+
+double DkZoomConfig::nextFactor(double currentFactor, double delta) const {
+
+	// do nothing?
+	if (!mUseLevels)
+		return delta;
+
+	assert(currentFactor != 0.0);
+
+	if (currentFactor == 0.0)
+		return 1.0;
+
+	if (delta > 1) {
+		for (double l : mLevels) {
+
+			if (currentFactor < l) {
+				return l / currentFactor;
+			}
+		}
+	}
+	else if (delta < 1) {
+
+		for (int idx = mLevels.size() - 1; idx >= 0; idx--) {
+
+			if (currentFactor > mLevels[idx]) {
+				return mLevels[idx] / currentFactor;
+			}
+		}
+	}
+
+	// do nothing
+	return 1.0;
+}
+
+QVector<double> DkZoomConfig::defaultLevels() const {
+
+	QVector<double> levels;
+
+	levels << 0.0001;
+	levels << 0.001;
+	levels << 0.01;
+	levels << 0.05;
+	levels << 0.1;
+	levels << 0.125;
+	levels << 0.166;
+	levels << 0.25;
+	levels << 0.333;
+	levels << 0.5;
+	levels << 0.66;
+	levels << 1;
+	levels << 1.5;
+	levels << 2;
+	levels << 3;
+	levels << 4;
+	levels << 5;
+	levels << 6;
+	levels << 7;
+	levels << 8;
+	levels << 12;
+	levels << 16;
+	levels << 32;
+	levels << 64;
+	levels << 128;
+
+	return levels;
+}
+
+bool DkZoomConfig::useLevels() const {
+	return mUseLevels;
+}
+
+void DkZoomConfig::setUseLevels(bool useLevels) {
+	mUseLevels = useLevels;
+}
+
+bool DkZoomConfig::setLevels(const QString & levelStr) {
+
+	QVector<double> levels;
+	QStringList levelList = levelStr.split(",");
+
+	bool ok = false;
+	for (const QString& s : levelList) {
+		levels << s.toDouble(&ok);
+		if (!ok)
+			break;
+	}
+
+	if (ok && checkLevels(levels)) {
+		mLevels = levels;
+		return true;
+	}
+	
+	return false;
+}
+
+QString DkZoomConfig::levelsToString() const {
+	
+	QStringList levelStr;
+	for (double l : mLevels)
+		levelStr << QString::number(l);
+	
+	return levelStr.join(",");
+}
+
+void DkZoomConfig::setLevelsToDefault() {
+
+	mLevels = defaultLevels();
+}
+
+bool DkZoomConfig::checkLevels(const QVector<double>& levels) {
+
+	if (levels.isEmpty())
+		return false;
+
+	double last = 0;
+
+	// levels must be monotonically increasing
+	for (double l : levels) {
+		if (l < last)
+			return false;
+	}
+
+	return true;
+}
+
+void DkZoomConfig::loadSettings(QSettings & settings) {
+
+	settings.beginGroup("zooming");
+	QString levelStr = settings.value("zoomLevels").toString();
+	mUseLevels = settings.value("useLevels").toBool();
+	settings.endGroup();
+
+	if (!setLevels(levelStr))
+		qWarning() << "illegal zoom levels when loading from settings:" << levelStr;
+}
+
+void DkZoomConfig::saveSettings(QSettings & settings) const {
+
+	settings.beginGroup("zooming");
+	settings.setValue("zoomLevels", levelsToString());
+	settings.setValue("useLevels", mUseLevels);
+	settings.endGroup();
+}
 
 }
