@@ -33,6 +33,7 @@
 #include <QColor>
 #include <QDate>
 #include <QSharedPointer>
+#include <QVector>
 #pragma warning(pop)	// no warnings from includes - end
 
 #pragma warning(disable: 4251)	// TODO: remove
@@ -148,15 +149,6 @@ public:
 		zoom_end,
 	};
 
-	enum syncModes {
-		sync_mode_default = 0,
-		sync_mode_remote_display,
-		sync_mode_remote_control,
-		sync_mode_receiveing_command,
-
-		sync_mode_end,
-	};
-
 	enum TransitionMode {
 		trans_appear,
 		trans_fade,
@@ -165,6 +157,14 @@ public:
 		trans_end
 	};
 
+	enum LoadSaveMode {
+		ls_load,
+		ls_load_to_tab,
+		ls_do_nothing,
+
+		ls,end
+	};
+
 	struct App {
 		bool showToolBar;
 		bool showMenuBar;
@@ -189,7 +189,7 @@ public:
 		bool privateMode;
 		bool advancedSettings;
 		bool closeOnEsc;
-		bool maximizedMode;
+		bool hideAllPanels;
 
 		int defaultJpgQuality;
 
@@ -231,10 +231,10 @@ public:
 		bool showCrop;
 		bool antiAliasing;
 		bool highQualityAntiAliasing;
-		bool toolbarGradient;	// 05.01.2016 - deprecated
 		bool showBorder;
 		bool displaySquaredThumbs;
 		bool showThumbLabel;
+		bool showScrollBars;
 		
 		TransitionMode transition;
 		bool alwaysAnimate;
@@ -253,6 +253,7 @@ public:
 		QString lastSaveDir;
 		QStringList recentFiles;
 		QStringList recentFolders;
+		QStringList pinnedFiles;
 		bool logRecentFiles;
 		bool checkOpenDuplicates;
 		bool extendedTabs;
@@ -287,18 +288,12 @@ public:
 		float moveSpeed;
 	};
 	struct Sync {
-		bool enableNetworkSync;
-		bool allowTransformation;
-		bool allowPosition;
-		bool allowFile;
-		bool allowImage;
 		bool checkForUpdates;
 		bool updateDialogShown;
 		bool disableUpdateInteraction;
 		QDate lastUpdateCheck;
 		bool syncAbsoluteTransform;
 		bool switchModifier;
-		int syncMode;
 		bool syncActions;
 	};
 	struct MetaData {
@@ -315,9 +310,8 @@ public:
 		bool filterDuplicats;
 		int loadRawThumb;
 		QString preferredExtension;
-		int numThumbsLoading;
-		int maxThumbsLoading;
 		bool gammaCorrection;
+		int loadSavedImage;
 	};
 
 	//enums for checkboxes - divide in camera data and description
@@ -353,7 +347,7 @@ public:
 
 	void load();
 	void load(QSettings& settings, bool defaults = false);
-	void save();
+	void save(bool force = false);
 	void save(QSettings& settings, bool force = false);
 	void setToDefaultSettings();
 	void setNumThreads(int numThreads);
@@ -427,4 +421,38 @@ private:
 	DkSettings* mParams = 0;
 };
 
+class DkZoomConfig {
+
+public:
+	static DkZoomConfig& instance();
+	~DkZoomConfig();
+
+	// singleton
+	DkZoomConfig(DkZoomConfig const&) = delete;
+	void operator=(DkZoomConfig const&) = delete;
+
+	double nextFactor(double currentFactor, double delta) const;
+	QVector<double> defaultLevels() const;
+
+	bool useLevels() const;
+	void setUseLevels(bool useLevels);
+
+	bool setLevels(const QString& levelStr);
+	QString levelsToString() const;
+
+	void setLevelsToDefault();
+
+	static bool checkLevels(const QVector<double>& levels);
+
+private:
+
+	QVector<double> mLevels;
+	bool mUseLevels = false;
+
+	DkZoomConfig();
+	void loadSettings(QSettings& settings);
+	void saveSettings(QSettings& settings) const;
+
+};
+
 }
