@@ -29,6 +29,8 @@
 #include "DkUtils.h"
 #include "DkMath.h"
 #include "DkSettings.h"
+#include "DkNoMacs.h"
+#include "DkViewPort.h"
 
 #if defined(Q_OS_LINUX) && !defined(Q_OS_OPENBSD)
 #include <sys/sysinfo.h>
@@ -93,6 +95,7 @@ namespace nmc {
 void qtMessageOutput(QtMsgType type, const QMessageLogContext &, const QString &msg) {
 
 #if QT_VERSION >= 0x050500
+	// this might cause a crash (if qDebug() is used in a destructor)
 	if (!DkSettingsManager::param().app().useLogFile)
 		return;	// should not be called anyhow
 
@@ -209,14 +212,13 @@ double DkMemory::getFreeMemory() {
 
 bool DkUtils::wCompLogic(const std::wstring & lhs, const std::wstring & rhs) {
 	return StrCmpLogicalW(lhs.c_str(),rhs.c_str()) < 0;
-	//return true;
 }
 
 bool DkUtils::compLogicQString(const QString & lhs, const QString & rhs) {
 #if QT_VERSION < 0x050000
 	return wCompLogic(lhs.toStdWString(), rhs.toStdWString());
 #else
-	return wCompLogic((wchar_t*)lhs.utf16(), (wchar_t*)rhs.utf16());	// TODO: is this nice?
+	return wCompLogic(qStringToStdWString(lhs), qStringToStdWString(rhs));
 #endif
 }
 
@@ -316,19 +318,21 @@ QString DkUtils::resolveSymLink(const QString & filePath) {
 					continue;
 
 				QFileInfo fi(cl);
-				if (fi.exists()) {
+				if (fi.exists() && fi.isFile() && DkUtils::hasValidSuffix(fi.fileName())) {
 					rFilePath = fi.absoluteFilePath();
 					break;
 				}
 
 				// is there a relative path?
 				fi = QFileInfo(fInfo.absolutePath() + QDir::separator() + cl);
-				if (fi.exists() & fi.isFile()) {
+				if (fi.exists() && fi.isFile() && DkUtils::hasValidSuffix(fi.fileName())) {
 					rFilePath = fi.absoluteFilePath();
 					break;
 				}
 			}
 		}
+
+		file.close();
 	}
 
 	return rFilePath;
@@ -500,14 +504,20 @@ QString DkUtils::getAppDataPath() {
 
 	QString appPath;
 
-#if QT_VERSION >= 0x050000
+#if QT_VERSION >= QT_VERSION_CHECK(5, 4, 0)
+	// this gives us a roaming profile on windows
+	appPath = QStandardPaths::writableLocation(QStandardPaths::AppDataLocation);
+#elif QT_VERSION >= 0x050000
 	appPath = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation);
+
+	// make our own folder - AppDataLocation already does this...
+	appPath += QDir::separator() + QCoreApplication::organizationName();
 #else
 	appPath = QDesktopServices::storageLocation(QDesktopServices::DataLocation);
-#endif
-
 	// make our own folder
 	appPath += QDir::separator() + QCoreApplication::organizationName();
+#endif
+
 	
 	if (!QDir().mkpath(appPath))
 		qWarning() << "I could not create" << appPath;
@@ -515,6 +525,23 @@ QString DkUtils::getAppDataPath() {
 	return appPath;
 }
 
+QString DkUtils::getTranslationPath() {
+
+	QString trPath;
+
+	if (DkSettingsManager::param().isPortable())
+		trPath = QCoreApplication::applicationDirPath();
+	else
+		trPath = DkUtils::getAppDataPath();
+
+	trPath += QDir::separator() + QString("translations");
+
+	if (!QDir().mkpath(trPath))
+		qWarning() << "I could not create" << trPath;
+
+	return trPath;
+}
+
 QWidget * DkUtils::getMainWindow() {
 
 	QWidgetList widgets = QApplication::topLevelWidgets();
@@ -532,6 +559,15 @@ QWidget * DkUtils::getMainWindow() {
 	return win;
 }
 
+void DkUtils::showViewportMessage(const QString & msg) {
+
+	DkNoMacs* nmc = dynamic_cast<DkNoMacs*>(getMainWindow());
+
+	if (nmc && nmc->viewport())
+		nmc->viewport()->infoSignal(msg);
+
+}
+
 void DkUtils::mSleep(int ms) {
 
 #ifdef Q_OS_WIN
@@ -619,25 +655,17 @@ bool DkUtils::isValid(const QFileInfo& fileInfo) {
 	if (fInfo.isSymLink())
 		fInfo = fileInfo.symLinkTarget();
 
-	bool fileIsValid = false;
-	auto printDebug = [&](QString msg){
-		QString validText = fileIsValid?"is valid":"is invalid";
-		qDebug() << QString("file %1 %2 %3").arg(fileName).arg(validText).arg(msg);
-	};
-
     if (!fInfo.exists()) {
-        fileIsValid = false;
-        printDebug("doesn't exist");
-
-    } else if(hasValidSuffix(fInfo.fileName()))  {
-        fileIsValid = true;
-        printDebug("is has no valid extension.");
-
-    } else if(isValidByContent(fInfo))  {
-        fileIsValid = true;
-        printDebug("detected by mime");
+		return false;
+    } 
+	else if (hasValidSuffix(fInfo.fileName()))  {
+		return true;
+    } 
+	else if (isValidByContent(fInfo))  {
+		return true;
     }
-    return fileIsValid;
+
+    return false;
 }
 
 bool DkUtils::isSavable(const QString & fileName) {
@@ -842,6 +870,12 @@ bool DkUtils::moveToTrash(const QString& filePath) {
 
 	QFileInfo fileInfo(filePath);
 
+	// delete links
+	if (fileInfo.isSymLink()) {
+		QFile fh(filePath);
+		return fh.remove();
+	}
+
 	if (!fileInfo.exists()) {
 		qDebug() << "Sorry, I cannot delete a non-existing file: " << filePath;
 		return false;
@@ -996,12 +1030,20 @@ QString DkUtils::resolveFraction(const QString& frac) {
 QList<QUrl> DkUtils::findUrlsInTextNewline(QString text){
     QList<QUrl> urls;
     QStringList lines = text.split(QRegExp("\n|\r\n|\r"));
-    for(QUrl maybeUrl: QUrl::fromStringList(lines)){
-        if(maybeUrl.isValid()){
-            if(maybeUrl.isRelative()){
-                maybeUrl.setScheme("file");
+    for (QString fp : lines) {
+        
+		// fixes urls for windows - yes that actually annoys me
+		fp = fp.replace("\\", "/");
+		
+		QUrl url(fp);
+
+		if (url.isValid()) {
+            
+			if (url.isRelative()){
+                url.setScheme("file");
             }
-            urls.append(maybeUrl);
+
+            urls.append(url);
         }
     }
     return urls;
