@@ -1,3 +1,4 @@
+#include "DkCentralWidget.h"
 /*******************************************************************************************************
  DkCentralWidget.cpp
  Created on:	14.11.2014
@@ -67,7 +68,8 @@ DkTabInfo::DkTabInfo(const QSharedPointer<DkImageContainerT> imgC, int idx, QObj
 		deactivate();
 	mImageLoader->setCurrentImage(imgC);
 
-	mTabMode = (!imgC) ? tab_recent_files : tab_single_image;
+	if (imgC)
+		mTabMode = tab_single_image;
 	mTabIdx = idx;
 	mFilePath = getFilePath();
 }
@@ -192,16 +194,18 @@ QIcon DkTabInfo::getIcon() {
 	
 	QIcon icon;
 
+	if (mTabMode == tab_thumb_preview)
+		return DkImage::loadIcon(":/nomacs/img/rects.svg");
+	else if (mTabMode == tab_recent_files)
+		return DkImage::loadIcon(":/nomacs/img/bars.svg");
+	else if (mTabMode == tab_preferences)
+		return DkImage::loadIcon(":/nomacs/img/settings.svg");
+	else if (mTabMode == tab_batch)
+		return DkImage::loadIcon(":/nomacs/img/batch-processing.svg");
+
 	if (!mImageLoader->getCurrentImage())
 		return icon;
 
-	if (mTabMode == tab_thumb_preview)
-		return QIcon(":/nomacs/img/thumbs-view.svg");
-	else if (mTabMode == tab_preferences)
-		return QIcon(":/nomacs/img/settings.svg");
-	else if (mTabMode == tab_batch)
-		return QIcon(":/nomacs/img/batch.svg");
-
 	QSharedPointer<DkThumbNailT> thumb = mImageLoader->getCurrentImage()->getThumb();
 
 	if (!thumb)
@@ -222,6 +226,8 @@ QString DkTabInfo::getTabText() const {
 
 	if (mTabMode == tab_thumb_preview)
 		return QObject::tr("Thumbnail Preview");
+	else if (mTabMode == tab_recent_files)
+		return QObject::tr("Recent Files");
 	else if (mTabMode == tab_preferences)
 		return QObject::tr("Settings");
 	else if (mTabMode == tab_batch)
@@ -264,12 +270,13 @@ DkCentralWidget::DkCentralWidget(DkViewPort* viewport, QWidget* parent) : QWidge
 	setAcceptDrops(true);
 
 	DkActionManager& am = DkActionManager::instance();
-	connect(am.action(DkActionManager::menu_file_new_tab), SIGNAL(triggered()), this, SLOT(addTab()));
-	connect(am.action(DkActionManager::menu_file_close_tab), SIGNAL(triggered()), this, SLOT(removeTab()));
-	connect(am.action(DkActionManager::menu_file_close_all_tabs), &QAction::triggered, this, [this]() { clearAllTabs(); });
-	connect(am.action(DkActionManager::menu_edit_paste), SIGNAL(triggered()), this, SLOT(pasteImage()));
+	connect(am.action(DkActionManager::menu_view_new_tab), SIGNAL(triggered()), this, SLOT(addTab()));
+	connect(am.action(DkActionManager::menu_view_close_tab), SIGNAL(triggered()), this, SLOT(removeTab()));
+	connect(am.action(DkActionManager::menu_view_close_all_tabs), &QAction::triggered, this, [this]() { clearAllTabs(); });
 	connect(am.action(DkActionManager::menu_view_first_tab), &QAction::triggered, this, [this]() { setActiveTab(0); });
 	connect(am.action(DkActionManager::menu_view_previous_tab), SIGNAL(triggered()), this, SLOT(previousTab()));
+	connect(am.action(DkActionManager::menu_edit_paste), SIGNAL(triggered()), this, SLOT(pasteImage()));
+
 	connect(am.action(DkActionManager::menu_view_goto_tab), &QAction::triggered, this, [this]() {
 		bool ok = false;
 		int idx = QInputDialog::getInt(this, tr("Go to Tab"), tr("Go to tab number: "), getActiveTab()+1, 1, getTabs().count(), 1, &ok);
@@ -299,14 +306,13 @@ void DkCentralWidget::createLayout() {
 	mTabbar->setMovable(true);
 	mTabbar->installEventFilter(new TabMiddleMouseCloser([this](int idx) { removeTab(idx); }));
 	mTabbar->hide();
-	//addTab(QFileInfo());
 
 	mProgressBar = new DkProgressBar(this);
-	//mProgressBar->setStyleSheet(mProgressBar->styleSheet() + "QProgressBar{background-color: #fff;}");
 	mProgressBar->hide();
 
 	mWidgets.resize(widget_end);
 	mWidgets[viewport_widget] = mViewport;
+	mWidgets[recent_files_widget] = 0;
 	mWidgets[thumbs_widget] = 0;
 	mWidgets[preference_widget] = 0;
 
@@ -324,19 +330,7 @@ void DkCentralWidget::createLayout() {
 	vbLayout->addWidget(mProgressBar);
 	vbLayout->addWidget(viewWidget);
 
-	mRecentFilesWidget = new DkRecentFilesWidget(viewWidget);
-	
-	// get the maximum resolution available
-	QSize recentFilesSize;
-	for (int idx = 0; idx < QApplication::desktop()->screenCount(); idx++) {
-		recentFilesSize = recentFilesSize.expandedTo(QApplication::desktop()->availableGeometry(idx).size());
-	}
-
-	mRecentFilesWidget->setFixedSize(recentFilesSize);
-	mRecentFilesWidget->registerAction(DkActionManager::instance().action(DkActionManager::menu_file_show_recent));
-
 	// connections
-	connect(this, SIGNAL(loadFileSignal(const QString&)), this, SLOT(loadFile(const QString&)));
 	connect(mViewport, SIGNAL(addTabSignal(const QString&)), this, SLOT(addTab(const QString&)));
 	connect(mViewport, SIGNAL(showProgress(bool, int)), this, SLOT(showProgress(bool, int)));
 
@@ -344,9 +338,6 @@ void DkCentralWidget::createLayout() {
 	connect(mTabbar, SIGNAL(tabCloseRequested(int)), this, SLOT(tabCloseRequested(int)));
 	connect(mTabbar, SIGNAL(tabMoved(int, int)), this, SLOT(tabMoved(int, int)));
 
-	// recent files widget
-	connect(mRecentFilesWidget, SIGNAL(loadFileSignal(const QString&)), this, SLOT(loadFile(const QString&)));
-
 	connect(this, SIGNAL(imageHasGPSSignal(bool)), DkActionManager::instance().action(DkActionManager::menu_view_gps_map), SLOT(setEnabled(bool)));
 
 	// preferences
@@ -418,11 +409,6 @@ DkThumbScrollWidget* DkCentralWidget::getThumbScrollWidget() const {
 	return dynamic_cast<DkThumbScrollWidget*>(mWidgets[thumbs_widget]);
 }
 
-DkRecentFilesWidget* DkCentralWidget::getRecentFilesWidget() const {
-
-	return mRecentFilesWidget;
-}
-
 void DkCentralWidget::currentTabChanged(int idx) {
 
 	if (idx < 0 || idx >= mTabInfos.size())
@@ -436,11 +422,6 @@ void DkCentralWidget::currentTabChanged(int idx) {
 	mTabInfos.at(idx)->activate();
 	QSharedPointer<DkImageContainerT> imgC = mTabInfos.at(idx)->getImage();
 
-	//// TODO: this is a fast fix because we release today
-	//// better solution: check why this state might happen
-	//if (!imgC && mTabInfos.at(idx)->getMode() == DkTabInfo::tab_single_image)
-	//	mTabInfos.at(idx)->setMode(DkTabInfo::tab_recent_files);
-
 	if (imgC && mTabInfos.at(idx)->getMode() == DkTabInfo::tab_single_image) {
 		mTabInfos.at(idx)->getImageLoader()->load(imgC);
 		showViewPort();
@@ -448,26 +429,16 @@ void DkCentralWidget::currentTabChanged(int idx) {
 	else if (mTabInfos.at(idx)->getMode() == DkTabInfo::tab_thumb_preview) {
 		showThumbView();
 	}
+	else if (mTabInfos.at(idx)->getMode() == DkTabInfo::tab_recent_files) {
+		showRecentFiles();
+	}
 	else if (mTabInfos.at(idx)->getMode() == DkTabInfo::tab_preferences) {
-		showRecentFiles(false);
 		showPreferences();
 	}
 	else if (mTabInfos.at(idx)->getMode() == DkTabInfo::tab_batch) {
-		showRecentFiles(false);
 		showBatch();
 	}
-	else {
-		showViewPort();
-		mViewport->unloadImage();
-		mViewport->deactivate();
 
-		if (DkSettingsManager::param().app().showRecentFiles)
-			showRecentFiles(true);
-	}
-
-	//qDebug() << "[MARKUS] tab mode: " << mTabInfos.at(idx)->getMode();
-
-	//switchWidget(tabInfos.at(idx)->getMode());
 }
 
 void DkCentralWidget::updateLoader(QSharedPointer<DkImageLoader> loader) const {
@@ -484,6 +455,7 @@ void DkCentralWidget::updateLoader(QSharedPointer<DkImageLoader> loader) const {
 		disconnect(loader.data(), SIGNAL(imageLoadedSignal(QSharedPointer<DkImageContainerT>)), this, SIGNAL(imageLoadedSignal(QSharedPointer<DkImageContainerT>)));
 		disconnect(loader.data(), SIGNAL(imageHasGPSSignal(bool)), this, SIGNAL(imageHasGPSSignal(bool)));
 		disconnect(loader.data(), SIGNAL(updateSpinnerSignalDelayed(bool, int)), this, SLOT(showProgress(bool, int)));
+		disconnect(loader.data(), SIGNAL(loadImageToTab(const QString&)), this, SLOT(loadFileToTab(const QString&)));
 	}
 
 	if (!loader)
@@ -495,26 +467,28 @@ void DkCentralWidget::updateLoader(QSharedPointer<DkImageLoader> loader) const {
 	connect(loader.data(), SIGNAL(imageLoadedSignal(QSharedPointer<DkImageContainerT>)), this, SIGNAL(imageLoadedSignal(QSharedPointer<DkImageContainerT>)), Qt::UniqueConnection);
 	connect(loader.data(), SIGNAL(imageHasGPSSignal(bool)), this, SIGNAL(imageHasGPSSignal(bool)), Qt::UniqueConnection);
 	connect(loader.data(), SIGNAL(updateSpinnerSignalDelayed(bool, int)), this, SLOT(showProgress(bool, int)), Qt::UniqueConnection);
+	connect(loader.data(), SIGNAL(loadImageToTab(const QString&)), this, SLOT(loadFileToTab(const QString&)), Qt::UniqueConnection);
 
 }
 
+void DkCentralWidget::paintEvent(QPaintEvent *) {
+	
+	QStyleOption opt;
+	opt.init(this);
+	QPainter p(this);
+	style()->drawPrimitive(QStyle::PE_Widget, &opt, &p, this);
+}
+
 DkPreferenceWidget* DkCentralWidget::createPreferences() {
 
 	// add preference widget ------------------------------
 	DkActionManager& am = DkActionManager::instance();
 	DkPreferenceWidget* pw = new DkPreferenceWidget(this);
-	connect(pw, SIGNAL(restartSignal()), this, SLOT(restart()));
+	connect(pw, SIGNAL(restartSignal()), this, SLOT(restart()), Qt::UniqueConnection);
 
 	// add actions
-	pw->addActions(am.fileActions().toList());
 	pw->addActions(am.viewActions().toList());
 	pw->addActions(am.editActions().toList());
-	pw->addActions(am.sortActions().toList());
-	pw->addActions(am.toolsActions().toList());
-	pw->addActions(am.panelActions().toList());
-	pw->addActions(am.syncActions().toList());
-	pw->addActions(am.pluginActions().toList());
-	pw->addActions(am.lanActions().toList());
 	pw->addActions(am.helpActions().toList());
 	pw->addActions(am.hiddenActions().toList());
 
@@ -527,7 +501,7 @@ DkPreferenceWidget* DkCentralWidget::createPreferences() {
 	pw->addTabWidget(tab);
 
 	// display preferences
-	tab = new DkPreferenceTabWidget(DkImage::loadIcon(":/nomacs/img/display-settings.svg", s), tr("Display"), this);
+	tab = new DkPreferenceTabWidget(DkImage::loadIcon(":/nomacs/img/display.svg", s), tr("Display"), this);
 	DkDisplayPreference* dp = new DkDisplayPreference(this);
 	tab->setWidget(dp);
 	pw->addTabWidget(tab);
@@ -539,7 +513,7 @@ DkPreferenceWidget* DkCentralWidget::createPreferences() {
 	pw->addTabWidget(tab);
 
 	// file association preferences
-	tab = new DkPreferenceTabWidget(DkImage::loadIcon(":/nomacs/img/nomacs.svg", s), tr("File Associations"), this);
+	tab = new DkPreferenceTabWidget(DkImage::loadIcon(":/nomacs/img/nomacs-bg.svg", s), tr("File Associations"), this);
 	DkFileAssociationsPreference* fap = new DkFileAssociationsPreference(this);
 	tab->setWidget(fap);
 	pw->addTabWidget(tab);
@@ -551,7 +525,7 @@ DkPreferenceWidget* DkCentralWidget::createPreferences() {
 	pw->addTabWidget(tab);
 
 	// file association preferences
-	tab = new DkPreferenceTabWidget(DkImage::loadIcon(":/nomacs/img/manipulation.svg", s), tr("Editor"), this);
+	tab = new DkPreferenceTabWidget(DkImage::loadIcon(":/nomacs/img/sliders.svg", s), tr("Editor"), this);
 	DkEditorPreference* ep = new DkEditorPreference(this);
 	tab->setWidget(ep);
 	pw->addTabWidget(tab);
@@ -561,6 +535,30 @@ DkPreferenceWidget* DkCentralWidget::createPreferences() {
 	return pw;
 }
 
+DkRecentFilesWidget * DkCentralWidget::createRecentFiles() {
+	
+	DkActionManager& am = DkActionManager::instance();
+	DkRecentFilesWidget* rw = new DkRecentFilesWidget(this);
+	rw->registerAction(DkActionManager::instance().action(DkActionManager::menu_file_show_recent));
+
+	// add actions
+	rw->addActions(am.fileActions().toList());
+	rw->addActions(am.viewActions().toList());
+	rw->addActions(am.editActions().toList());
+	rw->addActions(am.sortActions().toList());
+	rw->addActions(am.toolsActions().toList());
+	rw->addActions(am.panelActions().toList());
+	rw->addActions(am.syncActions().toList());
+	rw->addActions(am.pluginActions().toList());
+	rw->addActions(am.helpActions().toList());
+	rw->addActions(am.hiddenActions().toList());
+
+	connect(rw, SIGNAL(loadFileSignal(const QString&, bool)), this, SLOT(loadFile(const QString&, bool)));
+	connect(rw, SIGNAL(loadDirSignal(const QString&)), this, SLOT(loadDirToTab(const QString&)));
+
+	return rw;
+}
+
 DkThumbScrollWidget* DkCentralWidget::createThumbScrollWidget() {
 
 	DkThumbScrollWidget* thumbScrollWidget = new DkThumbScrollWidget(this);
@@ -574,14 +572,13 @@ DkThumbScrollWidget* DkCentralWidget::createThumbScrollWidget() {
 	thumbScrollWidget->addActions(am.sortActions().toList());
 	thumbScrollWidget->addActions(am.toolsActions().toList());
 	thumbScrollWidget->addActions(am.panelActions().toList());
-	thumbScrollWidget->addActions(am.syncActions().toList());
+	//thumbScrollWidget->addActions(am.syncActions().toList());
 	thumbScrollWidget->addActions(am.pluginActions().toList());
-	thumbScrollWidget->addActions(am.lanActions().toList());
 	thumbScrollWidget->addActions(am.helpActions().toList());
 	thumbScrollWidget->addActions(am.hiddenActions().toList());
 
 	// thumbnail preview widget
-	connect(thumbScrollWidget->getThumbWidget(), SIGNAL(loadFileSignal(const QString&)), this, SLOT(loadFile(const QString&)));
+	connect(thumbScrollWidget->getThumbWidget(), SIGNAL(loadFileSignal(const QString&, bool)), this, SLOT(loadFile(const QString&, bool)));
 	connect(thumbScrollWidget, SIGNAL(batchProcessFilesSignal(const QStringList&)), this, SLOT(openBatch(const QStringList&)));
 
 	return thumbScrollWidget;
@@ -621,26 +618,28 @@ void DkCentralWidget::setTabList(QVector<QSharedPointer<DkTabInfo> > tabInfos, i
 
 }
 
-void DkCentralWidget::addTab(const QString& filePath, int idx /* = -1 */) {
+void DkCentralWidget::addTab(const QString& filePath, int idx /* = -1 */, bool background) {
 
 	QSharedPointer<DkImageContainerT> imgC = QSharedPointer<DkImageContainerT>(new DkImageContainerT(filePath));
-	addTab(imgC, idx);
+	addTab(imgC, idx, background);
 }
 
-void DkCentralWidget::addTab(QSharedPointer<DkImageContainerT> imgC, int idx /* = -1 */) {
+void DkCentralWidget::addTab(QSharedPointer<DkImageContainerT> imgC, int idx /* = -1 */, bool background) {
 
 	if (idx == -1)
 		idx = mTabInfos.size();
 
 	QSharedPointer<DkTabInfo> tabInfo = QSharedPointer<DkTabInfo>(new DkTabInfo(imgC, idx));
-	addTab(tabInfo);
+	addTab(tabInfo, background);
 }
 
-void DkCentralWidget::addTab(QSharedPointer<DkTabInfo> tabInfo) {
+void DkCentralWidget::addTab(QSharedPointer<DkTabInfo> tabInfo, bool background) {
 
 	mTabInfos.push_back(tabInfo);
 	mTabbar->addTab(tabInfo->getTabText());
-	mTabbar->setCurrentIndex(tabInfo->getTabIdx());
+	
+	if (!background)
+		mTabbar->setCurrentIndex(tabInfo->getTabIdx());
 
 	if (mTabInfos.size() > 1)
 		mTabbar->show();
@@ -733,6 +732,7 @@ void DkCentralWidget::previousTab() const {
 }
 
 void DkCentralWidget::setActiveTab(int idx) const {
+	
 	if (mTabInfos.size() < 2)
 		return;
 
@@ -763,8 +763,6 @@ void DkCentralWidget::imageLoaded(QSharedPointer<DkImageContainerT> img) {
 		updateTab(tabInfo);
 		switchWidget(tabInfo->getMode());
 	}
-
-	mRecentFilesWidget->hide();
 }
 
 QVector<QSharedPointer<DkTabInfo> > DkCentralWidget::getTabs() const {
@@ -830,14 +828,20 @@ void DkCentralWidget::showViewPort(bool show /* = true */) {
 
 void DkCentralWidget::showRecentFiles(bool show) {
 
-	// TODO: fix the missing recent files (e.g. after the thumbnails are loaded once)
-	if (show && currentViewMode() != DkTabInfo::tab_preferences) {
-		mRecentFilesWidget->setCustomStyle(!mViewport->getImage().isNull() || (getThumbScrollWidget() && getThumbScrollWidget()->isVisible()));
-		mRecentFilesWidget->raise();
-		mRecentFilesWidget->show();
+	if (show) {
+
+		// create the preferences...
+		if (!mWidgets[recent_files_widget]) {
+			mWidgets[recent_files_widget] = createRecentFiles();
+			mViewLayout->insertWidget(recent_files_widget, mWidgets[recent_files_widget]);
+		}
+
+		switchWidget(mWidgets[recent_files_widget]);
+	}
+	else {
+		// toggle back to image
+		showViewPort();
 	}
-	else
-		mRecentFilesWidget->hide();
 }
 
 void DkCentralWidget::showPreferences(bool show) {
@@ -848,13 +852,11 @@ void DkCentralWidget::showPreferences(bool show) {
 		if (!mWidgets[preference_widget]) {
 			mWidgets[preference_widget] = createPreferences();
 			mViewLayout->insertWidget(preference_widget, mWidgets[preference_widget]);
-			connect(mWidgets[preference_widget], SIGNAL(restartSignal()), this, SLOT(restart()));
+			connect(mWidgets[preference_widget], SIGNAL(restartSignal()), this, SLOT(restart()), Qt::UniqueConnection);
 		}
 		
 		switchWidget(mWidgets[preference_widget]);
 	}
-	//else
-	//	mRecentFilesWidget->hide();
 }
 
 void DkCentralWidget::showBatch(bool show) {
@@ -902,10 +904,10 @@ void DkCentralWidget::switchWidget(int widget) {
 		switchWidget(mWidgets[thumbs_widget]);
 	else if (widget == DkTabInfo::tab_preferences)
 		switchWidget(mWidgets[preference_widget]);
+	else if (widget == DkTabInfo::tab_recent_files)
+		switchWidget(mWidgets[recent_files_widget]);
 	else
 		qDebug() << "Sorry, I cannot switch to widget: " << widget;
-
-	//recentFilesWidget->hide();
 }
 
 void DkCentralWidget::switchWidget(QWidget* widget) {
@@ -918,14 +920,14 @@ void DkCentralWidget::switchWidget(QWidget* widget) {
 	else
 		mViewLayout->setCurrentWidget(mWidgets[viewport_widget]);
 
-	mRecentFilesWidget->hide();
-
 	if (!mTabInfos.isEmpty()) {
 		
 		int mode = DkTabInfo::tab_single_image;
 
 		if (widget == mWidgets[thumbs_widget])
 			mode = DkTabInfo::tab_thumb_preview;
+		else if (widget == mWidgets[recent_files_widget])
+			mode = DkTabInfo::tab_recent_files;
 		else if (widget == mWidgets[preference_widget])
 			mode = DkTabInfo::tab_preferences;
 		else if (widget == mWidgets[batch_widget])
@@ -968,6 +970,11 @@ void DkCentralWidget::showProgress(bool show, int time) {
 	mProgressBar->setVisibleTimed(show, time);
 }
 
+void DkCentralWidget::startSlideshow(bool start) const {
+
+	getViewPort()->getController()->startSlideshow(start);
+}
+
 QSharedPointer<DkImageContainerT> DkCentralWidget::getCurrentImage() const {
 
 	if (mTabInfos.empty())
@@ -1015,11 +1022,6 @@ void DkCentralWidget::dragEnterEvent(QDragEnterEvent *event) {
 	QWidget::dragEnterEvent(event);
 }
 
-void DkCentralWidget::loadFile(const QString& filePath) {
-
-	mViewport->loadFile(filePath);
-}
-
 void DkCentralWidget::loadDir(const QString& filePath) {
 
 	if (mTabInfos[mTabbar->currentIndex()]->getMode() == DkTabInfo::tab_thumb_preview && getThumbScrollWidget())
@@ -1028,35 +1030,20 @@ void DkCentralWidget::loadDir(const QString& filePath) {
 		mViewport->loadFile(filePath);
 }
 
-
 void DkCentralWidget::loadFileToTab(const QString& filePath) {
 
-    if (mTabInfos.size() > 1){
-        // this is the first one: open a new tab
-        addTab(filePath);
-    }
-	else {
-        // we already have some opened tabs.
-        int currentTabIdx = mTabbar->currentIndex();
-        enum DkTabInfo::TabMode currentTabMode = mTabInfos[currentTabIdx]->getMode();
+	loadFile(filePath, true);
+}
 
-        if (currentTabMode == DkTabInfo::tab_thumb_preview ||
-            currentTabMode == DkTabInfo::tab_recent_files ||
-            currentTabMode == DkTabInfo::tab_single_image ||
-            currentTabMode == DkTabInfo::tab_empty) {
+void DkCentralWidget::loadFile(const QString& filePath, bool newTab) {
 
-			loadFile(filePath);
-            //// reuse the currently open tab.
-            //mTabInfos.at(currentTabIdx)->setFilePath(filePath);
-            //updateTab(mTabInfos.at(currentTabIdx));
-            //currentTabChanged(currentTabIdx);
+	if (!newTab) {
+		mViewport->loadFile(filePath);
+		return;
+	}
 
-        }
-		else {
-            // no tab to reuse. open create a new tab
-            addTab(filePath);
-        }
-    }
+    // no tab to reuse -> create a new tab
+    addTab(filePath, -1, mTabInfos.size() > 0);
 }
 
 /**
@@ -1092,54 +1079,6 @@ void DkCentralWidget::loadDirToTab(const QString& dirPath) {
     mViewport->getController()->setInfo(tr("I could not load \"%1\"").arg(dirPath));
 }
 
-/** loadUrl() loads a single valid url
- *  @param loadInTab: if true, replace the currently active image, so it exists.
- */
-void DkCentralWidget::loadUrl(const QUrl& url, bool loadInTab) {
-    Q_ASSERT(url.isValid());
-
-    // TODO decide cases where we just load over the current image
-    Q_UNUSED(loadInTab);
-    Q_ASSERT(loadInTab == true);
-
-	// url.toString fixes windows "C:/" vs "C:\"
-    QFileInfo fi(url.toString());
-
-	if (!fi.exists()) {
-		fi = QFileInfo(url.toLocalFile());
-	}
-
-    auto display = [&](QString msg){
-        mViewport->getController()->setInfo(msg.arg(msg));
-    };
-
-    if (fi.exists()) {
-        
-		if (fi.isFile()) {
-            // load a local file
-            if (DkUtils::isValid(fi)) {
-                loadFileToTab(fi.filePath());
-            } 
-			else {
-                display(tr("Unable to load file \"%1\"").arg(fi.canonicalPath()));
-            }
-        } 
-		else if(fi.isDir()) {
-            // load a directory as thmbnail view
-            loadDirToTab(fi.filePath());
-        }
-		else {
-            display(tr("\"%1\" cannot be loaded").arg(fi.canonicalPath()));
-        }
-    }
-	else {
-       //load a remote url
-        QSharedPointer<DkTabInfo> targetTab = mTabInfos[mTabbar->currentIndex()];
-        display(tr("downloading \"%1\"").arg(url.toDisplayString()));
-        targetTab->getImageLoader()->downloadFile(url);
-    }
-}
-
 /** loadUrls() loads a list of valid urls.
  * @param maxUrlsToLoad determines the maximum
  */
@@ -1148,15 +1087,67 @@ void DkCentralWidget::loadUrls(const QList<QUrl>& urls, int maxUrlsToLoad) {
 	if(urls.size() == 0)
         return;
 
-    if(urls.size() > maxUrlsToLoad){
-        QString urlsWarning(tr("Too many urls to load. Loading only the first %1"));
-        qDebug() << urlsWarning.arg(urls.size());
-    }
+    if(urls.size() > maxUrlsToLoad)
+		qWarning() << "Too many urls found, I will only load the first" << maxUrlsToLoad;
 
-    for (int idx = 0; idx < urls.size() && idx < maxUrlsToLoad; idx++) {
-        QUrl url = urls[idx];
-        loadUrl(url);
-    }
+	if (urls.size() == 1)
+		loadUrl(urls[0], false);
+	else {
+
+		for (const QUrl& url : urls)
+			loadUrl(url, true);
+	}
+}
+
+/** loadUrl() loads a single valid url
+*  @param loadInTab: if true, replace the currently active image, so it exists.
+*/
+void DkCentralWidget::loadUrl(const QUrl& url, bool newTab) {
+	Q_ASSERT(url.isValid());
+
+	QString fp = url.toString();
+
+	// allow drops from VSCode (i.e. images in README files)
+	if (fp.startsWith("vscode-resource:/"))
+		fp = fp.remove("vscode-resource:/");
+
+	// url.toString fixes windows "C:/" vs "C:\"
+	QFileInfo fi(fp);
+
+	if (!fi.exists()) {
+		fi = QFileInfo(url.toLocalFile());
+	}
+
+	auto display = [&](QString msg) {
+		mViewport->getController()->setInfo(msg);
+	};
+
+	if (fi.exists()) {
+
+		if (fi.isFile()) {
+			
+			// load a local file
+			if (DkUtils::isValid(fi)) {
+				loadFile(fi.filePath(), newTab);
+			}
+			else {
+				display(tr("Unable to load file \"%1\"").arg(fi.canonicalPath()));
+			}
+		}
+		else if (fi.isDir()) {
+			// load a directory as thmbnail view
+			loadDirToTab(fi.filePath());
+		}
+		else {
+			display(tr("\"%1\" cannot be loaded").arg(fi.canonicalPath()));
+		}
+	}
+	else {
+		//load a remote url
+		QSharedPointer<DkTabInfo> targetTab = mTabInfos[mTabbar->currentIndex()];
+		display(tr("downloading \"%1\"").arg(url.toDisplayString()));
+		targetTab->getImageLoader()->downloadFile(url);
+	}
 }
 
 void DkCentralWidget::openBatch(const QStringList& selectedFiles) {
@@ -1202,7 +1193,7 @@ void DkCentralWidget::pasteImage() {
 
 void DkCentralWidget::dropEvent(QDropEvent *event) {
 
-	if (event->source() == this) {
+	if (event->source() == this || event->source() == mViewport) {
 		event->accept();
 		return;
 	}
@@ -1218,16 +1209,45 @@ bool DkCentralWidget::loadFromMime(const QMimeData* mimeData) {
         return false;
 
     QStringList mimeFmts = mimeData->formats();
-    qDebug() << "loading mime data with formats: " << mimeFmts;
 
-    if (mimeData->hasImage()) {
+	// try to load an image
+	QImage dropImg;
+
+	// first see if we have MS mime data
+	// since i.e. outlook also add thumbnails, we try to first load the high quality stuff
+	for (const QString& fmt : mimeFmts) {
+	
+		//qDebugClean() << "mime format:" << fmt << " " << mimeData->data(fmt).size()/1024.0 << "KB";
+
+		if (fmt.contains("Office Drawing Shape Format")) {
+
+			// try to get rid of all decorations
+			QSharedPointer<QByteArray> ba(new QByteArray(DkImage::extractImageFromDataStream(mimeData->data(fmt))));
+
+			if (!ba->isEmpty()) {
+				DkBasicLoader bl;
+				bl.loadGeneral("", ba);
+
+				dropImg = bl.image();
+
+				if (!dropImg.isNull())
+					qDebug() << "image loaded from MS data";
+				break;
+			}
+		}
+	}
+
+    if (dropImg.isNull() && mimeData->hasImage()) {
         // we got an image buffer
-
-        QImage dropImg = qvariant_cast<QImage>(mimeData->imageData());
-        mViewport->loadImage(dropImg);
-        return true;
+        dropImg = qvariant_cast<QImage>(mimeData->imageData());
+		qInfo() << "Qt image loaded from mime";
     }
 
+	if (!dropImg.isNull()) {
+		mViewport->loadImage(dropImg);
+		return true;
+	}
+
     // parse mime data. get a non-empty list of urls. url is the first.
     QList<QUrl> urls;
 
@@ -1239,7 +1259,7 @@ bool DkCentralWidget::loadFromMime(const QMimeData* mimeData) {
 				urls.append(u);
 		}
 	}
-    else if(mimeData->formats().contains("text/plain")) {
+    else if (mimeData->formats().contains("text/plain")) {
         //we got text data. maybe it is a list of urls
         urls = DkUtils::findUrlsInTextNewline(mimeData->text());
     }
@@ -1249,7 +1269,7 @@ bool DkCentralWidget::loadFromMime(const QMimeData* mimeData) {
         return false;
     }
 
-    if(urls.size() == 0){
+    if(urls.size() == 0) {
         return false;
     }
 
@@ -1284,7 +1304,8 @@ bool DkCentralWidget::loadFromMime(const QMimeData* mimeData) {
 
 /** load a number of Cascade Trainig files */
 bool DkCentralWidget::loadCascadeTrainingFiles(QList<QUrl> urls) {
-    QStringList vecFiles;
+    
+	QStringList vecFiles;
 
     if (urls.size() > 1 && urls.at(0).toLocalFile().endsWith("vec")) {
 
