@@ -57,6 +57,7 @@ class QLabel;
 class QComboBox;
 class QCheckBox;
 class QProgressBar;
+class QSettings;
 
 namespace nmc {
 
@@ -67,6 +68,7 @@ class DkSlider;
 class DkButton;
 class DkThumbNail;
 class DkAppManager;
+class DkDisplayWidget;
 
 // needed because of http://stackoverflow.com/questions/1891744/pyqt4-qspinbox-selectall-not-working-as-expected 
 // and http://qt-project.org/forums/viewthread/8590
@@ -356,6 +358,8 @@ public:
 
 	QWidget* createEditor(QWidget* parent, const QStyleOptionViewItem& option, const QModelIndex& index) const;
 
+	QSize sizeHint(const QStyleOptionViewItem &option, const QModelIndex &index) const override;
+
 signals:
 	void checkDuplicateSignal(const QString& text, void* item);
 	void checkDuplicateSignal(const QKeySequence& keySequence, void* item);
@@ -368,27 +372,11 @@ protected slots:
 protected:
 	bool editorEvent(QEvent* event, QAbstractItemModel* model, const QStyleOptionViewItem& option, const QModelIndex& index);
 	void setEditorData(QWidget* editor, const QModelIndex& index) const;
-	void* item;
+	void* mItem;
 	//virtual void setEditorData(QWidget* editor, const QModelIndex& index) const;
+	void paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const override;
 
-};
-
-class DkShortcutEditor : public QLineEdit {
-	Q_OBJECT
-	Q_PROPERTY(QKeySequence shortcut READ shortcut WRITE setShortcut)
-
-public:
-	DkShortcutEditor(QWidget *widget = 0);
-	QKeySequence shortcut() const;
-	void setShortcut(const QKeySequence shortcut);
-
-protected:
-	//void keyPressEvent(QKeyEvent *event);
-	//void keyReleaseEvent(QKeyEvent* event);
-	bool eventFilter(QObject *obj, QEvent *event);
-
-	QKeySequence ks;
-
+	QPixmap mClearPm;
 };
 
 class DkShortcutsModel : public QAbstractItemModel {
@@ -397,7 +385,6 @@ class DkShortcutsModel : public QAbstractItemModel {
 public:
 	DkShortcutsModel(QObject* parent = 0);
 	~DkShortcutsModel();
-	//DkShortcutsModel(QVector<QPair<QString, QKeySequence> > actions, QObject *parent = 0);
 
 	QModelIndex index(int row, int column, const QModelIndex &parent) const;
 	QModelIndex parent(const QModelIndex &index) const;
@@ -494,50 +481,62 @@ protected:
 	QPushButton* cancelButton;
 };
 
+class DkPrintImage {
+
+public:
+	DkPrintImage(const QImage& img = QImage(), QPrinter* printer = 0);
+
+	QImage image() const;
+	void draw(QPainter& p, bool highQuality = false);
+
+	void fit();
+	void center();
+	void scale(double sf);
+
+	double dpi();
+
+private:
+	void center(QTransform & t) const;
+
+	QImage mImg;
+	QPrinter* mPrinter;
+
+	QTransform mTransform;
+};
+
 
 class DkPrintPreviewWidget : public QPrintPreviewWidget {
 	Q_OBJECT
+
 public:
 	DkPrintPreviewWidget(QPrinter* printer, QWidget* parent = 0, Qt::WindowFlags flags = 0);
 
+	void setImage(const QImage& img);
+	void addImage(const QImage& img);
+	void fitImages();
+
+public slots:
+	void paintForPrinting();
+	void paintPreview(QPrinter *printer);
+	void changeDpi(int value);
+	void centerImage();
+
+	void setLandscapeOrientation();
+	void setPortraitOrientation();
+
 signals:
 	void zoomChanged() const;
+	void dpiChanged(int dpi);
 
 protected:
-	virtual void wheelEvent(QWheelEvent *event);		
+	virtual void wheelEvent(QWheelEvent *event) override;
+	virtual void paintEvent(QPaintEvent *event) override;
 
-
-};
-
-class DkPrintPreviewValidator : public QDoubleValidator {
-	
-public:
-	DkPrintPreviewValidator(const QString& suffix, qreal bottom, qreal top, int decimals, QObject* parent) : QDoubleValidator(bottom, top, decimals, parent) { this->suffix = suffix;};
-	State validate(QString &input, int &pos) const {
-		bool replaceSuffix = false;
-		if (input.endsWith(suffix)) {
-			input = input.left(input.length() - suffix.length());
-			replaceSuffix = true;
-		}
-		State state = QDoubleValidator::validate(input, pos);
-		if (replaceSuffix)
-			input += suffix;
-		const int num_size = 4+suffix.length();
-		if (state == Intermediate) {
-			int i = input.indexOf(QLocale::system().decimalPoint());
-			if ((i == -1 && input.size() > num_size)
-				|| (i != -1 && i > num_size))
-				return Invalid;
-		}
-
-		return state;			
-	}
 private:
-	QString suffix;
+	QPrinter* mPrinter;
+	QVector<QSharedPointer<DkPrintImage> > mPrintImages;
 };
 
-
-
 class DkPrintPreviewDialog : public QMainWindow {
 	Q_OBJECT
 
@@ -555,73 +554,40 @@ public:
 		print_end,
 	};
 
-	DkPrintPreviewDialog(const QImage& img, float dpi, QPrinter* printer = 0, QWidget* parent = 0, Qt::WindowFlags flags = 0);
-	void setImage(const QImage& img, float dpi);
+	DkPrintPreviewDialog(QWidget* parent = 0, Qt::WindowFlags flags = 0);
+	
+	void setImage(const QImage& img);
+	void addImage(const QImage& img);
+
 	void init();
 
 public slots:
 	void updateZoomFactor();
 
 protected:
-	void setupActions();
 	void createLayout();
-	void setIcon(QAction* action, const QLatin1String &name);
 	void createIcons();
 
 private slots:
-	void paintRequested(QPrinter* printer);
-	void fitImage(QAction* action);
 	void zoomIn();
 	void zoomOut();
-	void zoomFactorChanged();
-	void dpiFactorChanged();
 	void updateDpiFactor(qreal dpi);
-	void resetDpi();
 	void pageSetup();
 	void print();
-	void centerImage();
+
+	void zoom(int scale);
+	void previewFitWidth();
+	void previewFitPage();
+
 
 private:
-	void setFitting(bool on);
-	void scaleImage();
-	bool isFitting();
-		
-	QImage mImg;
-
-	QActionGroup* mFitGroup = 0;
-	QAction* mFitWidthAction = 0;
-	QAction* mFitPageAction = 0;
-	
-	QActionGroup* mZoomGroup = 0;
-	QAction* mZoomInAction = 0;
-	QAction* mZoomOutAction = 0;
-
-	QActionGroup* mOrientationGroup = 0;
-	QAction* mPortraitAction = 0;
-	QAction* mLandscapeAction = 0;
-
-	QActionGroup* mPrinterGroup = 0;
-	QAction* mPrintAction = 0;
-	QAction* mPageSetupAction = 0;
-
-	QActionGroup* mDpiGroup = 0;
-	QAction* mResetDpiAction = 0;
-
-	QComboBox* mZoomFactor = 0;
-	QComboBox* mDpiFactor = 0;
-	QString mDpiEditorSuffix;
-
+	QSpinBox* mZoomFactor = 0;
+	QSpinBox* mDpiBox = 0;
 
 	DkPrintPreviewWidget* mPreview = 0;
 	QPrinter* mPrinter = 0;
-	QPrintDialog* mPrintDialog = 0;
 
 	QVector<QIcon> mIcons;
-
-	QTransform mImgTransform;
-
-	float mDpi = 150;
-	float mOrigDpi = 150;
 };
 
 class DkOpacityDialog : public QDialog {
@@ -824,6 +790,57 @@ protected:
 	bool mLanguageChanged = false;
 };
 
+class DkSvgSizeDialog : public QDialog {
+	Q_OBJECT
+
+public:
+	DkSvgSizeDialog(const QSize& size, QWidget* parent);
+
+	QSize size() const;
+
+public slots:
+	void on_width_valueChanged(int val);
+	void on_height_valueChanged(int val);
+
+private:
+	void createLayout();
+
+	enum {
+		b_width,
+		b_height,
+
+		b_end
+	};
+
+	double mARatio = 0;
+	QSize mSize;
+	QVector<QSpinBox*> mSizeBox;
+};
+
+class DkChooseMonitorDialog : public QDialog {
+	Q_OBJECT
+
+public:
+	DkChooseMonitorDialog(QWidget* parent);
+
+	QRect screenRect() const;
+	bool showDialog() const;
+
+public slots:
+	int exec() override;
+
+private:
+	void createLayout();
+	QList<QScreen*> screens() const;
+	void loadSettings();
+	void saveSettings() const;
+
+	QList<QScreen*> mScreens;
+	DkDisplayWidget* mDisplayWidget;
+	QCheckBox* mCbRemember;
+};
+
+
 #ifdef WITH_QUAZIP
 class DkArchiveExtractionDialog : public QDialog {
 	Q_OBJECT
@@ -869,7 +886,7 @@ class DkDialogManager : public QObject {
 public:
 	DkDialogManager(QObject* parent = 0);
 
-	public slots:
+public slots:
 	void openShortcutsDialog() const;
 	void openAppManager() const;
 };
