@@ -21,7 +21,7 @@
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
  related links:
- [1] http://www.nomacs.org/
+ [1] https://nomacs.org/
  [2] https://github.com/nomacs/
  [3] http://download.nomacs.org
  *******************************************************************************************************/
@@ -55,6 +55,7 @@ DkManipulatorWidget::DkManipulatorWidget(QWidget* parent) : DkWidget(parent) {
 	mWidgets << new DkRotateWidget(am.manipulatorManager().manipulatorExt(DkManipulatorManager::m_rotate), this);
 	mWidgets << new DkThresholdWidget(am.manipulatorManager().manipulatorExt(DkManipulatorManager::m_threshold), this);
 	mWidgets << new DkHueWidget(am.manipulatorManager().manipulatorExt(DkManipulatorManager::m_hue), this);
+	mWidgets << new DkColorWidget(am.manipulatorManager().manipulatorExt(DkManipulatorManager::m_color), this);
 	mWidgets << new DkExposureWidget(am.manipulatorManager().manipulatorExt(DkManipulatorManager::m_exposure), this);
 
 	setObjectName("DkPreferenceTabs");
@@ -85,7 +86,7 @@ void DkManipulatorWidget::createLayout() {
 		auto mpl = am.manipulatorManager().manipulatorExt((DkManipulatorManager::ManipulatorExtId)idx);
 
 		DkTabEntryWidget* entry = new DkTabEntryWidget(mpl->action()->icon(), mpl->name(), this);
-		connect(entry, SIGNAL(clicked()), mpl->action(), SIGNAL(triggered()), Qt::UniqueConnection);	// TODO: different connection if ManipulatorExt?
+		connect(entry, SIGNAL(clicked()), mpl->action(), SIGNAL(triggered()), Qt::UniqueConnection);
 		
 		aLayout->addWidget(entry);
 		group->addButton(entry);
@@ -137,7 +138,6 @@ void DkManipulatorWidget::createLayout() {
 	QWidget* mplWidget = new QWidget(this);
 	QVBoxLayout* mplLayout = new QVBoxLayout(mplWidget);
 	mplLayout->setAlignment(Qt::AlignTop | Qt::AlignHCenter);
-	
 	mplLayout->addWidget(mTitleLabel);
 	for (QWidget* w : mWidgets) 
 		mplLayout->addWidget(w);
@@ -167,7 +167,7 @@ void DkManipulatorWidget::setImage(QSharedPointer<DkImageContainerT> imgC) {
 
 	if (mImgC) {
 
-		QImage img = mImgC->imageScaledToWidth(qMin(mPreview->width(), 300));
+		QImage img = mImgC->imageScaledToWidth(qMin(mPreview->width(), mMaxPreview));
 		img = scaledPreview(img);
 
 		mPreview->setPixmap(QPixmap::fromImage(img));
@@ -188,7 +188,7 @@ void DkManipulatorWidget::selectManipulator() {
 	// compute preview
 	if (mpl && mImgC) {
 		DkTimer dt;
-		QImage img = mpl->apply(mImgC->imageScaledToWidth(qMin(mPreview->width(), 300)));
+		QImage img = mpl->apply(mImgC->imageScaledToWidth(qMin(mPreview->width(), mMaxPreview)));
 		img = scaledPreview(img);
 
 		if (!img.isNull())
@@ -204,6 +204,11 @@ void DkManipulatorWidget::selectManipulator() {
 		return;
 	}
 
+	if (!mplExt->widget()) {
+		qCritical() << action->text() << "does not have a corresponding UI";
+		return;
+	}
+
 	mplExt->widget()->show();
 	mTitleLabel->setText(mpl->name());
 }
@@ -385,6 +390,34 @@ void DkThresholdWidget::on_thrSlider_valueChanged(int val) {
 	manipulator()->setThreshold(val);
 }
 
+// -------------------------------------------------------------------- DkColorWidget 
+DkColorWidget::DkColorWidget(QSharedPointer<DkBaseManipulatorExt> manipulator, QWidget* parent) : DkBaseManipulatorWidget(manipulator, parent) {
+	createLayout();
+
+	QMetaObject::connectSlotsByName(this);
+
+	manipulator->setWidget(this);
+	setMinimumHeight(150);
+}
+
+QSharedPointer<DkColorManipulator> DkColorWidget::manipulator() const {
+	return qSharedPointerDynamicCast<DkColorManipulator>(baseManipulator());
+}
+
+void DkColorWidget::createLayout() {
+
+	DkColorPicker* cp = new DkColorPicker(this);
+	cp->setObjectName("colPicker");
+
+	QVBoxLayout* l = new QVBoxLayout(this);
+	l->setContentsMargins(0, 0, 0, 0);
+	l->addWidget(cp);
+}
+
+void DkColorWidget::on_colPicker_colorSelected(const QColor& col) {
+	manipulator()->setColor(col);
+}
+
 // DkHueWidget --------------------------------------------------------------------
 DkHueWidget::DkHueWidget(QSharedPointer<DkBaseManipulatorExt> manipulator, QWidget* parent) : DkBaseManipulatorWidget(manipulator, parent) {
 	createLayout();
@@ -447,7 +480,6 @@ DkExposureWidget::DkExposureWidget(QSharedPointer<DkBaseManipulatorExt> manipula
 	manipulator->setWidget(this);
 }
 
-
 QSharedPointer<DkExposureManipulator> DkExposureWidget::manipulator() const {
 	return qSharedPointerDynamicCast<DkExposureManipulator>(baseManipulator());
 }
