@@ -544,7 +544,7 @@ void DkMetaDataSelection::createLayout() {
 	scrollArea->setMinimumSize(QSize(200, 200));
 	scrollArea->setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding);
 	scrollArea->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
-	scrollArea->setBackgroundRole(QPalette::Light);
+	//scrollArea->setBackgroundRole(QPalette::Light);
 	scrollArea->setWidget(lWidget);
 
 	mCbCheckAll = new QCheckBox(tr("Check All"), this);
@@ -1179,14 +1179,14 @@ void DkCommentWidget::createLayout() {
 	QPushButton* saveButton = new QPushButton(this);
 	saveButton->setObjectName("saveButton");
 	saveButton->setFlat(true);
-	saveButton->setIcon(QIcon(DkImage::colorizePixmap(QIcon(":/nomacs/img/save.svg").pixmap(DkSettingsManager::param().effectiveIconSize()), DkSettingsManager::param().display().hudFgdColor, 1.0f)));
+	saveButton->setIcon(DkImage::loadIcon(":/nomacs/img/save.svg", QSize(), DkSettingsManager::param().display().hudFgdColor));
 	saveButton->setToolTip(tr("Save Note (CTRL + ENTER)"));
 	saveButton->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_Return));
 
 	QPushButton* cancelButton = new QPushButton(this);
 	cancelButton->setObjectName("cancelButton");
 	cancelButton->setFlat(true);
-	cancelButton->setIcon(QIcon(DkImage::colorizePixmap(QIcon(":/nomacs/img/trash.svg").pixmap(DkSettingsManager::param().effectiveIconSize()), DkSettingsManager::param().display().hudFgdColor, 1.0f)));
+	cancelButton->setIcon(DkImage::loadIcon(":/nomacs/img/trash.svg", QSize(), DkSettingsManager::param().display().hudFgdColor));
 	cancelButton->setToolTip(tr("Discard Changes (ESC)"));
 	cancelButton->setShortcut(QKeySequence(Qt::Key_Escape));
 
