@@ -118,14 +118,13 @@ DkNoMacs::DkNoMacs(QWidget *parent, Qt::WindowFlags flags)
 
 	mMenu = new DkMenuBar(this, -1);
 
-	DkActionManager::instance().createActions(this);
-	DkActionManager::instance().createMenus(mMenu);
+	DkActionManager& am = DkActionManager::instance();
+	am.createActions(this);
+	am.createMenus(mMenu);
+	am.enableImageActions(false);
 
 	mSaveSettings = true;
 
-	// load settings
-	//DkSettings::load();
-	
 	mOpenDialog = 0;
 	mSaveDialog = 0;
 	mThumbSaver = 0;
@@ -166,7 +165,6 @@ DkNoMacs::DkNoMacs(QWidget *parent, Qt::WindowFlags flags)
 
 	//qDebug() << "3987 ^ 12 + 4365 ^ 12 = " << pow(an + bn, 1/12.0) << "^ 12";
 	//qDebug() << "Sorry Fermat, but the Simpsons are right.";
-
 }
 
 DkNoMacs::~DkNoMacs() {
@@ -190,7 +188,6 @@ void DkNoMacs::init() {
 	createContextMenu();
 	createToolbar();
 	createStatusbar();
-	enableNoImageActions(false);
 
 	// TODO - just for android register me as a gesture recognizer
 	grabGesture(Qt::PanGesture);
@@ -201,13 +198,14 @@ void DkNoMacs::init() {
 	readSettings();
 	installEventFilter(this);
 
-	showMenuBar(DkSettingsManager::param().app().showMenuBar);
-	showToolBar(DkSettingsManager::param().app().showToolBar);
-	showStatusBar(DkSettingsManager::param().app().showStatusBar);
+	if (DkSettingsManager::param().app().appMode != DkSettings::mode_frameless) {
+		showToolBar(DkSettingsManager::param().app().showToolBar);
+		showMenuBar(DkSettingsManager::param().app().showMenuBar);
+		showStatusBar(DkSettingsManager::param().app().showStatusBar);
+	}
 
 	// connects that are needed in all viewers
 	connect(viewport(), SIGNAL(showStatusBar(bool, bool)), this, SLOT(showStatusBar(bool, bool)));
-	connect(viewport(), SIGNAL(enableNoImageSignal(bool)), this, SLOT(enableNoImageActions(bool)));
 
 	// connections to the image loader
 	connect(getTabWidget(), SIGNAL(imageUpdatedSignal(QSharedPointer<DkImageContainerT>)), this, SLOT(setWindowTitle(QSharedPointer<DkImageContainerT>)));
@@ -230,7 +228,7 @@ void DkNoMacs::init() {
 		}
 	}
 #endif // Q_WS_WIN
-
+	
 	//QTimer::singleShot(0, this, SLOT(onWindowLoaded()));
 }
 
@@ -241,9 +239,6 @@ void DkNoMacs::createToolbar() {
 
 	mToolbar->setIconSize(QSize(DkSettingsManager::param().effectiveIconSize(this), DkSettingsManager::param().effectiveIconSize(this)));
 
-	if (DkSettingsManager::param().display().toolbarGradient)
-		mToolbar->setObjectName("toolBarWithGradient");
-
 	DkActionManager& am = DkActionManager::instance();
 
 	mToolbar->addAction(am.action(DkActionManager::menu_file_prev));
@@ -289,10 +284,6 @@ void DkNoMacs::createToolbar() {
 	mMovieToolbar->addAction(am.action(DkActionManager::menu_view_movie_prev));
 	mMovieToolbar->addAction(am.action(DkActionManager::menu_view_movie_pause));
 	mMovieToolbar->addAction(am.action(DkActionManager::menu_view_movie_next));
-
-	if (DkSettingsManager::param().display().toolbarGradient)
-		mMovieToolbar->setObjectName("toolBarWithGradient");
-
 	mMovieToolbar->setIconSize(QSize(DkSettingsManager::param().effectiveIconSize(this), DkSettingsManager::param().effectiveIconSize(this)));
 
 	mToolbar->allActionsAdded();
@@ -370,7 +361,6 @@ void DkNoMacs::createActions() {
 	connect(am.action(DkActionManager::menu_edit_transform), SIGNAL(triggered()), this, SLOT(resizeImage()));
 	connect(am.action(DkActionManager::menu_edit_delete), SIGNAL(triggered()), this, SLOT(deleteFile()));
 	connect(am.action(DkActionManager::menu_tools_wallpaper), SIGNAL(triggered()), this, SLOT(setWallpaper()));
-	//connect(am.action(DkActionManager::menu_edit_preferences), SIGNAL(triggered()), this, SLOT(openSettings()));
 
 	connect(am.action(DkActionManager::menu_panel_menu), SIGNAL(toggled(bool)), this, SLOT(showMenuBar(bool)));
 	connect(am.action(DkActionManager::menu_panel_toolbar), SIGNAL(toggled(bool)), this, SLOT(showToolBar(bool)));
@@ -414,76 +404,6 @@ void DkNoMacs::createActions() {
 	connect(am.action(DkActionManager::menu_help_update_translation), SIGNAL(triggered()), this, SLOT(updateTranslations()));
 
 	connect(am.appManager(), SIGNAL(openFileSignal(QAction*)), this, SLOT(openFileWith(QAction*)));
-
-	//// add sort actions to the thumbscene
-	//getTabWidget()->getThumbScrollWidget()->addContextMenuActions(mSortActions, tr("&Sort"));
-}
-
-void DkNoMacs::enableNoImageActions(bool enable) {
-
-	DkActionManager& am = DkActionManager::instance();
-
-	am.action(DkActionManager::menu_file_save)->setEnabled(enable);
-	am.action(DkActionManager::menu_file_save_as)->setEnabled(enable);
-	am.action(DkActionManager::menu_file_save_list)->setEnabled(enable);
-	am.action(DkActionManager::menu_file_save_web)->setEnabled(enable);
-	am.action(DkActionManager::menu_file_rename)->setEnabled(enable);
-	am.action(DkActionManager::menu_file_print)->setEnabled(enable);
-	am.action(DkActionManager::menu_file_reload)->setEnabled(enable);
-	am.action(DkActionManager::menu_file_prev)->setEnabled(enable);
-	am.action(DkActionManager::menu_file_next)->setEnabled(enable);
-	am.action(DkActionManager::menu_file_goto)->setEnabled(enable);
-	am.action(DkActionManager::menu_file_find)->setEnabled(enable);
-
-	am.action(DkActionManager::menu_edit_rotate_cw)->setEnabled(enable);
-	am.action(DkActionManager::menu_edit_rotate_ccw)->setEnabled(enable);
-	am.action(DkActionManager::menu_edit_rotate_180)->setEnabled(enable);
-	am.action(DkActionManager::menu_edit_delete)->setEnabled(enable);
-	am.action(DkActionManager::menu_edit_transform)->setEnabled(enable);
-	am.action(DkActionManager::menu_edit_crop)->setEnabled(enable);
-	am.action(DkActionManager::menu_edit_copy)->setEnabled(enable);
-	am.action(DkActionManager::menu_edit_copy_buffer)->setEnabled(enable);
-	am.action(DkActionManager::menu_edit_copy_color)->setEnabled(enable);
-	am.action(DkActionManager::menu_tools_wallpaper)->setEnabled(enable);
-
-	am.action(DkActionManager::menu_tools_thumbs)->setEnabled(enable);
-	
-	am.action(DkActionManager::menu_panel_info)->setEnabled(enable);
-#ifdef WITH_OPENCV
-	am.action(DkActionManager::menu_panel_histogram)->setEnabled(enable);
-#else
-	am.action(DkActionManager::menu_panel_histogram)->setEnabled(false);
-#endif
-	am.action(DkActionManager::menu_panel_scroller)->setEnabled(enable);
-	am.action(DkActionManager::menu_panel_comment)->setEnabled(enable);
-	am.action(DkActionManager::menu_panel_preview)->setEnabled(enable);
-	am.action(DkActionManager::menu_panel_exif)->setEnabled(enable);
-	am.action(DkActionManager::menu_panel_overview)->setEnabled(enable);
-	am.action(DkActionManager::menu_panel_player)->setEnabled(enable);
-	
-	am.action(DkActionManager::menu_view_fullscreen)->setEnabled(enable);
-	am.action(DkActionManager::menu_view_reset)->setEnabled(enable);
-	am.action(DkActionManager::menu_view_100)->setEnabled(enable);
-	am.action(DkActionManager::menu_view_fit_frame)->setEnabled(enable);
-	am.action(DkActionManager::menu_view_zoom_in)->setEnabled(enable);
-	am.action(DkActionManager::menu_view_zoom_out)->setEnabled(enable);
-	am.action(DkActionManager::menu_view_tp_pattern)->setEnabled(enable);
-	am.action(DkActionManager::menu_view_anti_aliasing)->setEnabled(enable);
-
-	// hidden actions
-	am.action(DkActionManager::sc_skip_prev)->setEnabled(enable);
-	am.action(DkActionManager::sc_skip_prev_sync)->setEnabled(enable);
-	am.action(DkActionManager::sc_skip_next)->setEnabled(enable);
-	am.action(DkActionManager::sc_skip_next_sync)->setEnabled(enable);
-	am.action(DkActionManager::sc_first_file)->setEnabled(enable);
-	am.action(DkActionManager::sc_first_file_sync)->setEnabled(enable);
-	am.action(DkActionManager::sc_last_file)->setEnabled(enable);
-	am.action(DkActionManager::sc_last_file_sync)->setEnabled(enable);
-
-	// disable open with actions
-	for (QAction* a : DkActionManager::instance().appManager()->getActions())
-		a->setEnabled(enable);
-
 }
 
 void DkNoMacs::enableMovieActions(bool enable) {
@@ -761,6 +681,10 @@ void DkNoMacs::readSettings() {
 
 	restoreGeometry(settings.value("geometry").toByteArray());
 	restoreState(settings.value("windowState").toByteArray());
+
+	// restore state makes the toolbar visible - so hide it again...
+	if (DkSettingsManager::param().app().appMode == DkSettings::mode_frameless)
+		mToolbar->hide();
 }
 
 void DkNoMacs::toggleFullScreen() {
@@ -787,7 +711,7 @@ void DkNoMacs::enterFullScreen() {
 
 	restoreDocks();
 
-	DkSettingsManager::param().app().maximizedMode = isMaximized();
+	mMaximizedMode = isMaximized();
 	setWindowState(Qt::WindowFullScreen);
 	
 	if (viewport())
@@ -812,7 +736,7 @@ void DkNoMacs::exitFullScreen() {
 
 		restoreDocks();
 
-		if(DkSettingsManager::param().app().maximizedMode) 
+		if(mMaximizedMode) 
 			setWindowState(Qt::WindowMaximized);
 		else 
 			setWindowState(Qt::WindowNoState);
@@ -1044,7 +968,7 @@ void DkNoMacs::newClientConnected(bool connected, bool) {
 	// add methods if clients are connected
 
 	DkActionManager& am = DkActionManager::instance();
-	am.action(DkActionManager::menu_sync)->setEnabled(connected);
+	am.action(DkActionManager::menu_sync_view)->setEnabled(connected);
 	am.action(DkActionManager::menu_sync_pos)->setEnabled(connected);
 	am.action(DkActionManager::menu_sync_arrange)->setEnabled(connected);
 
@@ -1106,6 +1030,9 @@ void DkNoMacs::tcpSendArrange() {
 
 void DkNoMacs::showExplorer(bool show, bool saveSettings) {
 
+	if (!show && !mExplorer)
+		return;
+
 	if (!mExplorer) {
 
 		// get last location
@@ -1135,6 +1062,9 @@ void DkNoMacs::showExplorer(bool show, bool saveSettings) {
 
 void DkNoMacs::showMetaDataDock(bool show, bool saveSettings) {
 
+	if (!show && !mMetaDataDock)
+		return;
+
 	if (!mMetaDataDock) {
 
 		mMetaDataDock = new DkMetaDataDock(tr("Meta Data Info"), this);
@@ -1153,6 +1083,9 @@ void DkNoMacs::showMetaDataDock(bool show, bool saveSettings) {
 
 void DkNoMacs::showEditDock(bool show, bool saveSettings) {
 
+	if (!show && !mEditDock)
+		return;
+
 	if (!mEditDock) {
 
 		mEditDock = new DkEditDock(tr("Edit Image"), this);
@@ -1171,6 +1104,9 @@ void DkNoMacs::showEditDock(bool show, bool saveSettings) {
 
 void DkNoMacs::showHistoryDock(bool show, bool saveSettings) {
 
+	if (!show && !mHistoryDock)
+		return;
+
 	if (!mHistoryDock) {
 
 		mHistoryDock = new DkHistoryDock(tr("History"), this);
@@ -1189,6 +1125,9 @@ void DkNoMacs::showHistoryDock(bool show, bool saveSettings) {
 
 void DkNoMacs::showThumbsDock(bool show) {
 	
+	if (!show && !mThumbsDock)
+		return;
+
 	// nothing todo here
 	if (mThumbsDock && mThumbsDock->isVisible() && show)
 		return;
@@ -1254,9 +1193,7 @@ void DkNoMacs::openDir() {
 	if (dirName.isEmpty())
 		return;
 
-	qDebug() << "loading directory: " << dirName;
-	
-	getTabWidget()->loadFile(dirName);
+	getTabWidget()->loadDirToTab(dirName);
 }
 
 void DkNoMacs::openFile() {
@@ -1269,11 +1206,11 @@ void DkNoMacs::openFile() {
 	openFilters.prepend(tr("All Files (*.*)"));
 
 	// load system default open dialog
-	QStringList fileNames = QFileDialog::getOpenFileNames(this, tr("Open Image"),
+	QStringList filePaths = QFileDialog::getOpenFileNames(this, tr("Open Image"),
 		getTabWidget()->getCurrentDir(), 
 		openFilters.join(";;"));
 
-	if (fileNames.isEmpty())
+	if (filePaths.isEmpty())
 		return;
 
 	int count = getTabWidget()->getTabs().count(); // Save current count of tabs for setting tab position later
@@ -1281,12 +1218,12 @@ void DkNoMacs::openFile() {
 		count = 0; 
 		
 	QSet<QString> duplicates;
-	for (QString fileName : fileNames) {
+	for (const QString& fp : filePaths) {
 		bool dup = false;
 
 		if (DkSettingsManager::param().global().checkOpenDuplicates) { // Should we check for duplicates?
 			for (auto tab : getTabWidget()->getTabs()) {
-				if (tab->getFilePath().compare(fileName) == 0) {
+				if (tab->getFilePath().compare(fp) == 0) {
 					duplicates.insert(tab->getFilePath());
 					dup = true;
 					break;
@@ -1295,23 +1232,23 @@ void DkNoMacs::openFile() {
 		}
 
 		if (!dup) {
-			qDebug() << "os filename: " << fileName;
-			getTabWidget()->loadFileToTab(fileName);
+			getTabWidget()->loadFile(fp, true);
 		}
 	}
 	if (duplicates.count() > 0) { // Show message if at least one duplicate was found
-		QString duptext = tr("The following duplicates were not added:");
+		QString duptext = tr("The following duplicates were not opened:");
 		for (auto dup : duplicates) {
 			duptext.append("\n" + dup);
 		}
 		getTabWidget()->getViewPort()->getController()->setInfo(duptext);
 	}
 
-	if(fileNames.count() > duplicates.count()) // Only set the active tab if there is actually something added
+	if (filePaths.count() > duplicates.count()) // Only set the active tab if there is actually something added
 		getTabWidget()->setActiveTab(count); // Set first file opened to be the active tab
 }
 
 void DkNoMacs::openFileList() {
+	
 	QStringList openFilters;
 	openFilters.append(tr("Text file (*.txt)"));
 	openFilters.append(tr("All files (*.*)"));
@@ -1335,7 +1272,7 @@ void DkNoMacs::openFileList() {
 	while (!file.atEnd()) {
 		QString line = file.readLine().simplified();
 		if (QFileInfo::exists(line)) {
-			getTabWidget()->loadFileToTab(line);
+			getTabWidget()->loadFile(line, true);
 		}
 	}
 
@@ -1378,9 +1315,8 @@ void DkNoMacs::openQuickLaunch() {
 		// add all actions
 		mQuickAccess->addActions(DkActionManager::instance().allActions());
 		
-		connect(mToolbar->getQuickAccess()->completer(), SIGNAL(activated(const QModelIndex&)), mQuickAccess, SLOT(fireAction(const QModelIndex&)));
+		connect(mToolbar->getQuickAccess(), SIGNAL(executeSignal(const QString&)), mQuickAccess, SLOT(execute(const QString&)));
 		connect(mQuickAccess, SIGNAL(loadFileSignal(const QString&)), getTabWidget(), SLOT(loadFile(const QString&)));
-		connect(mQuickAccess, SIGNAL(hideEdit()), mToolbar->getQuickAccess(), SLOT(clearAccess()));
 	}
 	
 	mQuickAccess->addDirs(DkSettingsManager::param().global().recentFolders);
@@ -1392,8 +1328,7 @@ void DkNoMacs::openQuickLaunch() {
 		
 		if (!mQuickAccessEdit) {
 			mQuickAccessEdit = new DkQuickAccessEdit(this);
-			connect(mQuickAccessEdit->completer(), SIGNAL(activated(const QModelIndex&)), mQuickAccess, SLOT(fireAction(const QModelIndex&)));
-			connect(mQuickAccess, SIGNAL(hideEdit()), mQuickAccessEdit, SLOT(clearAccess()));
+			connect(mQuickAccessEdit, SIGNAL(executeSignal(const QString&)), mQuickAccess, SLOT(execute(const QString&)));
 		}
 
 		int right = viewport()->geometry().right();
@@ -1406,23 +1341,24 @@ void DkNoMacs::openQuickLaunch() {
 
 void DkNoMacs::loadFile(const QString& filePath) {
 
-	if (!viewport())
+	if (!getTabWidget())
 		return;
 
 	if (QFileInfo(filePath).isDir())
 		getTabWidget()->loadDirToTab(filePath);
 	else
-		getTabWidget()->loadFileToTab(filePath);
+		getTabWidget()->loadFile(filePath, false);
 
 }
 
+// TODO: move this
 void DkNoMacs::renameFile() {
 
 	QString filePath = getTabWidget()->getCurrentFilePath();
 	QFileInfo file(filePath);
 
 	if (!file.absoluteDir().exists()) {
-		viewport()->getController()->setInfo(tr("Sorry, the directory: %1  does not exist\n").arg(file.absolutePath()));
+		viewport()->getController()->setInfo(tr("Sorry, the directory: %1 does not exist\n").arg(file.absolutePath()));
 		return;
 	}
 	if (file.exists() && !file.isWritable()) {
@@ -1434,7 +1370,7 @@ void DkNoMacs::renameFile() {
 	int dotIdx = fileName.lastIndexOf(".");
 	QString baseName = dotIdx != -1 ? fileName.left(dotIdx) : fileName;
 
-	bool ok;
+	bool ok = false;
 	QString newFileName = QInputDialog::getText(this, baseName, tr("Rename:"), QLineEdit::Normal, baseName, &ok);
 
 	if (ok && !newFileName.isEmpty() && newFileName != baseName) {
@@ -1481,9 +1417,11 @@ void DkNoMacs::renameFile() {
 		// tell user that deleting went wrong, and stop the renaming
 		if (!renamed)
 			viewport()->getController()->setInfo(tr("Sorry, I can't rename: %1").arg(file.fileName()));
-		else
+		else if (DkSettingsManager::param().resources().loadSavedImage == DkSettings::ls_load)
 			getTabWidget()->loadFile(renamedFile.absoluteFilePath());
-		
+		else 
+			viewport()->loadNextFileFast();
+
 	}
 
 }
@@ -1663,7 +1601,6 @@ void DkNoMacs::deleteFile() {
 	viewport()->getController()->applyPluginChanges(true);
 
 	QFileInfo fileInfo = getTabWidget()->getCurrentFilePath();
-
 	QString question;
 
 #if defined(Q_OS_WIN) || defined(W_OS_LINUX)
@@ -1807,7 +1744,7 @@ void DkNoMacs::aboutDialog() {
 
 void DkNoMacs::openDocumentation() {
 
-	QString url = QString("http://www.nomacs.org/documentation/");
+	QString url = QString("https://nomacs.org/documentation/");
 	QDesktopServices::openUrl(QUrl(url));
 }
 
@@ -1848,23 +1785,33 @@ void DkNoMacs::newInstance(const QString& filePath) {
 	QProcess::startDetached(exe, args);
 }
 
+void tagWall(const std::list<std::string>& code) {
+	for (auto line : code)
+		std::cout << line << std::endl;
+}
+
 void DkNoMacs::loadRecursion() {
 
-	if (!getTabWidget()->getCurrentImage())
-		return;
-
-	viewport()->toggleDissolve();
+	std::list<std::string> code;
+	code.push_back("void tagWall(const std::list<std::string>& code) {");
+	code.push_back("	for (auto line : code)");
+	code.push_back("		std::cout << line << std::endl;");
+	code.push_back("}");
+	tagWall(code);
 
+	//if (!getTabWidget()->getCurrentImage())
+	//	return;
 
+	//viewport()->toggleDissolve();
 	//QImage img = getTabWidget()->getCurrentImage()->image();
 
 	//while (DkImage::addToImage(img, 1)) {
-	//	mViewport()->setEditedImage(img);
+	//	viewport()->setEditedImage(img, tr("Recursion"));
 	//	QApplication::sendPostedEvents();
 	//}
 
-	//QImage img = QPixmap::grabWindow(this->winId()).toImage();
-	//mViewport()->setImage(img);
+	QImage img = this->grab().toImage();
+	viewport()->setImage(img);
 }
 
 // Added by fabian for transfer function:
@@ -1899,13 +1846,6 @@ void DkNoMacs::setContrast(bool contrast) {
 	qDebug() << "contrast arguments: " << args;
 }
 
-void DkNoMacs::showRecentFiles(bool show) {
-
-	if (!DkSettingsManager::param().global().recentFiles.empty())
-		getTabWidget()->showRecentFiles(show);
-
-}
-
 void DkNoMacs::onWindowLoaded() {
 
 	DefaultSettings settings;
@@ -1946,7 +1886,7 @@ void DkNoMacs::onWindowLoaded() {
 	DkGlobalProgress::instance().setProgressBar(button->progress());
 #endif
 
-
+	toggleDocks(DkSettingsManager::param().app().hideAllPanels);
 }
 
 void DkNoMacs::keyPressEvent(QKeyEvent *event) {
@@ -1994,9 +1934,10 @@ void DkNoMacs::showMenuBar(bool show) {
 	int tts = (DkSettingsManager::param().app().showMenuBar) ? -1 : 5000;
 	DkActionManager::instance().action(DkActionManager::menu_panel_menu)->setChecked(DkSettingsManager::param().app().showMenuBar);
 	mMenu->setTimeToShow(tts);
-	mMenu->showMenu();
-
-	if (!show)
+	
+	if (show)
+		mMenu->showMenu();
+	else if (!show)
 		mMenu->hide();
 }
 
@@ -2197,23 +2138,13 @@ void DkNoMacs::checkForUpdate(bool silent) {
 
 		DkTimer dt;
 
-		// fall back to our old-school updater
-		//if (!DkSettingsManager::param().isPortable()) {
-		//	
-		//	if (!mInstallUpdater)
-		//		mInstallUpdater = new DkInstallUpdater(this);
-		//	mInstallUpdater->checkForUpdates(silent);
-		//}
-		//else {
-
-			if (!mUpdater) {
-				mUpdater = new DkUpdater(this);
-				connect(mUpdater, SIGNAL(displayUpdateDialog(QString, QString)), this, SLOT(showUpdateDialog(QString, QString)));
-				connect(mUpdater, SIGNAL(showUpdaterMessage(QString, QString)), this, SLOT(showUpdaterMessage(QString, QString)));
-			}
-			mUpdater->silent = silent;
-			mUpdater->checkForUpdates();
-		//}
+		if (!mUpdater) {
+			mUpdater = new DkUpdater(this);
+			connect(mUpdater, SIGNAL(displayUpdateDialog(QString, QString)), this, SLOT(showUpdateDialog(QString, QString)));
+			connect(mUpdater, SIGNAL(showUpdaterMessage(QString, QString)), this, SLOT(showUpdaterMessage(QString, QString)));
+		}
+		mUpdater->silent = silent;
+		mUpdater->checkForUpdates();
 		qDebug() << "checking for updates takes: " << dt;
 	}
 #endif // !#ifndef Q_OS_LINUX
@@ -2292,11 +2223,11 @@ void DkNoMacs::startSetup(QString filePath) {
 	qDebug() << "starting setup filePath:" << filePath;
 	
 	if (!QFile::exists(filePath))
-		qDebug() << "fileInfo does not exist";
+		qDebug() << "file does not exist";
 	if (!QDesktopServices::openUrl(QUrl::fromLocalFile(filePath))) {
 		QString msg = tr("Unable to install new version<br>") +
 			tr("You can download the new version from our web page") +
-			"<br><a href=\"http://www.nomacs.org/download/\">www.nomacs.org</a><br>";
+			"<br><a href=\"https://nomacs.org/download/\">www.nomacs.org</a><br>";
 		showUpdaterMessage(msg, "update");
 	}
 }
@@ -2383,82 +2314,32 @@ DkNoMacsSync::~DkNoMacsSync() {
 
 }
 
-void DkNoMacsSync::initLanClient() {
-
-	DkTimer dt;
-	if (mLanClient) {
-
-		mLanClient->quit();
-		mLanClient->wait();
-
-		delete mLanClient;
-	}
-
-	if (!DkSettingsManager::param().sync().enableNetworkSync) {
-
-		mLanClient = 0;
-
-		DkActionManager::instance().lanMenu()->setEnabled(false);
-		DkActionManager::instance().action(DkActionManager::menu_sync_remote_control)->setEnabled(false);
-		DkActionManager::instance().action(DkActionManager::menu_sync_remote_display)->setEnabled(false);
-		return;
-	}
-
-	DkTcpMenu* lanMenu = DkActionManager::instance().lanMenu();
-	lanMenu->clear();
-
-	// start lan client/server
-	mLanClient = new DkLanManagerThread(this);
-	mLanClient->setObjectName("lanClient");
-	mLanClient->start();
-
-	lanMenu->setClientManager(mLanClient);
-	lanMenu->addTcpAction(DkActionManager::instance().action(DkActionManager::menu_lan_server));
-	lanMenu->addTcpAction(DkActionManager::instance().action(DkActionManager::menu_lan_image));	// well this is a bit nasty... we only add it here to have correct enable/disable behavior...
-	lanMenu->setEnabled(true);
-	lanMenu->enableActions(false, false);
-	
-	connect(this, SIGNAL(startTCPServerSignal(bool)), mLanClient, SLOT(startServer(bool)));
-
-	qDebug() << "start server takes: " << dt;
-}
-
 void DkNoMacsSync::createActions() {
 
 	DkNoMacs::createActions();
 
 	DkActionManager& am = DkActionManager::instance();
-	connect(am.action(DkActionManager::menu_lan_server), SIGNAL(toggled(bool)), this, SLOT(startTCPServer(bool)));	// TODO: something that makes sense...
 	
-	// TODO: move to viewport
-	connect(am.action(DkActionManager::menu_lan_image), SIGNAL(triggered()), viewport(), SLOT(tcpSendImage()));
-	connect(am.action(DkActionManager::menu_sync), SIGNAL(triggered()), viewport(), SLOT(tcpForceSynchronize()));
-
 	// sync menu
+	connect(am.action(DkActionManager::menu_sync_view), SIGNAL(triggered()), viewport(), SLOT(tcpForceSynchronize()));
 	connect(am.action(DkActionManager::menu_sync_pos), SIGNAL(triggered()), this, SLOT(tcpSendWindowRect()));
 	connect(am.action(DkActionManager::menu_sync_arrange), SIGNAL(triggered()), this, SLOT(tcpSendArrange()));
 	connect(am.action(DkActionManager::menu_sync_connect_all), SIGNAL(triggered()), this, SLOT(tcpConnectAll()));
 	connect(am.action(DkActionManager::menu_sync_all_actions), SIGNAL(triggered(bool)), this, SLOT(tcpAutoConnect(bool)));
-	connect(am.action(DkActionManager::menu_sync_remote_control), SIGNAL(triggered(bool)), this, SLOT(tcpRemoteControl(bool)));
-	connect(am.action(DkActionManager::menu_sync_remote_display), SIGNAL(triggered(bool)), this, SLOT(tcpRemoteDisplay(bool)));
 }
 
 void DkNoMacsSync::createMenu() {
 
 	DkNoMacs::createMenu();
-
 	DkActionManager& am = DkActionManager::instance();
-	
 	// local host menu
 	DkTcpMenu* localMenu = new DkTcpMenu(QObject::tr("&Synchronize"), mSyncMenu, mLocalClient);
 	localMenu->showNoClientsFound(true);
 	// add connect all action
 	localMenu->addTcpAction(am.action(DkActionManager::menu_sync_connect_all));
-	
-	// LAN menu
-	DkTcpMenu* lanMenu = new DkTcpMenu(QObject::tr("&LAN Synchronize"), mSyncMenu, mLanClient);	// TODO: replace
 
-	am.addSyncMenu(mSyncMenu, localMenu, lanMenu);
+	am.addSyncMenu(mSyncMenu, localMenu);
+
 }
 
 // mouse events
@@ -2520,13 +2401,6 @@ void DkNoMacsSync::dropEvent(QDropEvent *event) {
 
 }
 
-void DkNoMacsSync::enableNoImageActions(bool enable /* = true */) {
-
-	DkNoMacs::enableNoImageActions(enable);
-
-	DkActionManager::instance().action(DkActionManager::menu_sync_connect_all)->setEnabled(enable);
-}
-
 qint16 DkNoMacsSync::getServerPort() {
 
 	return (mLocalClient) ? mLocalClient->getServerPort() : 0;
@@ -2546,107 +2420,30 @@ void DkNoMacsSync::tcpConnectAll() {
 
 }
 
-void DkNoMacsSync::tcpChangeSyncMode(int syncMode) {
-
-	DkActionManager::instance().action(DkActionManager::menu_sync_remote_control)->setChecked(false);
-	DkActionManager::instance().action(DkActionManager::menu_sync_remote_display)->setChecked(false);
-
-	if (syncMode == DkSettings::sync_mode_default) {
-		DkSettingsManager::param().sync().syncMode = syncMode;
-		return;
-	}
-
-	bool connected = DkSettingsManager::param().sync().syncMode == DkSettings::sync_mode_default;
-
-	if (!connected) {
-		DkSettingsManager::param().sync().syncMode = DkSettings::sync_mode_default;
-		viewport()->getController()->setInfo(tr("Sorry, I could not find any clients."));
-		return;
-	}
-
-	// turn on the new mode
-	switch(syncMode) {
-		case DkSettings::sync_mode_remote_control: 
-			DkActionManager::instance().action(DkActionManager::menu_sync_remote_control)->setChecked(true);	
-			break;
-		case DkSettings::sync_mode_remote_display: 
-			DkActionManager::instance().action(DkActionManager::menu_sync_remote_display)->setChecked(true);
-			break;
-	//default:
-	}
-
-	DkSettingsManager::param().sync().syncMode = syncMode;
-}
-
-
-void DkNoMacsSync::tcpRemoteControl(bool start) {
-
-	tcpChangeSyncMode((start) ? DkSettings::sync_mode_remote_control : DkSettings::sync_mode_default);
-}
-
-void DkNoMacsSync::tcpRemoteDisplay(bool start) {
-
-	tcpChangeSyncMode((start) ? DkSettings::sync_mode_remote_display : DkSettings::sync_mode_default);
-}
-
 void DkNoMacsSync::tcpAutoConnect(bool connect) {
 
 	DkSettingsManager::param().sync().syncActions = connect;
 }
 
-void DkNoMacsSync::newClientConnected(bool connected, bool local) {
-
-	DkActionManager::instance().lanMenu()->enableActions(connected, local);
-	
-	DkNoMacs::newClientConnected(connected, local);
-}
-
-void DkNoMacsSync::startTCPServer(bool start) {
-	
-	emit startTCPServerSignal(start);
-}
-
-void DkNoMacsSync::settingsChanged() {
-	initLanClient();
-
-	DkNoMacs::settingsChanged();
-}
-
-void DkNoMacsSync::clientInitialized() {
-	
-	emit clientInitializedSignal();
-}
-
 DkNoMacsIpl::DkNoMacsIpl(QWidget *parent, Qt::WindowFlags flags) : DkNoMacsSync(parent, flags) {
 
 	// init members
 	DkViewPort* vp = new DkViewPort(this);
-	vp->setAlignment(Qt::AlignHCenter);
 
 	DkCentralWidget* cw = new DkCentralWidget(vp, this);
 	setCentralWidget(cw);
-
 	mLocalClient = new DkLocalManagerThread(this);
 	mLocalClient->setObjectName("localClient");
 	mLocalClient->start();
 
-	mLanClient = 0;
-
 	init();
 	setAcceptDrops(true);
 	setMouseTracking (true);	//receive mouse event everytime
 
-	DkTimer dt;
-		
-	// sync signals
+								// sync signals
 	connect(vp, SIGNAL(newClientConnectedSignal(bool, bool)), this, SLOT(newClientConnected(bool, bool)));
 
 	DkSettingsManager::param().app().appMode = 0;
-	initLanClient();
-	//emit sendTitleSignal(windowTitle());
-	qInfo() << "LAN client created in: " << dt;
-	// show it...
-	show();
 	DkSettingsManager::param().app().appMode = DkSettings::mode_default;
 }
 
@@ -2662,7 +2459,7 @@ DkNoMacsFrameless::DkNoMacsFrameless(QWidget *parent, Qt::WindowFlags flags)
 
 		// init members
 		DkViewPortFrameless* vp = new DkViewPortFrameless(this);
-		vp->setAlignment(Qt::AlignHCenter);
+		//vp->setAlignment(Qt::AlignHCenter);
 
 		DkCentralWidget* cw = new DkCentralWidget(vp, this);
 		setCentralWidget(cw);
@@ -2687,13 +2484,18 @@ DkNoMacsFrameless::DkNoMacsFrameless(QWidget *parent, Qt::WindowFlags flags)
 		am.action(DkActionManager::menu_view_frameless)->blockSignals(false);
 
 		mDesktop = QApplication::desktop();
-		updateScreenSize();
+
+		chooseMonitor(false);
 		show();
         
-        connect(mDesktop, SIGNAL(workAreaResized(int)), this, SLOT(updateScreenSize(int)));
+        connect(mDesktop, SIGNAL(workAreaResized(int)), this, SLOT(chooseMonitor()));
+		connect(am.action(DkActionManager::menu_view_monitors), SIGNAL(triggered()), this, SLOT(chooseMonitor()));
 
 		setObjectName("DkNoMacsFrameless");
 		showStatusBar(false);	// fix
+
+		// actions that should always be disabled
+		DkActionManager::instance().action(DkActionManager::menu_view_fit_frame)->setEnabled(false);
 }
 
 DkNoMacsFrameless::~DkNoMacsFrameless() {
@@ -2708,51 +2510,30 @@ void DkNoMacsFrameless::createContextMenu() {
 	am.contextMenu()->addAction(am.action(DkActionManager::menu_file_exit));
 }
 
-void DkNoMacsFrameless::enableNoImageActions(bool enable) {
-
-	DkNoMacs::enableNoImageActions(enable);
-
-	// actions that should always be disabled
-	DkActionManager::instance().action(DkActionManager::menu_view_fit_frame)->setEnabled(false);
-
-}
-
-void DkNoMacsFrameless::updateScreenSize(int) {
+void DkNoMacsFrameless::chooseMonitor(bool force) {
 
 	if (!mDesktop)
 		return;
 
-	//TODO: let user choose which screen
-	int sc = mDesktop->screenCount();
-	QRect screenRects = mDesktop->availableGeometry();
+	QRect screenRect = mDesktop->availableGeometry();
 
-	for (int idx = 0; idx < sc; idx++) {
+	// ask the user which monitor to use
+	if (mDesktop->screenCount() > 1) {
+		DkChooseMonitorDialog* cmd = new DkChooseMonitorDialog(this);
+		cmd->setWindowTitle(tr("Choose a Monitor"));
 
-		qDebug() << "screens: " << mDesktop->availableGeometry(idx);
-		QRect curScreen = mDesktop->availableGeometry(idx);
-		screenRects.setLeft(qMin(screenRects.left(), curScreen.left()));
-		screenRects.setTop(qMin(screenRects.top(), curScreen.top()));
-		screenRects.setBottom(qMax(screenRects.bottom(), curScreen.bottom()));
-		screenRects.setRight(qMax(screenRects.right(), curScreen.right()));
+		if (force || cmd->showDialog()) {
+			int answer = cmd->exec();
+			if (answer == QDialog::Accepted) {
+				screenRect = cmd->screenRect();
+			}
+		}
+		else {
+			screenRect = cmd->screenRect();
+		}
 	}
 
-	qDebug() << "set up geometry: " << screenRects;
-
-	QRect mg = mDesktop->screenGeometry();
-	mg.moveTopLeft(-screenRects.topLeft());
-
-	
-	qDebug() << "main geometry:" << mDesktop->screenGeometry();
-
-	setGeometry(screenRects);
-
-	DkViewPortFrameless* vp = static_cast<DkViewPortFrameless*>(viewport());
-	vp->setMainGeometry(mg);
-
-
-	//vp->setMainGeometry(mDesktop->screenGeometry());
-	//setGeometry(mDesktop->screenGeometry());
-
+	setGeometry(screenRect);
 }
 
 void DkNoMacsFrameless::exitFullScreen() {
@@ -2809,7 +2590,7 @@ DkNoMacsContrast::DkNoMacsContrast(QWidget *parent, Qt::WindowFlags flags)
 
 		// init members
 		DkViewPortContrast* vp = new DkViewPortContrast(this);
-		vp->setAlignment(Qt::AlignHCenter);
+		//vp->setAlignment(Qt::AlignHCenter);
 
 		DkCentralWidget* cw = new DkCentralWidget(vp, this);
 		setCentralWidget(cw);
@@ -2818,8 +2599,6 @@ DkNoMacsContrast::DkNoMacsContrast(QWidget *parent, Qt::WindowFlags flags)
 		mLocalClient->setObjectName("localClient");
 		mLocalClient->start();
 
-		mLanClient = 0;
-
 		init();
 
 		createTransferToolbar();
@@ -2829,8 +2608,6 @@ DkNoMacsContrast::DkNoMacsContrast(QWidget *parent, Qt::WindowFlags flags)
 
 		// sync signals
 		connect(vp, SIGNAL(newClientConnectedSignal(bool, bool)), this, SLOT(newClientConnected(bool, bool)));
-		
-		initLanClient();
 		emit sendTitleSignal(windowTitle());
 
 		DkSettingsManager::param().app().appMode = DkSettings::mode_contrast;
@@ -2871,8 +2648,5 @@ void DkNoMacsContrast::createTransferToolbar() {
 
 	mTransferToolBar->setIconSize(QSize(DkSettingsManager::param().effectiveIconSize(this), DkSettingsManager::param().effectiveIconSize(this)));
 
-	if (DkSettingsManager::param().display().toolbarGradient)
-		mTransferToolBar->setObjectName("toolBarWithGradient");
-
 }
 }
