@@ -90,7 +90,7 @@ int DkPongSettings::totalScore() const {
 
 void DkPongSettings::writeSettings() {
 
-	QSettings& settings = Settings::instance().getSettings();
+	DefaultSettings settings;
 	settings.beginGroup("DkPong");
 
 	settings.setValue("field", mField);
@@ -127,7 +127,7 @@ float DkPongSettings::playerRatio() const {
 
 void DkPongSettings::loadSettings() {
 
-	QSettings& settings = Settings::instance().getSettings();
+	DefaultSettings settings;
 	settings.beginGroup("DkPong");
 
 	mField = settings.value("field", mField).toRect();
@@ -576,7 +576,7 @@ bool DkBall::move(DkPongPlayer& player1, DkPongPlayer& player2) {
 	DkVector dir = mDirection;
 
 	// collision detection top & bottom
-	if (mRect.top() <= mS->field().top() && dir.y < 0 || mRect.bottom() >= mS->field().bottom() && dir.y > 0) {
+	if ((mRect.top() <= mS->field().top() && dir.y < 0) || (mRect.bottom() >= mS->field().bottom() && dir.y > 0)) {
 		dir.rotate(dir.angle()*2);
 		//qDebug() << "collision...";
 	}
