@@ -65,7 +65,7 @@ void DkQuickAccess::addActions(const QVector<QAction*>& actions) {
 		QAction* a = actions[rIdx];
 		QIcon icon = a->icon().isNull() ? DkImage::loadIcon(":/nomacs/img/dummy.svg") : a->icon();
 
-		QString text = a->text().replace("&", "");
+		QString text = a->text().remove("&");
 		QStandardItem* item = new QStandardItem(text);
 		item->setSizeHint(QSize(18, 18));
 		item->setIcon(icon);
@@ -79,7 +79,7 @@ void DkQuickAccess::addActions(const QVector<QAction*>& actions) {
 
 void DkQuickAccess::addFiles(const QStringList& filePaths) {
 
-	QPixmap pm = DkImage::loadIcon(":/nomacs/img/nomacs.svg");
+	QPixmap pm = DkImage::loadIcon(":/nomacs/img/nomacs-bg.svg");
 	addItems(filePaths, pm);
 }
 
@@ -109,29 +109,28 @@ void DkQuickAccess::addItems(const QStringList& itemTexts, const QIcon& icon) {
 	}
 }
 
-void DkQuickAccess::fireAction(const QModelIndex& index) const {
+bool DkQuickAccess::execute(const QString& cmd) const {
+	
+	qDebug() << "executing" << cmd;
 
-	QString key = index.data().toString();
-
-	emit hideEdit();
-
-	if (mFilePaths.contains(key)) {
-		emit loadFileSignal(key);
-		return;
+	if (QFileInfo(cmd).exists()) {
+		emit loadFileSignal(cmd);
+		return true;
 	}
 
 	for (QAction* a : mActions) {
 
-		QString aKey = a->text().replace("&", "");
+		QString aKey = a->text().remove("&");
+
+		if (aKey == cmd) {
 
-		if (aKey == key) {
-			
 			if (a->isEnabled())
 				a->trigger();
-			// TODO: else feedback?
-			return;
+			return true;
 		}
 	}
+	
+	return false;
 }
 
 // DkQuickAcessEdit --------------------------------------------------------------------
@@ -150,6 +149,8 @@ DkQuickAccessEdit::DkQuickAccessEdit(QWidget* parent) : QLineEdit("", parent) {
 #endif
 	mCompleter->setCaseSensitivity(Qt::CaseInsensitive);
 	setCompleter(mCompleter);
+
+	connect(this, SIGNAL(returnPressed()), this, SLOT(editConfirmed()));
 }
 
 void DkQuickAccessEdit::setModel(QStandardItemModel* model) {
@@ -161,6 +162,22 @@ void DkQuickAccessEdit::setModel(QStandardItemModel* model) {
 	setFocus(Qt::MouseFocusReason);
 }
 
+void DkQuickAccessEdit::editConfirmed() {
+	
+	QString fp = text();
+
+	// check if we can directly load what is there (this is nice to load the parent dir of a recent dir)
+	if (QFileInfo(fp).exists())
+		emit executeSignal(text());
+	else if (!mCompleter->currentCompletion().isNull())
+		emit executeSignal(mCompleter->currentCompletion());
+	else
+		// do something usefull if our completer has no idea anymore...
+		emit executeSignal(text());
+
+	clearAccess();
+}
+
 void DkQuickAccessEdit::focusOutEvent(QFocusEvent* ev) {
 
 	QLineEdit::focusOutEvent(ev);
