@@ -59,6 +59,8 @@
 #include <QMessageBox>
 #include <QInputDialog>
 #include <QMimeData>
+#include <QThreadPool>
+#include <QPushButton>
 #pragma warning(pop)		// no warnings from includes - end
 
 namespace nmc {
@@ -219,8 +221,9 @@ void DkFilePreview::createContextMenu() {
 
 void DkFilePreview::paintEvent(QPaintEvent*) {
 
-	//if (selected != -1)
-	//	resize(parent->width(), minHeight+fileLabel->height());	// catch parent resize...
+	// render nothing if there are no thumbs
+	if (mThumbs.isEmpty())
+		return;
 
 	if (minHeight != DkSettingsManager::param().effectiveThumbSize(this) + yOffset && windowPosition != pos_dock_hor && windowPosition != pos_dock_ver) {
 
@@ -234,14 +237,7 @@ void DkFilePreview::paintEvent(QPaintEvent*) {
 		else
 			setMaximumSize(minHeight, QWIDGETSIZE_MAX);
 
-		//if (fileLabel->height() >= height() && fileLabel->isVisible())
-		//	fileLabel->hide();
-
 	}
-	//minHeight = DkSettings::DisplaySettings::thumbSize + yOffset;
-	//resize(parent->width(), minHeight);
-
-	//qDebug() << "size: " << size();
 
 	QPainter painter(this);
 	painter.setBackground(DkSettingsManager::param().display().hudBgColor);
@@ -354,10 +350,10 @@ void DkFilePreview::drawThumbs(QPainter* painter) {
 			break;
 		}
 
-		if (thumb->hasImage() == DkThumbNail::not_loaded && 
-			DkSettingsManager::param().resources().numThumbsLoading < DkSettingsManager::param().resources().maxThumbsLoading) {
-				thumb->fetchThumb();
-				connect(thumb.data(), SIGNAL(thumbLoadedSignal()), this, SLOT(update()));
+		// only fetch thumbs if we are not moving too fast...
+		if (thumb->hasImage() == DkThumbNail::not_loaded && fabs(currentDx) < 40) {
+			thumb->fetchThumb();
+			connect(thumb.data(), SIGNAL(thumbLoadedSignal()), this, SLOT(update()));
 		}
 
 		bool isLeftGradient = (orientation == Qt::Horizontal && worldMatrix.dx() < 0 && imgWorldRect.left() < leftGradient.finalStop().x()) ||
@@ -482,8 +478,6 @@ void DkFilePreview::resizeEvent(QResizeEvent *event) {
 	if (event->size() == event->oldSize() && 
 		((orientation == Qt::Horizontal && pw && this->width() == pw->width())  ||
 		(orientation == Qt::Vertical && pw && this->height() == pw->height()))) {
-	
-			qDebug() << "parent size: " << pw->height();
 			return;
 	}
 
@@ -636,7 +630,6 @@ void DkFilePreview::mouseReleaseEvent(QMouseEvent *event) {
 	currentDx = 0;
 	moveImageTimer->stop();
 	wheelButton->hide();
-	qDebug() << "stopping image timer (mouse release)";
 
 	if (mouseTrace < 20) {
 
@@ -647,7 +640,7 @@ void DkFilePreview::mouseReleaseEvent(QMouseEvent *event) {
 				if (mThumbs.at(idx)->isFromZip()) 
 					emit changeFileSignal(idx - currentFileIdx);
 				else 
-					emit loadFileSignal(mThumbs.at(idx)->filePath());
+					emit loadFileSignal(mThumbs.at(idx)->filePath()/*, event->modifiers() == Qt::ControlModifier*/);
 			}
 		}
 	}
@@ -687,6 +680,9 @@ void DkFilePreview::wheelEvent(QWheelEvent *event) {
 		}
 		emit changeFileSignal(fc);
 	}
+
+	// accept the event here - so it won't be propagated to the viewport
+	event->accept();
 }
 
 void DkFilePreview::leaveEvent(QEvent*) {
@@ -834,13 +830,6 @@ void DkFilePreview::setFileInfo(QSharedPointer<DkImageContainerT> cImage) {
 		}
 	}
 
-	//// don't know why we needed this statement
-	//// however, if we break here, the file preview
-	//// might not update correctly
-	//if (tIdx == currentFileIdx) {
-	//	return;
-	//}
-
 	currentFileIdx = tIdx;
 	if (currentFileIdx >= 0)
 		scrollToCurrentImage = true;
@@ -850,7 +839,7 @@ void DkFilePreview::setFileInfo(QSharedPointer<DkImageContainerT> cImage) {
 
 void DkFilePreview::updateThumbs(QVector<QSharedPointer<DkImageContainerT> > thumbs) {
 
-	this->mThumbs = thumbs;
+	mThumbs = thumbs;
 
 	for (int idx = 0; idx < thumbs.size(); idx++) {
 		if (thumbs.at(idx)->isSelected()) {
@@ -876,17 +865,8 @@ DkThumbLabel::DkThumbLabel(QSharedPointer<DkThumbNailT> thumb, QGraphicsItem* pa
 	mFetchingThumb = false;
 	mIsHovered = false;
 
-	//imgLabel = new QLabel(this);
-	//imgLabel->setFocusPolicy(Qt::NoFocus);
-	//imgLabel->setAttribute(Qt::WA_TransparentForMouseEvents);
-	//imgLabel->setScaledContents(true);
-	//imgLabel->setFixedSize(10,10);
-	//setStyleSheet("QLabel{background: transparent;}");
 	setThumb(thumb);
 	setFlag(ItemIsSelectable, true);
-	//setFlag(ItemIsMovable, true);	// uncomment this - it's fun : )
-
-	//setFlag(QGraphicsItem::ItemIsSelectable, false);
 
 #if QT_VERSION < 0x050000
 	setAcceptsHoverEvents(true);
@@ -905,7 +885,6 @@ void DkThumbLabel::setThumb(QSharedPointer<DkThumbNailT> thumb) {
 		return;
 
 	connect(thumb.data(), SIGNAL(thumbLoadedSignal()), this, SLOT(updateLabel()));
-	//setStatusTip(thumb->getFile().fileName());
 	QFileInfo fileInfo(thumb->getFilePath());
 	QString toolTipInfo = tr("Name: ") + fileInfo.fileName() + 
 		"\n" + tr("Size: ") + DkUtils::readableByte((float)fileInfo.size()) + 
@@ -921,7 +900,6 @@ void DkThumbLabel::setThumb(QSharedPointer<DkThumbNailT> thumb) {
 	col.setAlpha(90);
 	mSelectBrush = col;
 	mSelectPen.setColor(DkSettingsManager::param().display().highlightColor);
-	//selectPen.setWidth(2);
 }
 
 QPixmap DkThumbLabel::pixmap() const {
@@ -929,6 +907,11 @@ QPixmap DkThumbLabel::pixmap() const {
 	return mIcon.pixmap();
 }
 
+void DkThumbLabel::cancelLoading() {
+	
+	mFetchingThumb = false;
+}
+
 QRectF DkThumbLabel::boundingRect() const {
 
     int sz = DkSettingsManager::param().effectiveThumbPreviewSize();
@@ -966,7 +949,6 @@ void DkThumbLabel::updateLabel() {
 		mIcon.setTransformationMode(Qt::SmoothTransformation);
 		mIcon.setPixmap(pm);
 		mIcon.setFlag(ItemIsSelectable, true);
-		//QFlags<enum> f;
 	}
 	if (pm.isNull())
 		setFlag(ItemIsSelectable, false);	// if we cannot load it -> disable selection
@@ -974,7 +956,7 @@ void DkThumbLabel::updateLabel() {
 	// update label
 	mText.setPos(0, pm.height());
 	mText.setDefaultTextColor(QColor(255,255,255));
-	//text.setTextWidth(icon.boundingRect().width());
+	
 	QFont font;
 	font.setBold(false);
 	font.setPointSize(8);
@@ -1013,20 +995,7 @@ void DkThumbLabel::mouseDoubleClickEvent(QGraphicsSceneMouseEvent *event) {
 	if (mThumb.isNull())
 		return;
 
-	if (event->buttons() == Qt::LeftButton && event->modifiers() == Qt::ControlModifier) {
-		QString exe = QApplication::applicationFilePath();
-		QStringList args;
-		args.append(mThumb->getFilePath());
-
-		if (objectName() == "DkNoMacsFrameless")
-			args.append("1");	
-
-		QProcess::startDetached(exe, args);
-	}
-	else {
-		qDebug() << "trying to load: " << mThumb->getFilePath();
-		emit loadFileSignal(mThumb->getFilePath());
-	}
+	emit loadFileSignal(mThumb->getFilePath(), event->modifiers() == Qt::ControlModifier);
 }
 
 void DkThumbLabel::hoverEnterEvent(QGraphicsSceneHoverEvent*) {
@@ -1051,8 +1020,7 @@ void DkThumbLabel::setVisible(bool visible) {
 
 void DkThumbLabel::paint(QPainter* painter, const QStyleOptionGraphicsItem* option, QWidget* widget) {
 	
-	if (!mFetchingThumb && mThumb->hasImage() == DkThumbNail::not_loaded && 
-		DkSettingsManager::param().resources().numThumbsLoading < DkSettingsManager::param().resources().maxThumbsLoading*2) {
+	if (!mFetchingThumb && mThumb->hasImage() == DkThumbNail::not_loaded) {
 			mThumb->fetchThumb();
 			mFetchingThumb = true;
 	}
@@ -1062,10 +1030,6 @@ void DkThumbLabel::paint(QPainter* painter, const QStyleOptionGraphicsItem* opti
 		return;		// exit - otherwise we get paint errors
 	}
 
-	//if (!pixmap().isNull()) {
-	//	painter->setRenderHint(QPainter::SmoothPixmapTransform);
-	//	painter->drawPixmap(boundingRect(), pixmap(), QRectF(QPoint(), pixmap().size()));
-	//}
 	if (mIcon.pixmap().isNull() && mThumb->hasImage() == DkThumbNail::exists_not) {
 		painter->setPen(mNoImagePen);
 		painter->setBrush(mNoImageBrush);
@@ -1159,7 +1123,6 @@ void DkThumbScene::updateLayout() {
 
 	int tso = psz+mXOffset;
 	setSceneRect(0, 0, mNumCols*tso+mXOffset, mNumRows*tso+mXOffset);
-	//int fileIdx = thumbPool->getCurrentFileIdx();
 
 	DkTimer dt;
 	int cYOffset = mXOffset;
@@ -1192,11 +1155,6 @@ void DkThumbScene::updateLayout() {
 			mThumbLabels.at(idx)->ensureVisible();
 	}
 
-	//update();
-
-	//if (verticalScrollBar()->isVisible())
-	//	verticalScrollBar()->update();
-
 	mFirstLayout = false;
 }
 
@@ -1216,7 +1174,7 @@ void DkThumbScene::updateThumbLabels() {
 
 	for (int idx = 0; idx < mThumbs.size(); idx++) {
 		DkThumbLabel* thumb = new DkThumbLabel(mThumbs.at(idx)->getThumb());
-		connect(thumb, SIGNAL(loadFileSignal(const QString&)), this, SLOT(loadFile(const QString&)));
+		connect(thumb, SIGNAL(loadFileSignal(const QString&, bool)), this, SIGNAL(loadFileSignal(const QString&, bool)));
 		connect(thumb, SIGNAL(showFileSignal(const QString&)), this, SLOT(showFile(const QString&)));
 		connect(mThumbs.at(idx).data(), SIGNAL(thumbLoadedSignal()), this, SIGNAL(thumbLoadedSignal()));
 
@@ -1236,8 +1194,8 @@ void DkThumbScene::updateThumbLabels() {
 
 void DkThumbScene::setImageLoader(QSharedPointer<DkImageLoader> loader) {
 	
-	connectLoader(this->mLoader, false);		// disconnect
-	this->mLoader = loader;
+	connectLoader(mLoader, false);		// disconnect
+	mLoader = loader;
 	connectLoader(loader);
 }
 
@@ -1254,15 +1212,54 @@ void DkThumbScene::connectLoader(QSharedPointer<DkImageLoader> loader, bool conn
 	}
 }
 
+void DkThumbScene::keyPressEvent(QKeyEvent * event) {
+
+	int idx = selectedThumbIndex((event->key() != Qt::Key_Right && event->key() != Qt::Key_Down));
+
+	if (idx == -1)
+		return;
+
+	if (event->modifiers() != Qt::ShiftModifier && 
+		(event->key() == Qt::Key_Left || 
+		 event->key() == Qt::Key_Right || 
+		 event->key() == Qt::Key_Up || 
+		 event->key() == Qt::Key_Down))
+		selectThumbs(false);
+
+	switch (event->key()) {
+	case Qt::Key_Left: {
+		selectThumb(qMax(idx - 1, 0));
+		break;
+	}
+	case Qt::Key_Right: {
+		selectThumb(qMin(idx + 1, mThumbLabels.size()-1));
+		break;
+	}
+	case Qt::Key_Up: {
+		selectThumb(qMax(idx - mNumCols, 0));
+		break;
+	}
+	case Qt::Key_Down: {
+		selectThumb(qMin(idx + mNumCols, mThumbLabels.size()-1));
+		break;
+	}
+
+	}
+}
+
 void DkThumbScene::showFile(const QString& filePath) {
 
 	if (filePath == QDir::currentPath() || filePath.isEmpty()) {
 		int sf = getSelectedFiles().size();
 
+		QString info;
+
 		if (sf > 1)
-			DkStatusBarManager::instance().setMessage(tr("%1 selected").arg(QString::number(sf)));
+			info = QString::number(sf) + tr(" selected");
 		else
-			DkStatusBarManager::instance().setMessage(tr("%1 images").arg(QString::number(mThumbLabels.size())));
+			info = QString::number(mThumbLabels.size()) + tr(" images");
+
+		DkStatusBarManager::instance().setMessage(tr("%1 | %2").arg(info, currentDir()));
 	}
 	else
 		DkStatusBarManager::instance().setMessage(QFileInfo(filePath).fileName());
@@ -1284,6 +1281,28 @@ void DkThumbScene::ensureVisible(QSharedPointer<DkImageContainerT> img) const {
 
 }
 
+QString DkThumbScene::currentDir() const {
+	
+	if (mThumbs.empty() || !mThumbs[0])
+		return "";
+	
+	return mThumbs[0]->fileInfo().absolutePath();
+}
+
+int DkThumbScene::selectedThumbIndex(bool first) {
+	
+	int selIdx = -1;
+	for (int idx = 0; idx < mThumbLabels.size(); idx++) {
+
+		if (first && mThumbLabels[idx]->isSelected())
+			return idx;
+		else if (mThumbLabels[idx]->isSelected())
+			selIdx = idx;
+	}
+	
+	return selIdx;
+}
+
 void DkThumbScene::toggleThumbLabels(bool show) {
 
 	DkSettingsManager::param().display().showThumbLabel = show;
@@ -1291,9 +1310,6 @@ void DkThumbScene::toggleThumbLabels(bool show) {
 	for (int idx = 0; idx < mThumbLabels.size(); idx++)
 		mThumbLabels.at(idx)->updateLabel();
 
-	//// well, that's not too beautiful
-	//if (DkSettingsManager::param().display().displaySquaredThumbs)
-	//	updateLayout();
 }
 
 void DkThumbScene::toggleSquaredThumbs(bool squares) {
@@ -1324,8 +1340,6 @@ void DkThumbScene::resizeThumbs(float dx) {
 		dx += 2.0f;
 
 	int newSize = qRound(DkSettingsManager::param().display().thumbPreviewSize * dx);
-	qDebug() << "delta: " << dx;
-	qDebug() << "newsize: " << newSize;
 
 	if (newSize > 6 && newSize <= max_thumb_size) {
 		DkSettingsManager::param().display().thumbPreviewSize = newSize;
@@ -1333,13 +1347,16 @@ void DkThumbScene::resizeThumbs(float dx) {
 	}
 }
 
-void DkThumbScene::loadFile(const QString& filePath) const {
-	emit loadFileSignal(filePath);
+void DkThumbScene::cancelLoading() {
+	
+	DkThumbsThreadPool::clear();
+
+	for (auto t : mThumbLabels)
+		t->cancelLoading();
 }
 
 void DkThumbScene::selectAllThumbs(bool selected) {
 
-	qDebug() << "selecting...";
 	selectThumbs(selected);
 }
 
@@ -1366,6 +1383,25 @@ void DkThumbScene::selectThumbs(bool selected /* = true */, int from /* = 0 */,
 	showFile();	// update selection label
 }
 
+void DkThumbScene::selectThumb(int idx, bool select) {
+
+	if (mThumbLabels.empty())
+		return;
+
+	if (idx < 0 || idx >= mThumbLabels.size()) {
+		qWarning() << "index out of bounds in selectThumbs()" << idx;
+		return;
+	}
+
+	blockSignals(true);
+	mThumbLabels[idx]->setSelected(select);
+	blockSignals(false);
+	
+	emit selectionChanged();
+	showFile();	// update selection label
+	ensureVisible(mThumbs[idx]);
+}
+
 void DkThumbScene::copySelected() const {
 
 	QStringList fileList = getSelectedFiles();
@@ -1391,7 +1427,7 @@ void DkThumbScene::pasteImages() const {
 	copyImages(QApplication::clipboard()->mimeData());
 }
 
-void DkThumbScene::copyImages(const QMimeData* mimeData) const {
+void DkThumbScene::copyImages(const QMimeData* mimeData, const Qt::DropAction& da) const {
 
 	if (!mimeData || !mimeData->hasUrls() || !mLoader)
 		return;
@@ -1408,14 +1444,46 @@ void DkThumbScene::copyImages(const QMimeData* mimeData) const {
 		if (QFileInfo(newFilePath).exists())
 			continue;
 
-		if (!file.copy(newFilePath)) {
-			int answer = QMessageBox::critical(DkUtils::getMainWindow(), tr("Error"), tr("Sorry, I cannot copy %1 to %2")
-				.arg(fileInfo.absoluteFilePath(), newFilePath), QMessageBox::Ok | QMessageBox::Cancel);
+		auto askUser = [&](const QString& aMsg) {
+			int answer = QMessageBox::critical(DkUtils::getMainWindow(), tr("Error"), tr("Sorry, I cannot %1 %2")
+				.arg(aMsg, newFilePath), QMessageBox::Ok | QMessageBox::Cancel);
+			
+			return answer == QMessageBox::Cancel;
+		};
 
-			if (answer == QMessageBox::Cancel) {
-				break;
-			}
+		bool userCanceled = false;
+
+		switch (da) {
+		// move files -> a move is actually a rename
+		case Qt::MoveAction: {
+			if (!file.rename(newFilePath))
+				userCanceled = askUser(tr("move"));
+			break;
 		}
+		// create links
+		case Qt::LinkAction: {
+
+#ifdef Q_OS_WIN
+			newFilePath += ".lnk";
+#endif
+
+			if (!file.link(newFilePath)) {
+				userCanceled = askUser(tr("create link"));
+			}
+			break;
+		}
+
+		default: {
+			// our default action is copying (usually done without modifiers)
+			if (!file.copy(newFilePath)) {
+				userCanceled = askUser(tr("copy"));
+			}
+			break;
+		}
+		}
+
+		if (userCanceled)
+			break;
 	}
 
 }
@@ -1574,8 +1642,6 @@ DkThumbsView::DkThumbsView(DkThumbScene* scene, QWidget* parent /* = 0 */) : QGr
 	this->scene = scene;
 	connect(scene, SIGNAL(thumbLoadedSignal()), this, SLOT(fetchThumbs()));
 
-	//setDragMode(QGraphicsView::RubberBandDrag);
-
 	setResizeAnchor(QGraphicsView::AnchorUnderMouse);
 	setAcceptDrops(true);
 
@@ -1591,9 +1657,6 @@ void DkThumbsView::wheelEvent(QWheelEvent *event) {
 
 		if (verticalScrollBar()->isVisible()) {
 			verticalScrollBar()->setValue(verticalScrollBar()->value()-event->delta());
-			//fetchThumbs();
-			//scene->update();
-			//scene->invalidate(scene->sceneRect());
 		}
 	}
 
@@ -1655,7 +1718,8 @@ void DkThumbsView::mouseMoveEvent(QMouseEvent *event) {
 				QDrag* drag = new QDrag(this);
 				drag->setMimeData(mimeData);
 				drag->setPixmap(pm);
-				drag->exec(Qt::CopyAction);
+				
+				drag->exec(Qt::CopyAction | Qt::MoveAction | Qt::LinkAction, Qt::CopyAction);
 			}
 		}
 	}
@@ -1675,11 +1739,9 @@ void DkThumbsView::mouseReleaseEvent(QMouseEvent *event) {
 
 	if (lastShiftIdx != -1 && event->modifiers() & Qt::ShiftModifier && itemClicked != 0) {
 		scene->selectThumbs(true, lastShiftIdx, scene->findThumb(itemClicked));
-		qDebug() << "selecting... with SHIFT from: " << lastShiftIdx << " to: " << scene->findThumb(itemClicked);
 	}
 	else if (itemClicked != 0) {
 		lastShiftIdx = scene->findThumb(itemClicked);
-		qDebug() << "starting shift: " << lastShiftIdx;
 	}
 	else
 		lastShiftIdx = -1;
@@ -1688,10 +1750,12 @@ void DkThumbsView::mouseReleaseEvent(QMouseEvent *event) {
 
 void DkThumbsView::dragEnterEvent(QDragEnterEvent *event) {
 
+	QGraphicsView::dragEnterEvent(event);
+
 	qDebug() << event->source() << " I am: " << this;
 
 	if (event->source() == this)
-		event->acceptProposedAction();
+		event->accept();
 	else if (event->mimeData()->hasUrls()) {
 		QUrl url = event->mimeData()->urls().at(0);
 		url = url.toLocalFile();
@@ -1705,73 +1769,20 @@ void DkThumbsView::dragEnterEvent(QDragEnterEvent *event) {
 			event->acceptProposedAction();
 	}
 
-	//QGraphicsView::dragEnterEvent(event);
 }
 
 void DkThumbsView::dragMoveEvent(QDragMoveEvent *event) {
-//
-//	qDebug() << event->source() << " I am: " << this;
-//
-//	if (event->source() == this)
-//		event->acceptProposedAction();
-//	else if (event->mimeData()->hasUrls()) {
-//		QUrl url = event->mimeData()->urls().at(0);
-//		url = url.toLocalFile();
-//
-//		QFileInfo file = QFileInfo(url.toString());
-//
-//		// just accept image files
-//		if (DkImageLoader::isValid(file))
-//			event->acceptProposedAction();
-//		else if (file.isDir())
-//			event->acceptProposedAction();
-//	}
-//
-//	//QGraphicsView::dragEnterEvent(event);
-//}
 
-	if (event->source() == this)
-		event->acceptProposedAction();
+	QGraphicsView::dragMoveEvent(event);
+
+	if (event->source() == this) {
+		event->accept();
+	}
 	else if (event->mimeData()->hasUrls()) {
 		QUrl url = event->mimeData()->urls().at(0);
 		url = url.toLocalFile();
-//		QUrl url = event->mimeData()->urls().at(0);
-//		url = url.toLocalFile();
-//
-//		QFileInfo file = QFileInfo(url.toString());
-//
-//		// just accept image files
-//		if (DkImageLoader::isValid(file))
-//			event->acceptProposedAction();
-//		else if (file.isDir())
-//			event->acceptProposedAction();
-//	}
-//
-//	//QGraphicsView::dragMoveEvent(event);
-//}
 
 		QFileInfo file = QFileInfo(url.toString());
-//
-//	if (event->source() == this) {
-//		event->accept();
-//		return;
-//	}
-//
-//	if (event->mimeData()->hasUrls() && event->mimeData()->urls().size() > 0) {
-//		QUrl url = event->mimeData()->urls().at(0);
-//		qDebug() << "dropping: " << url;
-//		url = url.toLocalFile();
-//
-//		QFileInfo file = QFileInfo(url.toString());
-//		QDir newDir = file.isDir() ? file.absoluteFilePath() : file.absolutePath();
-//
-//		emit updateDirSignal(newDir);
-//	}
-//
-//	QGraphicsView::dropEvent(event);
-//
-//	qDebug() << "drop event...";
-//}
 
 		// just accept image files
 		if (DkUtils::isValid(file))
@@ -1780,7 +1791,6 @@ void DkThumbsView::dragMoveEvent(QDragMoveEvent *event) {
 			event->acceptProposedAction();
 	}
 
-	//QGraphicsView::dragMoveEvent(event);
 }
 
 void DkThumbsView::dropEvent(QDropEvent *event) {
@@ -1792,55 +1802,39 @@ void DkThumbsView::dropEvent(QDropEvent *event) {
 
 	if (event->mimeData()->hasUrls() && event->mimeData()->urls().size() > 0) {
 		
-		if (event->mimeData()->urls().size() > 1) {
-			scene->copyImages(event->mimeData());
-			return;
-		}
-
 		QUrl url = event->mimeData()->urls().at(0);
-		qDebug() << "dropping: " << url;
 		url = url.toLocalFile();
 
 		QFileInfo file = QFileInfo(url.toString());
-		QString newDir = (file.isDir()) ? file.absoluteFilePath() : file.absolutePath();
 
-		emit updateDirSignal(newDir);
+		// if a folder is dropped -> open it
+		if (file.isDir()) {
+			emit updateDirSignal(file.absoluteFilePath());
+		}
+		else {
+			scene->copyImages(event->mimeData(), event->proposedAction());
+		}
 	}
 
 	QGraphicsView::dropEvent(event);
-
-	qDebug() << "drop event...";
 }
 
 void DkThumbsView::fetchThumbs() {
 
-	int maxThreads = DkSettingsManager::param().resources().maxThumbsLoading*2;
-
-	// don't do anything if it is loading anyway
-	if (DkSettingsManager::param().resources().numThumbsLoading/* > maxThreads*/) {
-		return;
-	}
-
 	QList<QGraphicsItem*> items = scene->items(mapToScene(viewport()->rect()).boundingRect(), Qt::IntersectsItemShape);
 
 	for (int idx = 0; idx < items.size(); idx++) {
 
-		if (!maxThreads)
-			break;
-
 		DkThumbLabel* th = dynamic_cast<DkThumbLabel*>(items.at(idx));
 
 		if (!th) {
-			qDebug() << "not a thumb label...";
+			qWarning() << "could not cast to thumb label...";
 			continue;
 		}
 
 		if (th->pixmap().isNull()) {
 			th->update();
-			maxThreads--;
 		}
-		//else if (!thumbLabels.at(idx)->pixmap().isNull())
-		//	firstReached = true;
 	}
 
 }
@@ -1875,12 +1869,6 @@ void DkThumbScrollWidget::createToolbar() {
 	mToolbar = new QToolBar(tr("Thumb Preview Toolbar"), this);
 	mToolbar->setIconSize(QSize(DkSettingsManager::param().effectiveIconSize(this), DkSettingsManager::param().effectiveIconSize(this)));
 
-	qDebug() << mToolbar->styleSheet();
-
-	if (DkSettingsManager::param().display().toolbarGradient) {
-		mToolbar->setObjectName("toolBarWithGradient");
-	}
-
 	DkActionManager& am = DkActionManager::instance();
 	mToolbar->addAction(am.action(DkActionManager::preview_zoom_in));
 	mToolbar->addAction(am.action(DkActionManager::preview_zoom_out));
@@ -1905,12 +1893,7 @@ void DkThumbScrollWidget::createToolbar() {
 	toolButton->setMenu(m);
 	toolButton->setAccessibleName(menuTitle);
 	toolButton->setText(menuTitle);
-	QPixmap pm = QIcon(":/nomacs/img/sort.svg").pixmap(DkSettingsManager::param().effectiveIconSize(this));
-
-	if (!DkSettingsManager::param().display().defaultIconColor || DkSettingsManager::param().app().privateMode)
-		pm = DkImage::colorizePixmap(pm, DkSettingsManager::param().display().iconColor);
-
-	toolButton->setIcon(pm);
+	toolButton->setIcon(DkImage::loadIcon(":/nomacs/img/sort.svg"));
 	toolButton->setPopupMode(QToolButton::InstantPopup);
 	mToolbar->addWidget(toolButton);
 
@@ -1973,7 +1956,6 @@ void DkThumbScrollWidget::batchPrint() const {
 	}
 
 	printPreviewDialog->show();
-	//mPrintPreviewDialog->updateZoomFactor(); // otherwise the initial zoom factor is wrong
 }
 
 void DkThumbScrollWidget::updateThumbs(QVector<QSharedPointer<DkImageContainerT> > thumbs) {
@@ -2002,6 +1984,8 @@ void DkThumbScrollWidget::setVisible(bool visible) {
 		mThumbsScene->updateThumbLabels();
 		mFilterEdit->setText("");
 	}
+	else
+		mThumbsScene->cancelLoading();
 }
 
 void DkThumbScrollWidget::connectToActions(bool activate) {
@@ -2045,14 +2029,12 @@ void DkThumbScrollWidget::connectToActions(bool activate) {
 		disconnect(mFilterEdit, SIGNAL(textChanged(const QString&)), this, SIGNAL(filterChangedSignal(const QString&)));
 		disconnect(mView, SIGNAL(updateDirSignal(const QString&)), this, SIGNAL(updateDirSignal(const QString&)));
 		disconnect(mThumbsScene, SIGNAL(selectionChanged()), this, SLOT(enableSelectionActions()));
-
 	}
 }
 
 void DkThumbScrollWidget::setFilterFocus() const {
 
 	mFilterEdit->setFocus(Qt::MouseFocusReason);
-	qDebug() << "focus set...";
 }
 
 void DkThumbScrollWidget::resizeEvent(QResizeEvent *event) {
@@ -2066,7 +2048,6 @@ void DkThumbScrollWidget::resizeEvent(QResizeEvent *event) {
 
 void DkThumbScrollWidget::contextMenuEvent(QContextMenuEvent *event) {
 
-	//if (!event->isAccepted())
 	mContextMenu->exec(event->globalPos());
 	event->accept();
 
@@ -2086,4 +2067,373 @@ void DkThumbScrollWidget::enableSelectionActions() {
 	am.action(DkActionManager::preview_select_all)->setChecked(mThumbsScene->allThumbsSelected());
 }
 
+// DkThumbPreviewLabel --------------------------------------------------------------------
+DkThumbPreviewLabel::DkThumbPreviewLabel(const QString& filePath, int thumbSize, QWidget* parent /* = 0 */, Qt::WindowFlags f /* = 0 */) : QLabel(parent, f) {
+
+	mThumbSize = thumbSize;
+
+	mThumb = QSharedPointer<DkThumbNailT>(new DkThumbNailT(filePath));
+	connect(mThumb.data(), SIGNAL(thumbLoadedSignal()), this, SLOT(thumbLoaded()));
+
+	setFixedSize(mThumbSize, mThumbSize);
+	setAlignment(Qt::AlignHCenter | Qt::AlignVCenter);
+	setStatusTip(filePath);
+	
+	QFileInfo fInfo(filePath);
+	setToolTip(fInfo.fileName());
+
+	mThumb->fetchThumb(DkThumbNail::force_exif_thumb);
+}
+
+void DkThumbPreviewLabel::thumbLoaded() {
+
+	if (mThumb->getImage().isNull()) {
+		setProperty("empty", true);	// apply empty style
+		style()->unpolish(this);
+		style()->polish(this);
+		update();
+
+		return;
+	}
+
+	QPixmap pm = QPixmap::fromImage(mThumb->getImage());
+	pm = DkImage::makeSquare(pm);
+	
+	if (pm.width() > width())
+		pm = pm.scaled(size(), Qt::KeepAspectRatio, Qt::SmoothTransformation);
+
+	setPixmap(pm);
+}
+
+void DkThumbPreviewLabel::mousePressEvent(QMouseEvent *ev) {
+
+	emit loadFileSignal(mThumb->getFilePath(), ev->modifiers() == Qt::ControlModifier);
+
+	// do not propagate
+	//QLabel::mousePressEvent(ev);
+}
+
+// -------------------------------------------------------------------- DkRecentFilesEntry 
+DkRecentDirWidget::DkRecentDirWidget(const DkRecentDir& rde, QWidget* parent) : DkWidget(parent) {
+
+	mRecentDir = rde;
+
+	createLayout();
+	QMetaObject::connectSlotsByName(this);
+}
+
+void DkRecentDirWidget::createLayout() {
+
+	QLabel* dirNameLabel = new QLabel(mRecentDir.dirName(), this);
+	dirNameLabel->setAlignment(Qt::AlignBottom);
+	dirNameLabel->setObjectName("recentFilesTitle");
+
+	// create buttons
+	mButtons.resize(button_end);
+
+	mButtons[button_load_dir] = new QPushButton(DkImage::loadIcon(":/nomacs/img/dir.svg"), "", this);
+	mButtons[button_load_dir]->setToolTip(tr("Load the directory"));
+	mButtons[button_load_dir]->setObjectName("load_dir");
+	mButtons[button_load_dir]->setFlat(true);
+	mButtons[button_load_dir]->hide();
+
+	QIcon pIcon;
+	pIcon.addPixmap(DkImage::loadIcon(":/nomacs/img/pin-checked.svg"), QIcon::Normal, QIcon::On);
+	pIcon.addPixmap(DkImage::loadIcon(":/nomacs/img/pin.svg"), QIcon::Normal, QIcon::Off);
+
+	mButtons[button_pin] = new QPushButton(pIcon, "", this);
+	mButtons[button_pin]->setToolTip(tr("Pin this directory"));
+	mButtons[button_pin]->setObjectName("pin");
+	mButtons[button_pin]->setCheckable(true);
+	mButtons[button_pin]->setChecked(mRecentDir.isPinned());
+	mButtons[button_pin]->setFlat(true);
+	mButtons[button_pin]->hide();
+
+	mButtons[button_remove] = new QPushButton(DkImage::loadIcon(":/nomacs/img/close.svg"), "", this);
+	mButtons[button_remove]->setToolTip(tr("Remove this directory"));
+	mButtons[button_remove]->setObjectName("remove");
+	mButtons[button_remove]->setFlat(true);
+	mButtons[button_remove]->hide();
+
+	QVector<DkThumbPreviewLabel*> tls;
+
+	// check if the folder exists (in the current context)
+	// this should fix issues with disconnected samba drives on windows
+	if (DkUtils::exists(mRecentDir.firstFilePath(), 30)) {
+
+		for (auto tp : mRecentDir.filePaths(4)) {
+			auto tpl = new DkThumbPreviewLabel(tp, 42, this);
+			connect(tpl, SIGNAL(loadFileSignal(const QString&, bool)), this, SIGNAL(loadFileSignal(const QString&, bool)));
+			tls << tpl;
+		}
+	}
+	else {
+		qInfo() << mRecentDir.firstFilePath() << "does not exist - according to a fast check";
+	}
+
+	QLabel* pathLabel = new QLabel(mRecentDir.dirPath(), this);
+	pathLabel->setAlignment(Qt::AlignLeft);
+	pathLabel->setObjectName("recentFilesPath");
+
+	QGridLayout* layout = new QGridLayout(this);
+	layout->setAlignment(Qt::AlignLeft);
+	layout->addWidget(dirNameLabel, 1, 0, 1, tls.size()+1);
+	layout->setColumnStretch(tls.size()+2, 1);
+	layout->addWidget(mButtons[button_load_dir], 1, tls.size() + 3);
+	layout->addWidget(mButtons[button_pin], 1, tls.size() + 4);
+	layout->addWidget(mButtons[button_remove], 1, tls.size() + 5);
+	layout->addWidget(pathLabel, 2, tls.size(), 1, 6);
+
+	for (int idx = 0; idx < tls.size(); idx++)
+		layout->addWidget(tls[idx], 2, idx, Qt::AlignTop);
+
+	show();
+	setCursor(Qt::PointingHandCursor);
+
+	setToolTip(mRecentDir.dirPath());
+	setStatusTip(mRecentDir.dirPath());
+}
+
+void DkRecentDirWidget::on_pin_clicked(bool checked) {
+
+	if (checked) {
+		DkSettingsManager::param().global().pinnedFiles << mRecentDir.filePaths();
+	}
+	else {
+		for (const QString& fp : mRecentDir.filePaths())
+			DkSettingsManager::param().global().pinnedFiles.removeAll(fp);
+	}
+}
+
+void DkRecentDirWidget::on_remove_clicked() {
+
+	mRecentDir.remove();
+	emit removeSignal();
+}
+
+void DkRecentDirWidget::on_load_dir_clicked() {
+
+	emit loadDirSignal(mRecentDir.dirPath());
+}
+
+void DkRecentDirWidget::mousePressEvent(QMouseEvent * event) {
+	
+	if (event->button() == Qt::LeftButton && !mRecentDir.isEmpty()) {
+		emit loadFileSignal(mRecentDir.firstFilePath(), event->modifiers() == Qt::ControlModifier);
+	}
+
+	DkWidget::mousePressEvent(event);
+}
+
+void DkRecentDirWidget::enterEvent(QEvent * event) {
+
+	for (auto b : mButtons)
+		b->show();
+
+	DkWidget::enterEvent(event);
+}
+
+void DkRecentDirWidget::leaveEvent(QEvent * event) {
+
+	for (auto b : mButtons)
+		b->hide();
+
+	DkWidget::leaveEvent(event);
+}
+
+// -------------------------------------------------------------------- DkRecentFilesEntry 
+DkRecentFilesWidget::DkRecentFilesWidget(QWidget* parent) : DkWidget(parent) {
+
+	createLayout();
+	setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding);
+}
+
+void DkRecentFilesWidget::setVisible(bool visible) {
+
+	if (visible)
+		updateList();
+
+	DkWidget::setVisible(visible);
+}
+
+void DkRecentFilesWidget::createLayout() {
+
+	mScrollArea = new QScrollArea(this);
+	QVBoxLayout* sl = new QVBoxLayout(this);
+	sl->addWidget(mScrollArea);
+	sl->setContentsMargins(0, 0, 0, 0);
+
+	mScrollArea->setAlignment(Qt::AlignHCenter | Qt::AlignVCenter);
+
+	//updateList();
+}
+
+void DkRecentFilesWidget::updateList() {
+
+	DkRecentDirManager fm;
+
+	QWidget* dummy = new QWidget(this);
+	QVBoxLayout* l = new QVBoxLayout(dummy);
+
+	QVector<DkRecentDirWidget*> recentFiles;
+	int idx = 0;
+
+	for (auto rd : fm.recentDirs()) {
+		
+		DkRecentDirWidget* rf = new DkRecentDirWidget(rd, dummy);
+		rf->setMaximumWidth(500);
+		connect(rf, SIGNAL(loadFileSignal(const QString&, bool)), this, SIGNAL(loadFileSignal(const QString&, bool)));
+		connect(rf, SIGNAL(loadDirSignal(const QString&)), this, SIGNAL(loadDirSignal(const QString&)));
+		connect(rf, SIGNAL(removeSignal()), this, SLOT(entryRemoved()));
+		
+		recentFiles << rf;
+		l->addWidget(rf);
+		idx++;
+	}
+
+	mScrollArea->setWidget(dummy);
+}
+
+void DkRecentFilesWidget::entryRemoved() {
+
+	updateList();
+}
+
+// -------------------------------------------------------------------- DkRecentDir 
+DkRecentDir::DkRecentDir(const QStringList& filePaths, bool pinned) {
+	mFilePaths = filePaths;
+	mIsPinned = pinned;
+}
+
+bool DkRecentDir::operator==(const DkRecentDir& o) const {
+
+	return dirPath() == o.dirPath();
+}
+
+void DkRecentDir::update(const DkRecentDir & o) {
+
+	for (const QString& cp : o.filePaths())
+		mFilePaths.push_front(cp);
+
+	mFilePaths.removeDuplicates();
+}
+
+QStringList DkRecentDir::filePaths(int max) const {
+
+	if (max <= 0)
+		return mFilePaths;
+
+	QStringList fps = mFilePaths;
+
+	while (fps.size() > max)
+		fps.pop_back();
+
+	return fps;
+}
+
+bool DkRecentDir::isEmpty() const {
+	return mFilePaths.isEmpty();
+}
+
+bool DkRecentDir::isPinned() const {
+	return mIsPinned;
+}
+
+QString DkRecentDir::dirName() const {
+
+	QDir d(dirPath());
+	return d.dirName();
+}
+
+QString DkRecentDir::dirPath() const {
+
+	if (mFilePaths.empty())
+		return QString("");
+
+	return QFileInfo(mFilePaths[0]).absolutePath();
+}
+
+QString DkRecentDir::firstFilePath() const {
+	
+	if (!mFilePaths.isEmpty())
+		return mFilePaths[0];
+	
+	return QString();
+}
+
+void DkRecentDir::remove() const {
+	
+	QStringList& pf = DkSettingsManager::param().global().pinnedFiles;
+	QStringList& rf = DkSettingsManager::param().global().recentFiles;
+
+	// remove from history
+	for (const QString& fp : mFilePaths) {
+		pf.removeAll(fp);
+		rf.removeAll(fp);
+	}
+}
+
+// -------------------------------------------------------------------- DkRecentDirManager 
+DkRecentDirManager::DkRecentDirManager() {
+
+	// update pinned files
+	mDirs = genFileLists(DkSettingsManager::param().global().pinnedFiles, true);
+	auto recentDirs = genFileLists(DkSettingsManager::param().global().recentFiles);
+
+	for (auto rde : recentDirs) {
+
+		if (!mDirs.contains(rde))
+			mDirs << rde;
+		else {
+			int idx = mDirs.indexOf(rde);
+			if (idx != -1)
+				mDirs[idx].update(rde);
+		}
+
+	}
+}
+
+QList<DkRecentDir> DkRecentDirManager::recentDirs() const {
+	return mDirs;
+}
+
+QList<DkRecentDir> DkRecentDirManager::genFileLists(const QStringList & filePaths, bool pinned) {
+
+	QMap<QString, QStringList> gPaths;
+
+	for (const QString& cp : filePaths) {
+
+		QFileInfo fi(cp);
+
+		// this if is needed if there are errors in our data
+		// however, it incredibly slows down the process if samba mounts are lost
+		//if (!fi.isFile())
+		//	continue;
+		
+		// get folder
+		QString dp = fi.absolutePath();
+
+		auto dir = gPaths.find(dp);
+
+		// ok, create a new entry
+		if (dir == gPaths.end()) {
+			QStringList cpl;
+			cpl << cp;
+			gPaths.insert(dp, cpl);
+		}
+		else {
+
+			// append the filename
+			dir.value() << cp;
+		}
+	}
+
+	// create recent directories
+	QList<DkRecentDir> rdes;
+	for (const QStringList& fps : gPaths.values())
+		rdes << DkRecentDir(fps, pinned);
+
+	return rdes;
+}
+
 }
