@@ -179,7 +179,6 @@ private:
 	void drawCurrentImgEffect(QPainter* painter, const QRectF& r);
 	void drawNoImgEffect(QPainter* painter, const QRectF& r);
 	void createContextMenu();
-
 };
 
 class DkThumbLabel : public QGraphicsObject {
@@ -196,12 +195,13 @@ public:
 	void updateSize();
 	void setVisible(bool visible);
 	QPixmap pixmap() const;
+	void cancelLoading();
 
 public slots:
 	void updateLabel();
 
 signals:
-	void loadFileSignal(const QString& filePath) const;
+	void loadFileSignal(const QString& filePath, bool newTab) const;
 	void showFileSignal(const QString& filePath = QString()) const;
 
 protected:
@@ -232,15 +232,18 @@ public:
 	void updateLayout();
 	QStringList getSelectedFiles() const;
 	QVector<DkThumbLabel*> getSelectedThumbs() const;
+	int selectedThumbIndex(bool first = true);
+
 	void setImageLoader(QSharedPointer<DkImageLoader> loader);
-	void copyImages(const QMimeData* mimeData) const;
+	void copyImages(const QMimeData* mimeData, const Qt::DropAction& da = Qt::CopyAction) const;
 	int findThumb(DkThumbLabel* thumb) const;
 	bool allThumbsSelected() const;
 	void ensureVisible(QSharedPointer<DkImageContainerT> img) const;
-
+	QString currentDir() const;
+	
 public slots:
 	void updateThumbLabels();
-	void loadFile(const QString& filePath) const;
+	void cancelLoading();
 	void increaseThumbs();
 	void decreaseThumbs();
 	void toggleSquaredThumbs(bool squares);
@@ -248,6 +251,7 @@ public slots:
 	void resizeThumbs(float dx);
 	void showFile(const QString& filePath = QString());
 	void selectThumbs(bool select = true, int from = 0, int to = -1);
+	void selectThumb(int idx, bool select = true);
 	void selectAllThumbs(bool select = true);
 	void updateThumbs(QVector<QSharedPointer<DkImageContainerT> > thumbs);
 	void deleteSelected() const;
@@ -256,12 +260,13 @@ public slots:
 	void renameSelected() const;
 
 signals:
-	void loadFileSignal(const QString& filePath) const;
+	void loadFileSignal(const QString& filePath, bool newTab) const;
 	void statusInfoSignal(const QString& msg, int pos = 0) const;
 	void thumbLoadedSignal() const;
 
 protected:
 	void connectLoader(QSharedPointer<DkImageLoader> loader, bool connectSignals = true);
+	void keyPressEvent(QKeyEvent* event) override;
 	
 	int mXOffset = 0;
 	int mNumRows = 0;
@@ -341,5 +346,119 @@ protected:
 	QLineEdit* mFilterEdit = 0;
 };
 
+class DkRecentDir {
+
+public:
+	DkRecentDir(const QStringList& filePaths = QStringList(), bool pinned = false);
+
+	bool operator==(const DkRecentDir& o) const;
+	void update(const DkRecentDir& o);
+
+	bool isEmpty() const;
+	bool isPinned() const;
+	
+	QString dirName() const;
+	QString dirPath() const;
+	QString firstFilePath() const;
+	QStringList filePaths(int max = -1) const;
+	
+	void remove() const;
+
+private:
+	QStringList mFilePaths;
+	bool mIsPinned = false;
+};
+
+class DkRecentDirManager {
+
+public:
+	DkRecentDirManager();
+
+	QList<DkRecentDir> recentDirs() const;
+
+private:
+
+	QList<DkRecentDir> genFileLists(const QStringList& filePaths, bool pinned = false);
+	
+	QList<DkRecentDir> mDirs;
+};
+
+class DkThumbPreviewLabel : public QLabel {
+	Q_OBJECT
+
+public:
+	DkThumbPreviewLabel(const QString& filePath, int thumbSize = 100, QWidget* parent = 0, Qt::WindowFlags f = 0);
+
+signals:
+	void loadFileSignal(const QString& filePath, bool newTab);
+
+public slots:
+	void thumbLoaded();
+
+protected:
+	void mousePressEvent(QMouseEvent *ev);
+
+	QSharedPointer<DkThumbNailT> mThumb;
+	int mThumbSize = 100;
+};
+
+class DllCoreExport DkRecentDirWidget : public DkWidget {
+	Q_OBJECT
+
+public:
+	DkRecentDirWidget(const DkRecentDir& rde, QWidget* parent = 0);
+
+signals:
+	void loadFileSignal(const QString& filePath, bool newTab);
+	void loadDirSignal(const QString& filePath);
+	void removeSignal();
+
+public slots:
+	void on_pin_clicked(bool checked);
+	void on_remove_clicked();
+	void on_load_dir_clicked();
+
+protected:
+	DkRecentDir mRecentDir;
+	QVector<DkThumbLabel> mThumbs;
+	
+	enum {
+		button_load_dir = 0,
+		button_pin,
+		button_remove,
+
+		button_end
+	};
+
+	QVector<QPushButton*> mButtons;
+
+	void createLayout();
+	void mousePressEvent(QMouseEvent* event) override;
+	void enterEvent(QEvent* event) override;
+	void leaveEvent(QEvent* event) override;
+
+};
+
+class DllCoreExport DkRecentFilesWidget : public DkWidget {
+	Q_OBJECT
+
+public:
+	DkRecentFilesWidget(QWidget* parent = 0);
+
+signals:
+	void loadFileSignal(const QString& filePath, bool newTab);
+	void loadDirSignal(const QString& filePath);
+
+public slots:
+	void entryRemoved();
+	void setVisible(bool visible) override;
+
+protected:
+	void createLayout();
+	void updateList();
+	
+	QScrollArea* mScrollArea;
+};
+
 
 }
