@@ -864,13 +864,7 @@ DkCropToolBar::DkCropToolBar(const QString & title, QWidget * parent /* = 0 */)
 	QMetaObject::connectSlotsByName(this);
 
 	setIconSize(QSize(DkSettingsManager::param().effectiveIconSize(this), DkSettingsManager::param().effectiveIconSize(this)));
-
-	if (DkSettingsManager::param().display().toolbarGradient) 
-		setObjectName("toolBarWithGradient");
-	else {
-		setStyleSheet("QToolBar{spacing: 3px; padding: 3px;}");
-		setObjectName("cropToolBar");
-	}
+	setObjectName("cropToolBar");
 }
 
 DkCropToolBar::~DkCropToolBar() {
@@ -913,9 +907,9 @@ void DkCropToolBar::createIcons() {
 	mIcons.resize(icons_end);
 
 	mIcons[crop_icon] = DkImage::loadIcon(":/nomacs/img/crop.svg");
-	mIcons[cancel_icon] = DkImage::loadIcon(":/nomacs/img/cancel.svg");
+	mIcons[cancel_icon] = DkImage::loadIcon(":/nomacs/img/close.svg");
 	mIcons[pan_icon] = 	DkImage::loadIcon(":/nomacs/img/pan.svg");
-	mIcons[pan_icon].addPixmap(DkImage::loadIcon(":/nomacs/img/pan_checked.svg"), QIcon::Normal, QIcon::On);
+	mIcons[pan_icon].addPixmap(DkImage::loadIcon(":/nomacs/img/pan-checked.svg"), QIcon::Normal, QIcon::On);
 	mIcons[invert_icon] = DkImage::loadIcon(":/nomacs/img/crop-invert.svg");
 	mIcons[invert_icon].addPixmap(DkImage::loadIcon(":/nomacs/img/crop-invert-checked.svg"), QIcon::Normal, QIcon::On);
 	mIcons[info_icon] = DkImage::loadIcon(":/nomacs/img/info.svg");
