@@ -77,11 +77,11 @@ public:
 	DkViewPort(QWidget *parent = 0, Qt::WindowFlags flags = 0);
 	virtual ~DkViewPort();
 	
-	void zoom(float factor = 0.5, QPointF center = QPointF(-1,-1));
+	void zoom(double factor = 0.5, const QPointF& center = QPointF(-1,-1)) override;
 
 	void setFullScreen(bool fullScreen);
 		
-	QTransform getWorldMatrix() { 
+	QTransform getWorldMatrix() override { 
 		return mWorldMatrix;
 	};
 
@@ -110,18 +110,14 @@ public:
 	
 	void connectLoader(QSharedPointer<DkImageLoader> loader, bool connectSignals = true);
 
-	// fun
-	void toggleDissolve();
-
 signals:
 	void sendTransformSignal(QTransform transform, QTransform imgTransform, QPointF canvasSize) const;
 	void sendNewFileSignal(qint16 op, QString filename = "") const;
-	void sendImageSignal(QImage img, QString title) const;
 	void newClientConnectedSignal(bool connect, bool local) const;
 	void movieLoadedSignal(bool isMovie) const;
 	void infoSignal(const QString& msg) const;	// needed to forward signals
 	void addTabSignal(const QString& filePath) const;
-	void zoomSignal(float zoomLevel) const;
+	void zoomSignal(double zoomLevel) const;
 	void mouseClickSignal(QMouseEvent* event, QPoint imgPos) const;
 	void showProgress(bool show, int time = -1) const;
 
@@ -134,16 +130,15 @@ public slots:
 	void fullView();
 	void resizeEvent(QResizeEvent* event);
 	void toggleResetMatrix();
-	void zoomTo(float zoomLevel, const QPoint& pos = QPoint(-1, -1));
+	void zoomTo(double zoomLevel);
 	
 	// tcp actions
 	void tcpSetTransforms(QTransform worldMatrix, QTransform imgMatrix, QPointF canvasSize);
 	void tcpSetWindowRect(QRect rect);
-	void tcpSynchronize(QTransform relativeMatrix = QTransform());
 	void tcpForceSynchronize();
+	void tcpSynchronize(QTransform relativeMatrix = QTransform(), bool force = false);
 	void tcpLoadFile(qint16 idx, QString filename);
 	void tcpShowConnections(QList<DkPeer*> peers);
-	void tcpSendImage(bool silent = false);
 	
 	// file actions
 	void loadFile(const QString& filePath);
@@ -157,15 +152,15 @@ public slots:
 	void loadSkipNext10();
 	void loadSkipPrev10();
 	void loadLena();
-	bool unloadImage(bool fileChange = true);
+	bool unloadImage(bool fileChange = true) override;
 	void deactivate();
-	//void fileNotLoaded(QFileInfo file);
 	void cropImage(const DkRotatingRect& rect, const QColor& bgCol, bool cropToMetaData);
 	void repeatZoom();
 
 	void applyPlugin(DkPluginContainer* plugin, const QString& key);
 
 	// image saving
+	QImage getImage() const override;
 	void saveFile();
 	void saveFileAs(bool silent = false);
 	void saveFileWeb();
@@ -185,8 +180,7 @@ public slots:
 	virtual void loadImage(QSharedPointer<DkImageContainerT> img);
 	virtual void setEditedImage(const QImage& newImg, const QString& editName);
 	virtual void setEditedImage(QSharedPointer<DkImageContainerT> img);
-	virtual void setImage(QImage newImg);
-	virtual void setThumbImage(QImage newImg);
+	virtual void setImage(QImage newImg) override;
 
 	void settingsChanged();
 	void pauseMovie(bool paused);
@@ -196,26 +190,25 @@ public slots:
 	void nextMovieFrame();
 	void previousMovieFrame();
 	void animateFade();
-	virtual void togglePattern(bool show);
+	virtual void togglePattern(bool show) override;
 
 protected:
 	
 	// events
-	virtual void dragLeaveEvent(QDragLeaveEvent *event);
-	virtual void mousePressEvent(QMouseEvent *event);
-	virtual void mouseReleaseEvent(QMouseEvent *event);
-	virtual void mouseMoveEvent(QMouseEvent *event);
-	virtual void wheelEvent(QWheelEvent *event);
-	virtual bool event(QEvent *event);
-	virtual void paintEvent(QPaintEvent* event);
-	//QTransform getSwipeTransform() const;
+	virtual void dragLeaveEvent(QDragLeaveEvent *event) override;
+	virtual void mousePressEvent(QMouseEvent *event) override;
+	virtual void mouseReleaseEvent(QMouseEvent *event) override;
+	virtual void mouseMoveEvent(QMouseEvent *event) override;
+	virtual void wheelEvent(QWheelEvent *event) override;
+	virtual bool event(QEvent *event) override;
+	virtual void paintEvent(QPaintEvent* event) override;
 
 	bool mTestLoaded = false;
 	bool mGestureStarted = false;
 
 	QRectF mOldImgRect;
 
-	QTimer* mRepeatZoomTimer;// = new QTimer(this);
+	QTimer* mRepeatZoomTimer;
 	
 	// fading stuff
 	QTimer* mAnimationTimer;
@@ -226,9 +219,6 @@ protected:
 	QRectF mFadeImgRect;
 	bool mNextSwipe = true;
 
-	// fun
-	bool mDissolveImage = false;
-	
 	QImage mImgBg;
 
 	QVBoxLayout* mPaintLayout;
@@ -264,17 +254,9 @@ public:
 	DkViewPortFrameless(QWidget *parent = 0, Qt::WindowFlags flags = 0);
 	virtual ~DkViewPortFrameless();
 
-	virtual void zoom(float factor = 0.5, QPointF center = QPointF(-1,-1));
-	virtual void setMainGeometry(const QRect &geometry) {
-		mMainScreen = geometry;
-	};
-
-	virtual QRect getMainGeometry() {
-		return mMainScreen;
-	};
+	virtual void zoom(double factor = 0.5, const QPointF& center = QPointF(-1,-1)) override;
 
 public slots:
-	virtual void setImage(QImage newImg);
 	virtual void resetView();
 	virtual void moveView(QPointF);
 
@@ -282,11 +264,9 @@ protected:
 	virtual void mousePressEvent(QMouseEvent *event);
 	virtual void mouseReleaseEvent(QMouseEvent *event);
 	virtual void mouseMoveEvent(QMouseEvent *event);
-	virtual void resizeEvent(QResizeEvent* event);
 	virtual void paintEvent(QPaintEvent* event);
 
 	// functions
-	//QTransform getScaledImageMatrix();
 	virtual void updateImageMatrix();
 	virtual void draw(QPainter & painter, double opacity = 1.0);
 	void drawFrame(QPainter & painter);
@@ -299,7 +279,6 @@ protected:
 	QVector<QIcon> mStartIcons;
 	QVector<QRectF> mStartActionsRects;
 	QVector<QPixmap> mStartActionsIcons;
-	QRect mMainScreen;	// TODO: let user choose which one to take
 };
 
 class DllCoreExport DkViewPortContrast : public DkViewPort {
