@@ -95,6 +95,9 @@
 #include <QSvgRenderer>
 #include <QFileDialog>
 #include <QInputDialog>
+#include <QButtonGroup>
+#include <QDesktopWidget>
+#include <QScreen>
 #pragma warning(pop)		// no warnings from includes - end
 
 namespace nmc {
@@ -278,7 +281,6 @@ void DkFolderScrollBar::animateOpacityDown() {
 // DkThumbsSaver --------------------------------------------------------------------
 DkThumbsSaver::DkThumbsSaver(QWidget* parent) : DkWidget(parent) {
 	mStop = false;
-	mCLoadIdx = 0;
 	mNumSaved = 0;
 }
 
@@ -288,7 +290,6 @@ void DkThumbsSaver::processDir(QVector<QSharedPointer<DkImageContainerT> > image
 		return;
 
 	mStop = false;
-	mCLoadIdx = 0;
 	mNumSaved = 0;
 
 	mPd = new QProgressDialog(tr("\nCreating thumbnails...\n") + images.first()->filePath(), 
@@ -333,15 +334,9 @@ void DkThumbsSaver::loadNext() {
 	if (mStop)
 		return;
 
-	int missing = DkSettingsManager::param().resources().maxThumbsLoading-DkSettingsManager::param().resources().numThumbsLoading;
-	int numLoading = mCLoadIdx+missing;
 	int force = (mForceSave) ? DkThumbNail::force_save_thumb : DkThumbNail::save_thumb;
 
-	qDebug() << "missing: " << missing << " num loading: " << numLoading;
-	qDebug() << "loading bounds: " << mCLoadIdx << " - " << numLoading;
-
-	for (int idx = mCLoadIdx; idx < mImages.size() && idx < numLoading; idx++) {
-		mCLoadIdx++;
+	for (int idx = 0; idx < mImages.size(); idx++) {
 		connect(mImages.at(idx)->getThumb().data(), SIGNAL(thumbLoadedSignal(bool)), this, SLOT(thumbLoaded(bool)));
 		mImages.at(idx)->getThumb()->fetchThumb(force);
 	}
@@ -359,8 +354,6 @@ DkFileSystemModel::DkFileSystemModel(QObject* parent /* = 0 */) : QFileSystemMod
 	setRootPath(QDir::rootPath());
 	setNameFilters(DkSettingsManager::param().app().fileFilters);
 	setReadOnly(false);
-	//setSupportedDragActions(Qt::CopyAction | Qt::MoveAction);
-
 }
 
 // DkSortFileProxyModel --------------------------------------------------------------------
@@ -433,12 +426,12 @@ void DkExplorer::createLayout() {
 	sortModel = new DkSortFileProxyModel(this);
 	sortModel->setSourceModel(fileModel);
 	sortModel->setSortLocaleAware(true);
-
+	
 	fileTree = new QTreeView(this);
 	fileTree->setSortingEnabled(true);
 	fileTree->setModel(sortModel);
 	fileTree->setDragEnabled(true);
-	//fileTree->setContextMenuPolicy(Qt::CustomContextMenu);
+	fileTree->setAcceptDrops(true);
 
 	// by default descendingOrder is set
 	fileTree->header()->setSortIndicator(0, Qt::AscendingOrder);
@@ -609,7 +602,12 @@ DkOverview::DkOverview(QWidget* parent) : QLabel(parent) {
 
 void DkOverview::paintEvent(QPaintEvent *event) {
 
-	if (mImg.isNull() || !mImgMatrix || !mWorldMatrix)
+	if (mImgT.isNull()) {
+		mImgT = resizedImg(mImg);
+		mImg = QImage();	// free-up space
+	}
+
+	if (!mImgMatrix || !mWorldMatrix)
 		return;
 
 	QPainter painter(this);
@@ -622,7 +620,7 @@ void DkOverview::paintEvent(QPaintEvent *event) {
 	if (viewSize.width() > 2 && viewSize.height() > 2) {
 	
 		QTransform overviewImgMatrix = getScaledImageMatrix();			// matrix that always resizes the image to the current mViewport
-		QRectF overviewImgRect = getScaledImageMatrix().mapRect(QRectF(QPointF(), mImg.size()));
+		QRectF overviewImgRect = getScaledImageMatrix().mapRect(QRectF(QPointF(), mImgSize));
 
 		// now render the current view
 		QRectF viewRect = mViewPortRect;
@@ -642,7 +640,7 @@ void DkOverview::paintEvent(QPaintEvent *event) {
 		painter.setPen(QColor(200, 200, 200));
 		//painter.drawRect(overviewRect);
 		painter.setOpacity(0.8f);
-		painter.drawImage(overviewImgRect, imgT, QRect(0, 0, imgT.width(), imgT.height()));
+		painter.drawImage(overviewImgRect, mImgT, QRect(0, 0, mImgT.width(), mImgT.height()));
 
 		QColor col = DkSettingsManager::param().display().highlightColor;
 		col.setAlpha(255);
@@ -710,48 +708,39 @@ void DkOverview::mouseMoveEvent(QMouseEvent *event) {
 
 }
 
-void DkOverview::resizeEvent(QResizeEvent* event) {
-
-	QWidget::resizeEvent(event);
-}
-
 QRectF DkOverview::getImageRect() const {
 	
 	QRectF imgRect = QRectF(QPoint(), size());			// get the overview rect
 
-	if ((float)imgT.width()/imgT.height() < (float)imgRect.width()/imgRect.height())
-		imgRect.setWidth(width() * (float)height()/(float)imgT.height());
+	if ((float)mImgT.width()/mImgT.height() < (float)imgRect.width()/imgRect.height())
+		imgRect.setWidth(width() * (float)height()/(float)mImgT.height());
 	else
-		imgRect.setHeight(height() * (float)width()/(float)imgT.width());
-
-	//imgRect = imgRect.toRect();	// force round
+		imgRect.setHeight(height() * (float)width()/(float)mImgT.width());
 
 	return imgRect;
 }
 
-void DkOverview::resizeImg() {
+QImage DkOverview::resizedImg(const QImage& src) {
 
-	if (mImg.isNull())
-		return;
+	if (src.isNull())
+		return QImage();
 
-	//QRectF overviewRect = getImageRect();
 	QTransform overviewImgMatrix = getScaledImageMatrix();			// matrix that always resizes the image to the current mViewport
 	
 	// is the overviewImgMatrix empty?
 	if (overviewImgMatrix.isIdentity())
-		return;
+		return src;
 	
-	//if (overviewRect.width() <= 1|| overviewRect.height() <= 1)
-	//	return;
-
 	// fast downscaling
-	imgT = mImg.scaled(maximumWidth()*2, maximumHeight()*2, Qt::KeepAspectRatio, Qt::FastTransformation);
-	imgT = imgT.scaled(maximumWidth(), maximumHeight(), Qt::KeepAspectRatio, Qt::SmoothTransformation);
+	QImage sImg = src.scaled(maximumWidth()*2, maximumHeight()*2, Qt::KeepAspectRatio, Qt::FastTransformation);
+	sImg = sImg.scaled(maximumWidth(), maximumHeight(), Qt::KeepAspectRatio, Qt::SmoothTransformation);
+
+	return sImg;
 }
 
 QTransform DkOverview::getScaledImageMatrix() {
 
-	if (mImg.isNull())
+	if (mImgT.isNull() && mImg.isNull())
 		return QTransform();
 
 	int lm, tm, rm, bm;
@@ -763,7 +752,7 @@ QTransform DkOverview::getScaledImageMatrix() {
 		return QTransform();
 
 	// the image resizes as we zoom
-	QRectF imgRect = QRectF(QPoint(lm, tm), mImg.size());
+	QRectF imgRect = QRectF(QPoint(lm, tm), mImgSize);
 	float ratioImg = (float)(imgRect.width()/imgRect.height());
 	float ratioWin = (float)(iSize.width())/(float)(iSize.height());
 
@@ -799,28 +788,20 @@ DkZoomWidget::DkZoomWidget(QWidget* parent) : DkFadeLabel(parent) {
 void DkZoomWidget::createLayout() {
 
 	mOverview = new DkOverview(this);
-
+	
 	mSlZoom = new QSlider(Qt::Horizontal, this);
 	mSlZoom->setObjectName("slZoom");
 	mSlZoom->setCursor(Qt::ArrowCursor);
 	mSlZoom->setMinimum(0);	// add a mapping here
 	mSlZoom->setMaximum(100);
 
-	QString styleString = "QDoubleSpinBox{margin: 0px; padding: 0px; color: " + 
-		DkUtils::colorToString(DkSettingsManager::param().display().hudFgdColor) + 
-		"; background-color: rgba(0,0,0,0); border: none; selection-background-color: " +
-		DkUtils::colorToString(DkSettingsManager::param().display().highlightColor) + ";}";
-	//styleString += "QDoubleSpinBox::up-arrow, QDoubleSpinBox::down-arrow {width: 0px; heihgt: 0px;}";
-	//styleString += "QDoubleSpinBox::up-bottom, QDoubleSpinBox::down-bottom {width: 0px; heihgt: 0px;}";
-
 	mSbZoom = new QDoubleSpinBox(this);
 	mSbZoom->setObjectName("sbZoom");
-	mSbZoom->setStyleSheet(styleString);
 	mSbZoom->setButtonSymbols(QAbstractSpinBox::NoButtons);
 	mSbZoom->setSuffix("%");
 	mSbZoom->setDecimals(0);
-	mSbZoom->setMinimum(0.2);
 	mSbZoom->setValue(100);
+	mSbZoom->setMinimum(0.2);
 	mSbZoom->setMaximum(6000);
 
 	QLabel* sliderWidget = new QLabel(this);
@@ -841,23 +822,23 @@ void DkZoomWidget::createLayout() {
 void DkZoomWidget::on_sbZoom_valueChanged(double zoomLevel) {
 	updateZoom((float)zoomLevel);
 	mAutoHide = false;
-	emit zoomSignal((float)zoomLevel/100.0f);
+	emit zoomSignal(zoomLevel/100.0);
 }
 
 void DkZoomWidget::on_slZoom_valueChanged(int zoomLevel) {
-	float level = (zoomLevel > 50) ? (zoomLevel-50.0f)/50.0f * (float)mSbZoom->maximum() + 200.0f : zoomLevel*4.0f;
-	if (level < 0.2f) level = 0.2f;
+	double level = (zoomLevel > 50) ? (zoomLevel-50.0)/50.0 * mSbZoom->maximum() + 200.0 : zoomLevel*4.0;
+	if (level < 0.2) level = 0.2;
 	mAutoHide = false;
 	updateZoom(level);
-	emit zoomSignal(level/100.0f);
+	emit zoomSignal(level/100.0);
 }
 
-void DkZoomWidget::updateZoom(float zoomLevel) {
+void DkZoomWidget::updateZoom(double zoomLevel) {
 
 	mSlZoom->blockSignals(true);
 	mSbZoom->blockSignals(true);
 	
-	int slVal = (zoomLevel > 200.0f) ? qRound(zoomLevel/mSbZoom->maximum()*50.0f + 50.0f) : qRound(zoomLevel*0.25f);
+	int slVal = (zoomLevel > 200.0) ? qRound(zoomLevel/mSbZoom->maximum()*50.0 + 50.0) : qRound(zoomLevel*0.25);
 	mSlZoom->setValue(slVal);
 	mSbZoom->setValue(zoomLevel);
 	mSlZoom->blockSignals(false);
@@ -1015,8 +996,8 @@ DkRatingLabel::DkRatingLabel(int rating, QWidget* parent, Qt::WindowFlags flags)
 
 void DkRatingLabel::init() {
 
-	QPixmap starDark = QPixmap(":/nomacs/img/star-dark.png");
-	QPixmap starWhite = QPixmap(":/nomacs/img/star-white.png");
+	QIcon starDark = DkImage::loadIcon(":/nomacs/img/star-off.svg", QSize(), DkSettingsManager::param().display().hudFgdColor);
+	QIcon starWhite = DkImage::loadIcon(":/nomacs/img/star-on.svg", QSize(), DkSettingsManager::param().display().hudFgdColor);
 
 	mStars.resize(5);
 	
@@ -1054,38 +1035,20 @@ DkRatingLabelBg::DkRatingLabelBg(int rating, QWidget* parent, Qt::WindowFlags fl
 	// we want a margin
 	mLayout->setContentsMargins(10,4,10,4);
 	mLayout->setSpacing(4);
-	
-	mActions.resize(6);
 
-	mActions[rating_0] = new QAction(tr("no rating"), this);
-	mActions[rating_0]->setShortcut(Qt::Key_0);
-	connect(mActions[rating_0], SIGNAL(triggered()), this, SLOT(rating0()));
+	DkActionManager& am = DkActionManager::instance();
 
-	mActions[rating_1] = new QAction(tr("one star"), this);
-	mActions[rating_1]->setShortcut(Qt::Key_1);
-	connect(mActions[rating_1], SIGNAL(triggered()), this, SLOT(rating1()));
-
-	mActions[rating_2] = new QAction(tr("two stars"), this);
-	mActions[rating_2]->setShortcut(Qt::Key_2);
-	connect(mActions[rating_2], SIGNAL(triggered()), this, SLOT(rating2()));
-
-	mActions[rating_3] = new QAction(tr("three stars"), this);
-	mActions[rating_3]->setShortcut(Qt::Key_3);
-	connect(mActions[rating_3], SIGNAL(triggered()), this, SLOT(rating3()));
-
-	mActions[rating_4] = new QAction(tr("four stars"), this);
-	mActions[rating_4]->setShortcut(Qt::Key_4);
-	connect(mActions[rating_4], SIGNAL(triggered()), this, SLOT(rating4()));
-
-	mActions[rating_5] = new QAction(tr("five stars"), this);
-	mActions[rating_5]->setShortcut(Qt::Key_5);
-	connect(mActions[rating_5], SIGNAL(triggered()), this, SLOT(rating5()));
-
-	mStars[rating_1]->addAction(mActions[rating_1]);
-	mStars[rating_2]->addAction(mActions[rating_2]);
-	mStars[rating_3]->addAction(mActions[rating_3]);
-	mStars[rating_4]->addAction(mActions[rating_4]);
-	mStars[rating_5]->addAction(mActions[rating_5]);
+	connect(am.action(DkActionManager::sc_star_rating_0), SIGNAL(triggered()), this, SLOT(rating0()));
+	mStars[rating_1]->addAction(am.action(DkActionManager::sc_star_rating_1));
+	connect(am.action(DkActionManager::sc_star_rating_1), SIGNAL(triggered()), this, SLOT(rating1()));
+	mStars[rating_2]->addAction(am.action(DkActionManager::sc_star_rating_2));
+	connect(am.action(DkActionManager::sc_star_rating_2), SIGNAL(triggered()), this, SLOT(rating2()));
+	mStars[rating_3]->addAction(am.action(DkActionManager::sc_star_rating_3));
+	connect(am.action(DkActionManager::sc_star_rating_3), SIGNAL(triggered()), this, SLOT(rating3()));
+	mStars[rating_4]->addAction(am.action(DkActionManager::sc_star_rating_4));
+	connect(am.action(DkActionManager::sc_star_rating_4), SIGNAL(triggered()), this, SLOT(rating4()));
+	mStars[rating_5]->addAction(am.action(DkActionManager::sc_star_rating_5));
+	connect(am.action(DkActionManager::sc_star_rating_5), SIGNAL(triggered()), this, SLOT(rating5()));
 	
 	connect(mHideTimer, SIGNAL(timeout()), this, SLOT(hide()));
 }
@@ -1098,10 +1061,6 @@ void DkRatingLabelBg::changeRating(int newRating) {
 	mHideTimer->start();
 }
 
-QVector<QAction*> DkRatingLabelBg::getActions() const {
-	return mActions;
-}
-
 void DkRatingLabelBg::paintEvent(QPaintEvent *event) {
 
 	QPainter painter(this);
@@ -1255,35 +1214,36 @@ DkPlayer::DkPlayer(QWidget* parent) : DkWidget(parent) {
 void DkPlayer::createLayout() {
 
 	int height = 50;
+	QSize ih(height-12, height-12);
 
-	previousButton = new QPushButton(QIcon(":/nomacs/img/player-previous.svg"), "", this);
+	previousButton = new QPushButton(DkImage::loadIcon(":/nomacs/img/previous.svg", ih, Qt::white), "", this);
 	//previousButton->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
-	previousButton->setIconSize(QSize(2*height, height));
-	previousButton->setMaximumHeight(height);
+	previousButton->setIconSize(ih);
+	previousButton->setMinimumSize(QSize(qRound(1.5*height), height));
 	previousButton->setToolTip(tr("Show previous image"));
 	previousButton->setObjectName("DkPlayerButton");
 	previousButton->setFlat(true);
 	connect(previousButton, SIGNAL(pressed()), this, SLOT(previous()));
 
 	QIcon icon;
-	icon.addPixmap(QIcon(":/nomacs/img/player-pause.svg").pixmap(2*height), QIcon::Normal, QIcon::On);
-	icon.addPixmap(QIcon(":/nomacs/img/player-play.svg").pixmap(2*height), QIcon::Normal, QIcon::Off);
+	icon.addPixmap(DkImage::loadIcon(":/nomacs/img/pause.svg", ih, Qt::white), QIcon::Normal, QIcon::On);
+	icon.addPixmap(DkImage::loadIcon(":/nomacs/img/play.svg", ih, Qt::white), QIcon::Normal, QIcon::Off);
 	playButton = new QPushButton(icon, "", this);
 	//playButton->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
-	playButton->setIconSize(QSize(2*height, height));
-	playButton->setMaximumHeight(height);
+	playButton->setIconSize(ih);
+	playButton->setMinimumSize(QSize(qRound(1.5*height), height));
 	playButton->setToolTip(tr("Play/Pause"));
 	playButton->setObjectName("DkPlayerButton");
 	playButton->setFlat(true);
 	playButton->setCheckable(true);
 	playButton->setChecked(false);
-	playButton->addAction(actions[play_action]);
+	playButton->addAction(DkActionManager::instance().action(DkActionManager::menu_view_slideshow));
 	connect(playButton, SIGNAL(clicked(bool)), this, SLOT(play(bool)));
 
-	nextButton = new QPushButton(QIcon(":/nomacs/img/player-next.svg"), "",  this);
+	nextButton = new QPushButton(DkImage::loadIcon(":/nomacs/img/next.svg", ih, Qt::white), "",  this);
 	//nextButton->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
-	nextButton->setIconSize(QSize(2*height, height));
-	nextButton->setMaximumHeight(height);
+	nextButton->setIconSize(ih);
+	nextButton->setMinimumSize(QSize(qRound(1.5*height), height));
 	nextButton->setToolTip(tr("Show next image"));
 	nextButton->setObjectName("DkPlayerButton");
 	nextButton->setFlat(true);
@@ -1292,7 +1252,7 @@ void DkPlayer::createLayout() {
 	// now add to mLayout
 	container = new QWidget(this);
 	QHBoxLayout* layout = new QHBoxLayout(container);
-	layout->setContentsMargins(0,0,0,0);
+	//layout->setContentsMargins(0,0,0,0);
 	layout->addStretch();
 	layout->addWidget(previousButton);
 	layout->addWidget(playButton);
@@ -1326,9 +1286,6 @@ void DkPlayer::init() {
 	hideTimer->setSingleShot(true);
 	connect(hideTimer, SIGNAL(timeout()), this, SLOT(hide()));
 
-	actions.resize(1);
-	actions[play_action] = new QAction(tr("play"), this);
-	connect(actions[play_action], SIGNAL(triggered()), this, SLOT(togglePlay()));
 	connect(DkActionManager::instance().action(DkActionManager::menu_view_slideshow), SIGNAL(triggered()), this, SLOT(togglePlay()));
 }
 
@@ -1485,7 +1442,7 @@ void DkTransformRect::enterEvent(QEvent*) {
 DkEditableRect::DkEditableRect(const QRectF& rect, QWidget* parent, Qt::WindowFlags f) : DkWidget(parent, f) {
 
 	mRect = rect;
-	mRotatingCursor = QCursor(QPixmap(":/nomacs/img/rotating-cursor.png"));
+	mRotatingCursor = QCursor(DkImage::loadFromSvg(":/nomacs/img/rotating-cursor.svg", QSize(24, 24)));
 	
 	setAttribute(Qt::WA_MouseTracking);
 
@@ -1864,7 +1821,7 @@ void DkEditableRect::mouseMoveEvent(QMouseEvent *event) {
 		setAngle(angle, false);
 	}
 
-	if (event->buttons() == Qt::LeftButton && mState != moving) {
+	if (event->buttons() == Qt::LeftButton) {
 
 		QPolygonF p = mRect.getPoly();
 
@@ -1877,11 +1834,11 @@ void DkEditableRect::mouseMoveEvent(QMouseEvent *event) {
 		QPoint tl;
 
 		if (sAngle == 0.0f || fabs(sAngle) == 90.0f) {
-			tl = mRect.getTopLeft().toPoint();
+			tl = mRtform.map(mRect.getTopLeft()).toPoint();
 			info += "x: ";
 		}
 		else {
-			tl = mRect.getCenter().toPoint();
+			tl = mRtform.map(mRect.getCenter()).toPoint();
 			info += "center x: ";
 		}
 		info += QString::number(tl.x()) + ", y: ";
@@ -2048,6 +2005,12 @@ void DkCropWidget::createToolbar() {
 
 }
 
+void DkCropWidget::mouseDoubleClickEvent(QMouseEvent * ev) {
+	
+	crop();
+	QWidget::mouseDoubleClickEvent(ev);
+}
+
 DkCropToolBar* DkCropWidget::getToolbar() const {
 	return cropToolbar;
 }
@@ -2505,311 +2468,6 @@ void DkFolderLabel::mousePressEvent(QMouseEvent *ev) {
 	QLabel::mousePressEvent(ev);
 }
 
-// DkImageLabel --------------------------------------------------------------------
-DkImageLabel::DkImageLabel(const QString& filePath, int thumbSize, QWidget* parent /* = 0 */, Qt::WindowFlags f /* = 0 */) : QLabel(parent, f) {
-
-	mThumbSize = thumbSize;
-
-	thumb = QSharedPointer<DkThumbNailT>(new DkThumbNailT(filePath));
-	connect(thumb.data(), SIGNAL(thumbLoadedSignal()), this, SIGNAL(labelLoaded()));
-	connect(thumb.data(), SIGNAL(thumbLoadedSignal()), this, SLOT(thumbLoaded()));
-
-	setFixedSize(mThumbSize, mThumbSize);
-	setMouseTracking(true);
-
-	QFileInfo fInfo(filePath);
-	setStatusTip(fInfo.fileName());
-	setToolTip(fInfo.fileName());
-	
-	createLayout();
-}
-
-void DkImageLabel::createLayout() {
-
-	imageLabel = new QLabel(this);
-	imageLabel->setFixedSize(mThumbSize, mThumbSize);
-	imageLabel->setScaledContents(true);
-	imageLabel->setStyleSheet("QLabel{margin: 0 0 0 0; padding: 0 0 0 0; border: 1px solid " + DkUtils::colorToString(DkSettingsManager::param().display().hudBgColor) + ";}");
-
-	QColor cA = DkSettingsManager::param().display().highlightColor;
-	cA.setAlpha(100);
-	highLightLabel = new QLabel(this);
-	highLightLabel->setFixedSize(mThumbSize, mThumbSize);
-	highLightLabel->setStyleSheet("QLabel{background: " + DkUtils::colorToString(cA) + "; border: 1px solid " + DkUtils::colorToString(DkSettingsManager::param().display().highlightColor) + ";}");
-	highLightLabel->hide();
-
-	removeFileButton = new QPushButton(QIcon(":/nomacs/img/close.svg"), tr(""), this);
-	removeFileButton->setIconSize(QSize(12, 12));
-	removeFileButton->setFixedSize(QSize(12, 12));
-	removeFileButton->setFlat(true);
-	removeFileButton->setObjectName("removeFileButton");
-	removeFileButton->move(width()-17, 5);
-	removeFileButton->hide();
-
-	connect(removeFileButton, SIGNAL(clicked()), this, SLOT(removeFileFromList()));
-}
-
-bool DkImageLabel::hasFile() const {
-
-	return !thumb->getImage().isNull();
-}
-
-QSharedPointer<DkThumbNailT> DkImageLabel::getThumb() const {
-	
-	return thumb;
-}
-
-void DkImageLabel::thumbLoaded() {
-
-	if (thumb->getImage().isNull()) {
-		qDebug() << QFileInfo(thumb->getFilePath()).fileName() << " not loaded...";
-		return;
-	}
-	
-	QPixmap pm = QPixmap::fromImage(thumb->getImage());
-
-	QRect r(QPoint(), pm.size());
-
-	if (r.width() > r.height()) {
-		r.setX(qFloor((r.width()-r.height())*0.5f));
-		r.setWidth(r.height());
-	}
-	else {
-		r.setY(qFloor((r.height()-r.width())*0.5f));
-		r.setHeight(r.width());
-	}
-	pm = pm.copy(r);
-
-	imageLabel->setPixmap(pm);
-}
-
-void DkImageLabel::removeFileFromList() {
-
-	imageLabel->hide();
-	//highLightLabel->hide();
-	removeFileButton->hide();
-	highLightLabel->setStyleSheet("QLabel{background: " + DkUtils::colorToString(DkSettingsManager::param().display().hudBgColor) + "; border: 1px solid black;}");
-	highLightLabel->show();
-
-	for (int idx = 0; idx < DkSettingsManager::param().global().recentFiles.size(); idx++) {
-
-		if (thumb->getFilePath() == DkSettingsManager::param().global().recentFiles.at(idx))
-			DkSettingsManager::param().global().recentFiles.removeAt(idx);
-	}
-}
-
-void DkImageLabel::enterEvent(QEvent *ev) {
-	
-	if (imageLabel->isVisible()) {
-		highLightLabel->show();
-		removeFileButton->show();
-	}
-	QLabel::enterEvent(ev);
-}
-
-void DkImageLabel::leaveEvent(QEvent *ev) {
-	
-	if (imageLabel->isVisible())
-		highLightLabel->hide();
-	removeFileButton->hide();
-	QLabel::leaveEvent(ev);
-}
-
-void DkImageLabel::mousePressEvent(QMouseEvent *ev) {
-
-	emit loadFileSignal(thumb->getFilePath());
-
-	QLabel::mousePressEvent(ev);
-}
-
-
-// Recent Files Widget --------------------------------------------------------------------
-DkRecentFilesWidget::DkRecentFilesWidget(QWidget* parent /* = 0 */) : DkWidget(parent) {
-
-	setObjectName("DkRecentFilesWidget");
-	rFileIdx = 0;
-
-	createLayout();
-
-	//connect(&fileWatcher, SIGNAL(finished()), this, SLOT(updateFiles()));
-}
-
-DkRecentFilesWidget::~DkRecentFilesWidget() {
-
-	//fileWatcher.blockSignals(true);
-	//fileWatcher.cancel();
-	//fileWatcher.waitForFinished();
-}
-
-void DkRecentFilesWidget::createLayout() {
-
-	filesWidget = new QWidget(this);
-	filesLayout = new QGridLayout(filesWidget);
-	filesLayout->setAlignment(Qt::AlignTop);
-	//filesWidget->setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding);
-
-	//folderWidget = new QWidget(this);
-	//folderLayout = new QVBoxLayout(folderWidget);
-	
-	//filesTitle = new QLabel(tr("Recent Files"), this);
-	//filesTitle->setObjectName("DkRecentFilesTitle");
-	//filesTitle->setStyleSheet("QLabel{font-size: 15pt;}" + filesTitle->styleSheet());
-
-	//folderTitle = new QLabel(tr("Recent Folders"), this);
-	//folderTitle->setObjectName("DkRecentFilesTitle");
-	//folderTitle->setStyleSheet("QLabel{font-size: 15pt;}" + folderTitle->styleSheet());
-
-	bgLabel = new QLabel(this);
-	bgLabel->setObjectName("bgLabel");
-	
-	QHBoxLayout* layout = new QHBoxLayout(this);
-	layout->setContentsMargins(0,0,0,0);
-	layout->addWidget(bgLabel);
-	
-	QHBoxLayout* hLayout = new QHBoxLayout(bgLabel);
-	hLayout->setAlignment(Qt::AlignTop | Qt::AlignLeft);
-	hLayout->addWidget(filesWidget);
-	//hLayout->addWidget(folderWidget);
-	//hLayout->addStretch();
-
-	setCustomStyle();
-}
-
-void DkRecentFilesWidget::setCustomStyle(bool imgLoadedStyle) {
-
-	setProperty("imageLoaded", imgLoadedStyle);
-	style()->unpolish(bgLabel);
-	//style()->unpolish(filesTitle);	// don't know why I need to unpolish every widget on it's own
-	//style()->unpolish(folderTitle);
-	style()->unpolish(this);
-	ensurePolished();
-}
-
-void DkRecentFilesWidget::setVisible(bool visible, bool saveSettings) {
-	
-	if (visible && !isVisible()) {
-		updateFileList();
-	}
-
-	DkWidget::setVisible(saveSettings);
-}
-
-void DkRecentFilesWidget::hide(bool saveSettings) {
-	
-	QWidget::hide();	// no animation effect on hide
-	DkWidget::hide(saveSettings);
-}
-
-void DkRecentFilesWidget::updateFileList() {
-
-	//delete folderLayout;
-	delete filesLayout;
-	rFileIdx = 0;
-	numActiveLabels = 0;
-
-	filesLayout = new QGridLayout(filesWidget);
-	filesLayout->setAlignment(Qt::AlignLeft | Qt::AlignTop);
-
-	//folderLayout = new QVBoxLayout(folderWidget);
-
-	filesWidget->setFixedHeight(1080);
-	//folderWidget->setFixedHeight(1080);
-
-	//filesLayout->setSpacing(10);
-	//folderLayout->setSpacing(0);
-
-	for (int idx = 0; idx < fileLabels.size(); idx++) {
-		delete fileLabels.at(idx);
-	}
-
-	//for (int idx = 0; idx < folderLabels.size(); idx++) {
-	//	delete folderLabels.at(idx);
-	//}
-
-	//filesTitle->hide();
-	//folderTitle->hide();
-
-	fileLabels.clear();
-	//folderLabels.clear();
-	recentFiles.clear();
-	//recentFolders.clear();
-
-	for (const QString& filePath : DkSettingsManager::param().global().recentFiles)
-		recentFiles.append(QFileInfo(filePath));
-	//for (int idx = 0; idx < DkSettingsManager::param().global().recentFolders.size(); idx++)
-	//	recentFolders.append(QFileInfo(DkSettingsManager::param().global().recentFolders.at(idx)));
-
-	updateFiles();
-	//updateFolders();
-}
-
-void DkRecentFilesWidget::updateFiles() {
-
-	int columns = 5;//qFloor(width()/(mThumbSize*2.0));
-
-	if (fileLabels.empty()) {
-		//filesTitle->show();
-		//filesLayout->setRowStretch(recentFiles.size()+2, 100);
-		//filesLayout->addWidget(filesTitle, 0, 0, 1, columns, Qt::AlignRight);
-	}
-
-	// show current
-	if (rFileIdx < fileLabels.size() && fileLabels.at(rFileIdx)->hasFile()) {
-		fileLabels.at(rFileIdx)->show();
-		filesLayout->addWidget(fileLabels.at(rFileIdx), qFloor((float)numActiveLabels/columns)+2, numActiveLabels%columns);
-		numActiveLabels++;
-	}
-	else if (rFileIdx < fileLabels.size()) {
-		fileLabels.at(rFileIdx)->hide();
-
-		// remove files which we can't load to keep the list clean...
-		DkSettingsManager::param().global().recentFiles.removeAll(fileLabels.at(rFileIdx)->getThumb()->getFilePath());		// remove recent files which we could not load...
-	}
-
-	if (!fileLabels.empty())
-		rFileIdx++;
-
-	// load next
-	if ((rFileIdx/(float)columns*mThumbSize < filesWidget->height()-200 || !(rFileIdx+1 % columns)) && rFileIdx < recentFiles.size()) {
-		DkImageLabel* cLabel = new DkImageLabel(recentFiles.at(rFileIdx).absoluteFilePath(), mThumbSize, this);
-		cLabel->hide();
-		cLabel->setStyleSheet(QString("QLabel{background-color: rgba(0,0,0,0), border: solid 1px black;}"));
-		
-		fileLabels.append(cLabel);
-		connect(cLabel, SIGNAL(labelLoaded()), this, SLOT(updateFiles()));
-		connect(cLabel, SIGNAL(loadFileSignal(const QString&)), this, SIGNAL(loadFileSignal(const QString&)));
-		cLabel->getThumb()->fetchThumb(DkThumbNailT::force_exif_thumb);
-	}
-	//else {
-	//	qDebug() << "[Recent Files] loading stopped at" << rFileIdx << "history size:" << recentFiles.size();
-	//}
-
-	update();
-}
-
-//void DkRecentFilesWidget::updateFolders() {
-//
-//	//folderTitle->show();
-//	//folderLayout->addWidget(folderTitle);
-//	//folderLayout->addSpacerItem(new QSpacerItem(10, 10));
-//
-//	int cHeight = 0;
-//
-//	for (DkFileInfo& fi : recentFolders) {
-//
-//		DkFolderLabel* fLabel = new DkFolderLabel(fi, this);
-//		connect(fLabel, SIGNAL(loadFileSignal(const QString&)), this, SIGNAL(loadFileSignal(const QString&)));
-//		folderLayout->addWidget(fLabel);
-//		folderLabels.append(fLabel);
-//
-//		cHeight += fLabel->height();
-//		if (cHeight > folderWidget->height())
-//			break;
-//	}
-//
-//	folderLayout->addStretch();
-//}
-
 // DkDirectoryEdit --------------------------------------------------------------------
 DkDirectoryEdit::DkDirectoryEdit(QWidget* parent /* = 0 */) : QLineEdit(parent) {
 	setObjectName("DkWarningEdit");
@@ -2854,7 +2512,6 @@ bool DkDirectoryEdit::existsDirectory(const QString& path) {
 	return QDir(path).exists();
 }
 
-
 // DkDirectoryChooser --------------------------------------------------------------------
 DkDirectoryChooser::DkDirectoryChooser(const QString& dirPath, QWidget* parent) : QWidget(parent) {
 	
@@ -2999,7 +2656,7 @@ void DkProgressBar::paintEvent(QPaintEvent *) {
 	p.setPen(Qt::NoPen);
 
 	if (parentWidget() && DkUtils::getMainWindow()->isFullScreen())
-		p.fillRect(QRect(QPoint(), size()), DkSettingsManager::param().slideShow().backgroundColor);
+		p.setBackground(DkSettingsManager::param().slideShow().backgroundColor);
 
 	p.setBrush(DkSettingsManager::param().display().highlightColor);
 
@@ -3262,6 +2919,119 @@ void DkTabEntryWidget::paintEvent(QPaintEvent *event) {
 	QPushButton::paintEvent(event);
 }
 
+// -------------------------------------------------------------------- DkDisplayWidget 
+DkDisplayWidget::DkDisplayWidget(QWidget* parent) : DkWidget(parent) {
+
+	createLayout();
+	updateLayout();
+
+	setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Minimum);
+	setMinimumHeight(100);
 }
 
+QRect DkDisplayWidget::screenRect() const {
+	
+	int idx = currentIndex();
 
+	if (idx >= 0)
+		return mScreens[idx]->availableGeometry();
+
+	return QRect();
+}
+
+int DkDisplayWidget::count() const {
+	
+	return mScreens.size();
+}
+
+int DkDisplayWidget::currentIndex() const {
+	
+	for (int idx = 0; idx < mScreenButtons.size(); idx++) {
+
+		if (mScreenButtons[idx]->isChecked())
+			return idx;
+	}
+	
+	return 0;
+}
+
+void DkDisplayWidget::setCurrentIndex(int index) {
+
+	mScreenButtons[index]->setChecked(true);
+}
+
+void DkDisplayWidget::resizeEvent(QResizeEvent * event) {
+
+	DkWidget::resizeEvent(event);
+	updateLayout();
+}
+
+void DkDisplayWidget::createLayout() {
+
+	mScreens = QGuiApplication::screens();
+
+	QButtonGroup* bg = new QButtonGroup(this);
+
+	for (int idx = 0; idx < mScreens.size(); idx++) {
+
+		QPushButton* sb = new QPushButton(QString::number(idx+1), this);
+		sb->setObjectName("displayButton");
+		sb->setCheckable(true);
+		sb->setFlat(true);
+
+		//connect(sb, SIGNAL(clicked()), this, SLOT(changeDisplay()));
+
+		bg->addButton(sb);
+		mScreenButtons << sb;
+	}
+}
+
+void DkDisplayWidget::updateLayout() {
+
+
+	QRect desktop;
+	for (auto s : mScreens) {
+		desktop = desktop.united(s->geometry());
+	}
+
+	int w = width() - 6;
+	int h = height() - 6;
+
+	QTransform tm;
+	double sx = (double)w / desktop.width();
+	double sy = (double)h / desktop.height();
+	double s = qMin(sx, sy);
+	tm.scale(s, s);
+
+	QRect md = tm.mapRect(desktop);
+	QPoint dxy(qRound((width() - md.width()) * 0.5), qRound((height() - md.height()) * 0.5));
+
+	int myScreen = QApplication::desktop()->screenNumber(this);
+
+	for (int idx = 0; idx < mScreens.size(); idx++) {
+
+		QRect r = mScreens[idx]->geometry();
+		r.moveCenter(r.center()-desktop.topLeft());
+		
+		r = tm.mapRect(r);
+		r.moveCenter(r.center()+dxy);	// center
+
+		if (idx == myScreen)
+			mScreenButtons[idx]->setChecked(true);
+
+		mScreenButtons[idx]->setGeometry(r);
+	}
+}
+
+//void DkDisplayWidget::changeDisplay() {
+//
+//	QRect sr = screenRect();
+//
+//	DkNoMacsFrameless* w = dynamic_cast<DkNoMacsFrameless*>(DkUtils::getMainWindow());
+//
+//	if (w)
+//		w->setGeometry(sr);
+//}
+
+
+}
