@@ -182,10 +182,8 @@ public:
 	~DkRatingLabelBg();
 
 	void changeRating(int newRating);
-	QVector<QAction*> getActions() const;
 
 protected:
-	QVector<QAction*> mActions;
 	QTimer* mHideTimer;
 	int mTimeToDisplay = 4000;
 	
@@ -234,10 +232,6 @@ public:
 
 	void setTimeToDisplay(int ms = 1000);
 
-	QVector<QAction*> getActions() {
-		return actions;
-	};
-
 signals:
 	void nextSignal();
 	void previousSignal();
@@ -266,8 +260,6 @@ protected:
 	QPushButton* nextButton;
 	QPushButton* playButton;
 	QWidget* container;
-
-	QVector<QAction*> actions;
 };
 
 class DkFolderScrollBar : public QSlider {
@@ -339,7 +331,6 @@ protected:
 
 	QFileInfo mCurrentDir;
 	QProgressDialog* mPd = 0;
-	int mCLoadIdx = 0;
 	bool mStop = false;
 	bool mForceSave = false;
 	int mNumSaved = false;
@@ -351,9 +342,6 @@ class DkFileSystemModel : public QFileSystemModel {
 
 public:
 	DkFileSystemModel(QObject* parent = 0);
-
-protected:
-
 };
 
 class DkSortFileProxyModel : public QSortFilterProxyModel {
@@ -413,9 +401,8 @@ public:
 
 	void setImage(const QImage& img) {
 		mImg = img;
-
-		if (isVisible())
-			resizeImg();
+		mImgSize = img.size();
+		mImgT = QImage();
 	};
 
 	void setTransforms(QTransform* worldMatrix, QTransform* imgMatrix){
@@ -427,21 +414,14 @@ public:
 		mViewPortRect = viewPortRect;	
 	};
 
-	void setVisible(bool visible) {
-
-		if (visible)
-			resizeImg();
-
-		QWidget::setVisible(visible);
-	};
-
 signals:
 	void moveViewSignal(const QPointF& dxy) const;
 	void sendTransformSignal() const;
 
 protected:
 	QImage mImg;
-	QImage imgT;
+	QImage mImgT;
+	QSize mImgSize;
 	QTransform* mScaledImgMatrix;
 	QTransform* mWorldMatrix;
 	QTransform* mImgMatrix;
@@ -449,12 +429,11 @@ protected:
 	QPointF mPosGrab;
 	QPointF mEnterPos;
 
-	void resizeImg();
+	QImage resizedImg(const QImage& src);
 	void paintEvent(QPaintEvent *event);
 	void mouseMoveEvent(QMouseEvent *event);
 	void mouseReleaseEvent(QMouseEvent *event);
 	void mousePressEvent(QMouseEvent *event);
-	void resizeEvent(QResizeEvent* event);
 	QRectF getImageRect() const;
 	QTransform getScaledImageMatrix();
 };
@@ -470,12 +449,12 @@ public:
 	bool isAutoHide() const;
 
 signals:
-	void zoomSignal(float zoomLevel);
+	void zoomSignal(double zoomLevel);
 
 public slots:
 	virtual void setVisible(bool visible, bool autoHide = false);
 
-	void updateZoom(float zoomLevel);
+	void updateZoom(double zoomLevel);
 	void on_sbZoom_valueChanged(double zoomLevel);
 	void on_slZoom_valueChanged(int zoomLevel);
 
@@ -566,6 +545,7 @@ signals:
 	void cropImageSignal(const DkRotatingRect& cropArea, const QColor& bgCol = QColor(0,0,0,0), bool cropToMetaData = false) const;
 	void angleSignal(double angle) const;
 	void aRatioSignal(const QPointF& aRatio) const;
+	void updateRectSignal(const QRect& r) const;
 
 public slots:
 	void updateCorner(int idx, const QPointF& point, Qt::KeyboardModifiers modifier, bool changeState = false);
@@ -576,6 +556,7 @@ public slots:
 	void setPaintHint(int paintMode = rule_of_thirds);
 	void setShadingHint(bool invert);
 	void setShowInfo(bool showInfo);
+	void setRect(const QRect& rect);
 
 protected:
 	void mousePressEvent(QMouseEvent *event);
@@ -585,6 +566,7 @@ protected:
 	void keyPressEvent(QKeyEvent *event);
 	void keyReleaseEvent(QKeyEvent *event);
 	void paintEvent(QPaintEvent *event);
+	QRect rect() const;
 
 	QPointF clipToImage(const QPointF& pos);
 	QPointF clipToImageForce(const QPointF& pos);
@@ -626,11 +608,12 @@ public slots:
 	virtual void setVisible(bool visible);
 
 signals:
-	void cancelSignal();
-	void showToolbar(QToolBar* toolbar, bool show);
+	void hideSignal();
+	void showToolBar(QToolBar* toolbar, bool show);
 
 protected:
 	void createToolbar();
+	void mouseDoubleClickEvent(QMouseEvent* ev) override;
 
 	DkCropToolBar* cropToolbar;
 };
@@ -744,83 +727,6 @@ protected:
 	DkFileInfo fileInfo;
 };
 
-class DkImageLabel : public QLabel {
-	Q_OBJECT
-
-public:
-	DkImageLabel(const QString& filePath, int thumbSize = 100, QWidget* parent = 0, Qt::WindowFlags f = 0);
-
-	bool hasFile() const;
-	QSharedPointer<DkThumbNailT> getThumb() const;
-
-signals:
-	void labelLoaded() const;
-	void loadFileSignal(const QString&) const;
-
-public slots:
-	void thumbLoaded();
-	void removeFileFromList();
-
-protected:
-	void mousePressEvent(QMouseEvent *ev);
-	void enterEvent(QEvent *ev);
-	void leaveEvent(QEvent *ev);
-	void createLayout();
-
-	QLabel* imageLabel;
-	QLabel* highLightLabel;
-	QPushButton* removeFileButton;
-	QSharedPointer<DkThumbNailT> thumb;
-	int mThumbSize = 64;
-};
-
-class DkRecentFilesWidget : public DkWidget {
-	Q_OBJECT
-
-public:
-	DkRecentFilesWidget(QWidget* parent = 0);
-	~DkRecentFilesWidget();
-	void setCustomStyle(bool imgLoadedStyle = false);
-
-signals:
-	void loadFileSignal(const QString& filePath) const;
-
-public slots:
-	void updateFiles();
-	//void updateFolders();
-	virtual void setVisible(bool visible, bool saveSettings = true);
-	virtual void hide(bool saveSettings = true);
-	//void clearFileHistory();
-	//void clearFolderHistory();
-
-protected:
-	void createLayout();
-	void updateFileList();
-
-	QVector<QFileInfo> recentFiles;
-	//QVector<DkFileInfo> recentFolders;
-	//QFutureWatcher<void> fileWatcher;
-	QVector<DkImageLabel*> fileLabels;
-	//QVector<DkFolderLabel*> folderLabels;
-
-	QGridLayout* filesLayout;
-	//QVBoxLayout* folderLayout;
-
-	QWidget* filesWidget;
-	//QWidget* folderWidget;
-
-	//QLabel* folderTitle;
-	//QLabel* filesTitle;
-	QLabel* bgLabel;
-
-	QLabel* clearFiles;
-	//QLabel* clearFolders;
-
-	int rFileIdx;
-	int numActiveLabels;
-	int mThumbSize = 100;
-};
-
 class DkDirectoryEdit : public QLineEdit {
 	Q_OBJECT
 
@@ -828,7 +734,7 @@ public:
 	DkDirectoryEdit(QWidget* parent = 0);
 	DkDirectoryEdit(const QString& content, QWidget* parent = 0);
 		
-	bool existsDirectory() { return existsDirectory(text());};
+	bool existsDirectory() { return existsDirectory(text()); };
 
 signals:
 	bool directoryChanged(const QString& path);
@@ -923,6 +829,8 @@ public:
 	DkDelayedMessage(const QString& msg  = QString(), int time = 0, QObject* parent = 0) : DkDelayedInfo(time, parent) {
 		mMsg = msg;
 	}
+	DkDelayedMessage(QObject* parent = 0) : DkDelayedInfo(0, parent) {
+	}
 
 	~DkDelayedMessage() {}
 
@@ -1033,4 +941,31 @@ protected:
 
 };
 
+class DllCoreExport DkDisplayWidget : public DkWidget {
+	Q_OBJECT
+
+public:
+	DkDisplayWidget(QWidget* parent);
+
+	QRect screenRect() const;
+	
+	int count() const;
+
+	int currentIndex() const;
+	void setCurrentIndex(int index);
+
+//public slots:
+//	void changeDisplay();
+
+protected:
+	void resizeEvent(QResizeEvent *event) override;
+
+private:
+	void createLayout();
+	void updateLayout();
+
+	QList<QScreen*> mScreens;
+	QList<QPushButton*> mScreenButtons;
+};
+
 }
